Module datadog_api_client::datadogV1::api::api_aws_integration
source · Structs
- Configure your Datadog-AWS integration directly through the Datadog API. For more information, see the AWS integration page.
- ListAWSAccountsOptionalParams is a struct for passing parameters to the method
AWSIntegrationAPI::list_aws_accounts - UpdateAWSAccountOptionalParams is a struct for passing parameters to the method
AWSIntegrationAPI::update_aws_account
Enums
- CreateAWSAccountError is a struct for typed errors of method
AWSIntegrationAPI::create_aws_account - CreateAWSEventBridgeSourceError is a struct for typed errors of method
AWSIntegrationAPI::create_aws_event_bridge_source - CreateAWSTagFilterError is a struct for typed errors of method
AWSIntegrationAPI::create_aws_tag_filter - CreateNewAWSExternalIDError is a struct for typed errors of method
AWSIntegrationAPI::create_new_aws_external_id - DeleteAWSAccountError is a struct for typed errors of method
AWSIntegrationAPI::delete_aws_account - DeleteAWSEventBridgeSourceError is a struct for typed errors of method
AWSIntegrationAPI::delete_aws_event_bridge_source - DeleteAWSTagFilterError is a struct for typed errors of method
AWSIntegrationAPI::delete_aws_tag_filter - ListAWSAccountsError is a struct for typed errors of method
AWSIntegrationAPI::list_aws_accounts - ListAWSEventBridgeSourcesError is a struct for typed errors of method
AWSIntegrationAPI::list_aws_event_bridge_sources - ListAWSTagFiltersError is a struct for typed errors of method
AWSIntegrationAPI::list_aws_tag_filters - ListAvailableAWSNamespacesError is a struct for typed errors of method
AWSIntegrationAPI::list_available_aws_namespaces - UpdateAWSAccountError is a struct for typed errors of method
AWSIntegrationAPI::update_aws_account