Module datadog_api_client::datadogV1::api::api_hosts
source · Structs
- GetHostTotalsOptionalParams is a struct for passing parameters to the method
HostsAPI::get_host_totals - Get information about your infrastructure hosts in Datadog, and mute or unmute any notifications from your hosts. See the Infrastructure page for more information.
- ListHostsOptionalParams is a struct for passing parameters to the method
HostsAPI::list_hosts
Enums
- GetHostTotalsError is a struct for typed errors of method
HostsAPI::get_host_totals - ListHostsError is a struct for typed errors of method
HostsAPI::list_hosts - MuteHostError is a struct for typed errors of method
HostsAPI::mute_host - UnmuteHostError is a struct for typed errors of method
HostsAPI::unmute_host