#[non_exhaustive]
pub struct SubmitLogOptionalParams { pub content_encoding: Option<ContentEncoding>, pub ddtags: Option<String>, }
SubmitLogOptionalParams is a struct for passing parameters to the method LogsAPI::submit_log

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
content_encoding: Option<ContentEncoding>

HTTP header used to compress the media-type.

ddtags: Option<String>

Log tags can be passed as query parameters with text/plain content type.

Implementations

source

impl SubmitLogOptionalParams

source

pub fn content_encoding(self, value: ContentEncoding) -> Self

HTTP header used to compress the media-type.

Examples found in repository?
examples/v1_logs_SubmitLog_1920474053.rs (line 19)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
async fn main() {
    let body = vec![HTTPLogItem::new("Example-Log".to_string())
        .ddtags("host:ExampleLog".to_string())
        .additional_properties(BTreeMap::from([]))];
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .submit_log(
            body,
            SubmitLogOptionalParams::default().content_encoding(ContentEncoding::GZIP),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_logs_SubmitLog_3418823904.rs (line 20)
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    let body = vec![HTTPLogItem::new("Example-Log".to_string())
        .ddtags("host:ExampleLog".to_string())
        .additional_properties(BTreeMap::from([]))];
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .submit_log(
            body,
            SubmitLogOptionalParams::default().content_encoding(ContentEncoding::DEFLATE),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn ddtags(self, value: String) -> Self

Log tags can be passed as query parameters with text/plain content type.