#[non_exhaustive]pub struct SearchMonitorGroupsOptionalParams {
pub query: Option<String>,
pub page: Option<i64>,
pub per_page: Option<i64>,
pub sort: Option<String>,
}Expand description
SearchMonitorGroupsOptionalParams is a struct for passing parameters to the method MonitorsAPI::search_monitor_groups
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query: Option<String>After entering a search query on the Triggered Monitors page, use the query parameter value in the URL of the page as a value for this parameter. For more information, see the Manage Monitors documentation.
The query can contain any number of space-separated monitor attributes, for instance: query="type:metric group_status:alert".
page: Option<i64>Page to start paginating from.
per_page: Option<i64>Number of monitors to return per page.
sort: Option<String>String for sort order, composed of field and sort order separate by a comma, for example name,asc. Supported sort directions: asc, desc. Supported fields:
namestatustags
Implementations
sourceimpl SearchMonitorGroupsOptionalParams
impl SearchMonitorGroupsOptionalParams
sourcepub fn query(self, value: String) -> Self
pub fn query(self, value: String) -> Self
After entering a search query on the Triggered Monitors page, use the query parameter value in the URL of the page as a value for this parameter. For more information, see the Manage Monitors documentation.
The query can contain any number of space-separated monitor attributes, for instance: query="type:metric group_status:alert".