Module datadog_api_client::datadogV1::api::api_notebooks
source · Structs
- ListNotebooksOptionalParams is a struct for passing parameters to the method
NotebooksAPI::list_notebooks - Interact with your notebooks through the API to make it easier to organize, find, and share all of your notebooks with your team and organization. For more information, see the Notebooks documentation.
Enums
- CreateNotebookError is a struct for typed errors of method
NotebooksAPI::create_notebook - DeleteNotebookError is a struct for typed errors of method
NotebooksAPI::delete_notebook - GetNotebookError is a struct for typed errors of method
NotebooksAPI::get_notebook - ListNotebooksError is a struct for typed errors of method
NotebooksAPI::list_notebooks - UpdateNotebookError is a struct for typed errors of method
NotebooksAPI::update_notebook