#[non_exhaustive]pub struct ListNotebooksOptionalParams {
pub author_handle: Option<String>,
pub exclude_author_handle: Option<String>,
pub start: Option<i64>,
pub count: Option<i64>,
pub sort_field: Option<String>,
pub sort_dir: Option<String>,
pub query: Option<String>,
pub include_cells: Option<bool>,
pub is_template: Option<bool>,
pub type_: Option<String>,
}Expand description
ListNotebooksOptionalParams is a struct for passing parameters to the method NotebooksAPI::list_notebooks
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.Return notebooks created by the given author_handle.
Return notebooks not created by the given author_handle.
start: Option<i64>The index of the first notebook you want returned.
count: Option<i64>The number of notebooks to be returned.
sort_field: Option<String>Sort by field modified, name, or created.
sort_dir: Option<String>Sort by direction asc or desc.
query: Option<String>Return only notebooks with query string in notebook name or author handle.
include_cells: Option<bool>Value of false excludes the cells and global time for each notebook.
is_template: Option<bool>True value returns only template notebooks. Default is false (returns only non-template notebooks).
type_: Option<String>If type is provided, returns only notebooks with that metadata type. Default does not have type filtering.
Implementations
sourceimpl ListNotebooksOptionalParams
impl ListNotebooksOptionalParams
Return notebooks created by the given author_handle.
Return notebooks not created by the given author_handle.
sourcepub fn count(self, value: i64) -> Self
pub fn count(self, value: i64) -> Self
The number of notebooks to be returned.
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = NotebooksAPI::with_config(configuration);
let response =
api.list_notebooks_with_pagination(ListNotebooksOptionalParams::default().count(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn sort_field(self, value: String) -> Self
pub fn sort_field(self, value: String) -> Self
Sort by field modified, name, or created.
sourcepub fn query(self, value: String) -> Self
pub fn query(self, value: String) -> Self
Return only notebooks with query string in notebook name or author handle.
sourcepub fn include_cells(self, value: bool) -> Self
pub fn include_cells(self, value: bool) -> Self
Value of false excludes the cells and global time for each notebook.
sourcepub fn is_template(self, value: bool) -> Self
pub fn is_template(self, value: bool) -> Self
True value returns only template notebooks. Default is false (returns only non-template notebooks).