pub struct SlackIntegrationAPI { /* private fields */ }
Configure your Datadog-Slack integration directly through the Datadog API.

Implementations

source

impl SlackIntegrationAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v1_slack-integration_GetSlackIntegrationChannels.rs (line 8)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .get_slack_integration_channels("account_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_slack-integration_GetSlackIntegrationChannel.rs (line 8)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .get_slack_integration_channel("account_name".to_string(), "channel_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_slack-integration_RemoveSlackIntegrationChannel.rs (line 9)
7
8
9
10
11
12
13
14
15
16
17
18
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .remove_slack_integration_channel("account_name".to_string(), "channel_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_slack-integration_CreateSlackIntegrationChannel.rs (line 19)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    let body = SlackIntegrationChannel::new()
        .display(
            SlackIntegrationChannelDisplay::new()
                .message(true)
                .notified(true)
                .snapshot(true)
                .tags(true),
        )
        .name("#general".to_string());
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .create_slack_integration_channel("account_name".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_slack-integration_UpdateSlackIntegrationChannel.rs (line 19)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
async fn main() {
    let body = SlackIntegrationChannel::new()
        .display(
            SlackIntegrationChannelDisplay::new()
                .message(true)
                .notified(true)
                .snapshot(true)
                .tags(true),
        )
        .name("#general".to_string());
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .update_slack_integration_channel(
            "account_name".to_string(),
            "channel_name".to_string(),
            body,
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn create_slack_integration_channel( &self, account_name: String, body: SlackIntegrationChannel, ) -> Result<SlackIntegrationChannel, Error<CreateSlackIntegrationChannelError>>

Add a channel to your Datadog-Slack integration.

Examples found in repository?
examples/v1_slack-integration_CreateSlackIntegrationChannel.rs (line 21)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    let body = SlackIntegrationChannel::new()
        .display(
            SlackIntegrationChannelDisplay::new()
                .message(true)
                .notified(true)
                .snapshot(true)
                .tags(true),
        )
        .name("#general".to_string());
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .create_slack_integration_channel("account_name".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_slack_integration_channel_with_http_info( &self, account_name: String, body: SlackIntegrationChannel, ) -> Result<ResponseContent<SlackIntegrationChannel>, Error<CreateSlackIntegrationChannelError>>

Add a channel to your Datadog-Slack integration.

source

pub async fn get_slack_integration_channel( &self, account_name: String, channel_name: String, ) -> Result<SlackIntegrationChannel, Error<GetSlackIntegrationChannelError>>

Get a channel configured for your Datadog-Slack integration.

Examples found in repository?
examples/v1_slack-integration_GetSlackIntegrationChannel.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .get_slack_integration_channel("account_name".to_string(), "channel_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_slack_integration_channel_with_http_info( &self, account_name: String, channel_name: String, ) -> Result<ResponseContent<SlackIntegrationChannel>, Error<GetSlackIntegrationChannelError>>

Get a channel configured for your Datadog-Slack integration.

source

pub async fn get_slack_integration_channels( &self, account_name: String, ) -> Result<Vec<SlackIntegrationChannel>, Error<GetSlackIntegrationChannelsError>>

Get a list of all channels configured for your Datadog-Slack integration.

Examples found in repository?
examples/v1_slack-integration_GetSlackIntegrationChannels.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .get_slack_integration_channels("account_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_slack_integration_channels_with_http_info( &self, account_name: String, ) -> Result<ResponseContent<Vec<SlackIntegrationChannel>>, Error<GetSlackIntegrationChannelsError>>

Get a list of all channels configured for your Datadog-Slack integration.

source

pub async fn remove_slack_integration_channel( &self, account_name: String, channel_name: String, ) -> Result<(), Error<RemoveSlackIntegrationChannelError>>

Remove a channel from your Datadog-Slack integration.

Examples found in repository?
examples/v1_slack-integration_RemoveSlackIntegrationChannel.rs (line 11)
7
8
9
10
11
12
13
14
15
16
17
18
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .remove_slack_integration_channel("account_name".to_string(), "channel_name".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn remove_slack_integration_channel_with_http_info( &self, account_name: String, channel_name: String, ) -> Result<ResponseContent<()>, Error<RemoveSlackIntegrationChannelError>>

Remove a channel from your Datadog-Slack integration.

source

pub async fn update_slack_integration_channel( &self, account_name: String, channel_name: String, body: SlackIntegrationChannel, ) -> Result<SlackIntegrationChannel, Error<UpdateSlackIntegrationChannelError>>

Update a channel used in your Datadog-Slack integration.

Examples found in repository?
examples/v1_slack-integration_UpdateSlackIntegrationChannel.rs (lines 21-25)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
async fn main() {
    let body = SlackIntegrationChannel::new()
        .display(
            SlackIntegrationChannelDisplay::new()
                .message(true)
                .notified(true)
                .snapshot(true)
                .tags(true),
        )
        .name("#general".to_string());
    let configuration = datadog::Configuration::new();
    let api = SlackIntegrationAPI::with_config(configuration);
    let resp = api
        .update_slack_integration_channel(
            "account_name".to_string(),
            "channel_name".to_string(),
            body,
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn update_slack_integration_channel_with_http_info( &self, account_name: String, channel_name: String, body: SlackIntegrationChannel, ) -> Result<ResponseContent<SlackIntegrationChannel>, Error<UpdateSlackIntegrationChannelError>>

Update a channel used in your Datadog-Slack integration.