Struct datadog_api_client::datadogV1::api::api_snapshots::SnapshotsAPI
source · pub struct SnapshotsAPI { /* private fields */ }Expand description
Take graph snapshots using the API.
Implementations
sourceimpl SnapshotsAPI
impl SnapshotsAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
examples/v1_snapshots_GetGraphSnapshot.rs (line 9)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
let configuration = datadog::Configuration::new();
let api = SnapshotsAPI::with_config(configuration);
let resp = api
.get_graph_snapshot(
1636542671,
1636629071,
GetGraphSnapshotOptionalParams::default()
.metric_query("avg:system.load.1{*}".to_string())
.title("System load".to_string())
.height(400)
.width(600),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn get_graph_snapshot(
&self,
start: i64,
end: i64,
params: GetGraphSnapshotOptionalParams,
) -> Result<GraphSnapshot, Error<GetGraphSnapshotError>>
pub async fn get_graph_snapshot( &self, start: i64, end: i64, params: GetGraphSnapshotOptionalParams, ) -> Result<GraphSnapshot, Error<GetGraphSnapshotError>>
Take graph snapshots. Note: When a snapshot is created, there is some delay before it is available.
Examples found in repository?
examples/v1_snapshots_GetGraphSnapshot.rs (lines 11-19)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
let configuration = datadog::Configuration::new();
let api = SnapshotsAPI::with_config(configuration);
let resp = api
.get_graph_snapshot(
1636542671,
1636629071,
GetGraphSnapshotOptionalParams::default()
.metric_query("avg:system.load.1{*}".to_string())
.title("System load".to_string())
.height(400)
.width(600),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_graph_snapshot_with_http_info(
&self,
start: i64,
end: i64,
params: GetGraphSnapshotOptionalParams,
) -> Result<ResponseContent<GraphSnapshot>, Error<GetGraphSnapshotError>>
pub async fn get_graph_snapshot_with_http_info( &self, start: i64, end: i64, params: GetGraphSnapshotOptionalParams, ) -> Result<ResponseContent<GraphSnapshot>, Error<GetGraphSnapshotError>>
Take graph snapshots. Note: When a snapshot is created, there is some delay before it is available.