Struct datadog_api_client::datadogV1::api::api_users::UsersAPI

source ·
pub struct UsersAPI { /* private fields */ }
Create, edit, and disable users.

Implementations

source

impl UsersAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v1_users_ListUsers.rs (line 8)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.list_users().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_users_GetUser.rs (line 8)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_user("test@datadoghq.com".to_string()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_users_DisableUser.rs (line 8)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.disable_user("test@datadoghq.com".to_string()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_users_CreateUser_266604071.rs (line 15)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
async fn main() {
    let body = User::new()
        .access_role(None)
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.create_user(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_users_CreateUser.rs (line 16)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
async fn main() {
    let body = User::new()
        .access_role(Some(AccessRole::READ_ONLY))
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.create_user(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_users_UpdateUser.rs (line 16)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
async fn main() {
    let body = User::new()
        .access_role(Some(AccessRole::READ_ONLY))
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api
        .update_user("test@datadoghq.com".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn create_user( &self, body: User, ) -> Result<UserResponse, Error<CreateUserError>>

Create a user for your organization.

Note: Users can only be created with the admin access role if application keys belong to administrators.

Examples found in repository?
examples/v1_users_CreateUser_266604071.rs (line 16)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
async fn main() {
    let body = User::new()
        .access_role(None)
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.create_user(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_users_CreateUser.rs (line 17)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
async fn main() {
    let body = User::new()
        .access_role(Some(AccessRole::READ_ONLY))
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.create_user(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_user_with_http_info( &self, body: User, ) -> Result<ResponseContent<UserResponse>, Error<CreateUserError>>

Create a user for your organization.

Note: Users can only be created with the admin access role if application keys belong to administrators.

source

pub async fn disable_user( &self, user_handle: String, ) -> Result<UserDisableResponse, Error<DisableUserError>>

Delete a user from an organization.

Note: This endpoint can only be used with application keys belonging to administrators.

Examples found in repository?
examples/v1_users_DisableUser.rs (line 9)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.disable_user("test@datadoghq.com".to_string()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn disable_user_with_http_info( &self, user_handle: String, ) -> Result<ResponseContent<UserDisableResponse>, Error<DisableUserError>>

Delete a user from an organization.

Note: This endpoint can only be used with application keys belonging to administrators.

source

pub async fn get_user( &self, user_handle: String, ) -> Result<UserResponse, Error<GetUserError>>

Get a user’s details.

Examples found in repository?
examples/v1_users_GetUser.rs (line 9)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_user("test@datadoghq.com".to_string()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_user_with_http_info( &self, user_handle: String, ) -> Result<ResponseContent<UserResponse>, Error<GetUserError>>

Get a user’s details.

source

pub async fn list_users( &self, ) -> Result<UserListResponse, Error<ListUsersError>>

List all users for your organization.

Examples found in repository?
examples/v1_users_ListUsers.rs (line 9)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.list_users().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_users_with_http_info( &self, ) -> Result<ResponseContent<UserListResponse>, Error<ListUsersError>>

List all users for your organization.

source

pub async fn update_user( &self, user_handle: String, body: User, ) -> Result<UserResponse, Error<UpdateUserError>>

Update a user information.

Note: It can only be used with application keys belonging to administrators.

Examples found in repository?
examples/v1_users_UpdateUser.rs (line 18)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
async fn main() {
    let body = User::new()
        .access_role(Some(AccessRole::READ_ONLY))
        .disabled(false)
        .email("test@datadoghq.com".to_string())
        .handle("test@datadoghq.com".to_string())
        .name("test user".to_string());
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api
        .update_user("test@datadoghq.com".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn update_user_with_http_info( &self, user_handle: String, body: User, ) -> Result<ResponseContent<UserResponse>, Error<UpdateUserError>>

Update a user information.

Note: It can only be used with application keys belonging to administrators.