Module datadog_api_client::datadogV1::api::api_webhooks_integration
source · Structs
- Configure your Datadog-Webhooks integration directly through the Datadog API. See the Webhooks integration page for more information.
Enums
- CreateWebhooksIntegrationCustomVariableError is a struct for typed errors of method
WebhooksIntegrationAPI::create_webhooks_integration_custom_variable - CreateWebhooksIntegrationError is a struct for typed errors of method
WebhooksIntegrationAPI::create_webhooks_integration - DeleteWebhooksIntegrationCustomVariableError is a struct for typed errors of method
WebhooksIntegrationAPI::delete_webhooks_integration_custom_variable - DeleteWebhooksIntegrationError is a struct for typed errors of method
WebhooksIntegrationAPI::delete_webhooks_integration - GetWebhooksIntegrationCustomVariableError is a struct for typed errors of method
WebhooksIntegrationAPI::get_webhooks_integration_custom_variable - GetWebhooksIntegrationError is a struct for typed errors of method
WebhooksIntegrationAPI::get_webhooks_integration - UpdateWebhooksIntegrationCustomVariableError is a struct for typed errors of method
WebhooksIntegrationAPI::update_webhooks_integration_custom_variable - UpdateWebhooksIntegrationError is a struct for typed errors of method
WebhooksIntegrationAPI::update_webhooks_integration