Struct datadog_api_client::datadogV1::model::model_change_widget_request::ChangeWidgetRequest
source · #[non_exhaustive]pub struct ChangeWidgetRequest {Show 19 fields
pub apm_query: Option<LogQueryDefinition>,
pub change_type: Option<WidgetChangeType>,
pub compare_to: Option<WidgetCompareTo>,
pub event_query: Option<LogQueryDefinition>,
pub formulas: Option<Vec<WidgetFormula>>,
pub increase_good: Option<bool>,
pub log_query: Option<LogQueryDefinition>,
pub network_query: Option<LogQueryDefinition>,
pub order_by: Option<WidgetOrderBy>,
pub order_dir: Option<WidgetSort>,
pub process_query: Option<ProcessQueryDefinition>,
pub profile_metrics_query: Option<LogQueryDefinition>,
pub q: Option<String>,
pub queries: Option<Vec<FormulaAndFunctionQueryDefinition>>,
pub response_format: Option<FormulaAndFunctionResponseFormat>,
pub rum_query: Option<LogQueryDefinition>,
pub security_query: Option<LogQueryDefinition>,
pub show_present: Option<bool>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Updated change widget.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.apm_query: Option<LogQueryDefinition>The log query.
change_type: Option<WidgetChangeType>Show the absolute or the relative change.
compare_to: Option<WidgetCompareTo>Timeframe used for the change comparison.
event_query: Option<LogQueryDefinition>The log query.
formulas: Option<Vec<WidgetFormula>>List of formulas that operate on queries.
increase_good: Option<bool>Whether to show increase as good.
log_query: Option<LogQueryDefinition>The log query.
network_query: Option<LogQueryDefinition>The log query.
order_by: Option<WidgetOrderBy>What to order by.
order_dir: Option<WidgetSort>Widget sorting methods.
process_query: Option<ProcessQueryDefinition>The process query to use in the widget.
profile_metrics_query: Option<LogQueryDefinition>The log query.
q: Option<String>Query definition.
queries: Option<Vec<FormulaAndFunctionQueryDefinition>>List of queries that can be returned directly or used in formulas.
response_format: Option<FormulaAndFunctionResponseFormat>Timeseries, scalar, or event list response. Event list response formats are supported by Geomap widgets.
rum_query: Option<LogQueryDefinition>The log query.
security_query: Option<LogQueryDefinition>The log query.
show_present: Option<bool>Whether to show the present value.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl ChangeWidgetRequest
impl ChangeWidgetRequest
sourcepub fn new() -> ChangeWidgetRequest
pub fn new() -> ChangeWidgetRequest
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 38)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 40)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 40)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn apm_query(self, value: LogQueryDefinition) -> Self
sourcepub fn change_type(self, value: WidgetChangeType) -> Self
pub fn change_type(self, value: WidgetChangeType) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 39)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 41)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 41)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn compare_to(self, value: WidgetCompareTo) -> Self
pub fn compare_to(self, value: WidgetCompareTo) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_578885732.rs (line 42)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_2064651578.rs (line 42)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn event_query(self, value: LogQueryDefinition) -> Self
sourcepub fn formulas(self, value: Vec<WidgetFormula>) -> Self
pub fn formulas(self, value: Vec<WidgetFormula>) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (lines 40-43)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (lines 43-48)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (lines 43-48)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn increase_good(self, value: bool) -> Self
pub fn increase_good(self, value: bool) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 44)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 49)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 49)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn log_query(self, value: LogQueryDefinition) -> Self
pub fn network_query(self, value: LogQueryDefinition) -> Self
sourcepub fn order_by(self, value: WidgetOrderBy) -> Self
pub fn order_by(self, value: WidgetOrderBy) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 45)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 50)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 50)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn order_dir(self, value: WidgetSort) -> Self
pub fn order_dir(self, value: WidgetSort) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 46)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 51)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 51)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn process_query(self, value: ProcessQueryDefinition) -> Self
pub fn profile_metrics_query(self, value: LogQueryDefinition) -> Self
pub fn q(self, value: String) -> Self
sourcepub fn queries(self, value: Vec<FormulaAndFunctionQueryDefinition>) -> Self
pub fn queries(self, value: Vec<FormulaAndFunctionQueryDefinition>) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (lines 47-61)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (lines 52-74)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (lines 52-74)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn response_format(self, value: FormulaAndFunctionResponseFormat) -> Self
pub fn response_format(self, value: FormulaAndFunctionResponseFormat) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3562282606.rs (line 62)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83
async fn main() {
// there is a valid "slo" in the system
let slo_data_0_id = std::env::var("SLO_DATA_0_ID").unwrap();
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(WidgetDefinition::ChangeWidgetDefinition(Box::new(
ChangeWidgetDefinition::new(
vec![ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.formulas(vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string()),
])
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::ASCENDING)
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionSLOQueryDefinition(
Box::new(
FormulaAndFunctionSLOQueryDefinition::new(
FormulaAndFunctionSLODataSource::SLO,
FormulaAndFunctionSLOMeasure::SLO_STATUS,
slo_data_0_id.clone(),
)
.additional_query_filters("*".to_string())
.group_mode(FormulaAndFunctionSLOGroupMode::OVERALL)
.name("query1".to_string())
.slo_query_type(FormulaAndFunctionSLOQueryType::METRIC),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(
WidgetLegacyLiveSpan::new(),
)))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
)))
.layout(WidgetLayout::new(2, 4, 0, 0)),
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_578885732.rs (line 75)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2064651578.rs (line 75)
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::ChangeWidgetDefinition(
Box::new(
ChangeWidgetDefinition::new(
vec![
ChangeWidgetRequest::new()
.change_type(WidgetChangeType::ABSOLUTE)
.compare_to(WidgetCompareTo::HOUR_BEFORE)
.formulas(
vec![
WidgetFormula::new("hour_before(query1)".to_string()),
WidgetFormula::new("query1".to_string())
],
)
.increase_good(true)
.order_by(WidgetOrderBy::CHANGE)
.order_dir(WidgetSort::DESCENDING)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(
FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
),
),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
ChangeWidgetDefinitionType::CHANGE,
)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
).tags(Some(vec!["team:foobar".to_string()]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn rum_query(self, value: LogQueryDefinition) -> Self
pub fn security_query(self, value: LogQueryDefinition) -> Self
pub fn show_present(self, value: bool) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self