#[non_exhaustive]
pub struct CheckStatusWidgetDefinition { pub check: String, pub group: Option<String>, pub group_by: Option<Vec<String>>, pub grouping: WidgetGrouping, pub tags: Option<Vec<String>>, pub time: Option<WidgetTime>, pub title: Option<String>, pub title_align: Option<WidgetTextAlign>, pub title_size: Option<String>, pub type_: CheckStatusWidgetDefinitionType, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
Check status shows the current status or number of results for any check performed.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
check: String

Name of the check to use in the widget.

group: Option<String>

Group reporting a single check.

group_by: Option<Vec<String>>

List of tag prefixes to group by in the case of a cluster check.

grouping: WidgetGrouping

The kind of grouping to use.

tags: Option<Vec<String>>

List of tags used to filter the groups reporting a cluster check.

time: Option<WidgetTime>

Time setting for the widget.

title: Option<String>

Title of the widget.

title_align: Option<WidgetTextAlign>

How to align the text on the widget.

title_size: Option<String>

Size of the title.

type_: CheckStatusWidgetDefinitionType

Type of the check status widget.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl CheckStatusWidgetDefinition

source

pub fn new( check: String, grouping: WidgetGrouping, type_: CheckStatusWidgetDefinitionType, ) -> CheckStatusWidgetDefinition

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2607944105.rs (lines 21-25)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::CheckStatusWidgetDefinition(Box::new(
                CheckStatusWidgetDefinition::new(
                    "datadog.agent.up".to_string(),
                    WidgetGrouping::CHECK,
                    CheckStatusWidgetDefinitionType::CHECK_STATUS,
                )
                .tags(vec!["*".to_string()])
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(8, 15, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn group(self, value: String) -> Self

source

pub fn group_by(self, value: Vec<String>) -> Self

source

pub fn tags(self, value: Vec<String>) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2607944105.rs (line 26)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::CheckStatusWidgetDefinition(Box::new(
                CheckStatusWidgetDefinition::new(
                    "datadog.agent.up".to_string(),
                    WidgetGrouping::CHECK,
                    CheckStatusWidgetDefinitionType::CHECK_STATUS,
                )
                .tags(vec!["*".to_string()])
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(8, 15, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn time(self, value: WidgetTime) -> Self

source

pub fn title(self, value: String) -> Self

source

pub fn title_align(self, value: WidgetTextAlign) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2607944105.rs (line 27)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::CheckStatusWidgetDefinition(Box::new(
                CheckStatusWidgetDefinition::new(
                    "datadog.agent.up".to_string(),
                    WidgetGrouping::CHECK,
                    CheckStatusWidgetDefinitionType::CHECK_STATUS,
                )
                .tags(vec!["*".to_string()])
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(8, 15, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title_size(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2607944105.rs (line 28)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::CheckStatusWidgetDefinition(Box::new(
                CheckStatusWidgetDefinition::new(
                    "datadog.agent.up".to_string(),
                    WidgetGrouping::CHECK,
                    CheckStatusWidgetDefinitionType::CHECK_STATUS,
                )
                .tags(vec!["*".to_string()])
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(8, 15, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self