Struct datadog_api_client::datadogV1::model::model_dashboard_template_variable::DashboardTemplateVariable
source · #[non_exhaustive]pub struct DashboardTemplateVariable {
pub available_values: Option<Option<Vec<String>>>,
pub default: Option<Option<String>>,
pub defaults: Option<Vec<String>>,
pub name: String,
pub prefix: Option<Option<String>>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Template variable.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.available_values: Option<Option<Vec<String>>>The list of values that the template variable drop-down is limited to.
default: Option<Option<String>>👎Deprecated
(deprecated) The default value for the template variable on dashboard load. Cannot be used in conjunction with defaults.
defaults: Option<Vec<String>>One or many default values for template variables on load. If more than one default is specified, they will be unioned together with OR. Cannot be used in conjunction with default.
name: StringThe name of the variable.
prefix: Option<Option<String>>The tag prefix associated with the variable. Only tags with this prefix appear in the variable drop-down.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl DashboardTemplateVariable
impl DashboardTemplateVariable
sourcepub fn new(name: String) -> DashboardTemplateVariable
pub fn new(name: String) -> DashboardTemplateVariable
Examples found in repository?
examples/v1_dashboards_CreateDashboard_858397694.rs (lines 33-35)
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_2850365602.rs (lines 41-43)
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variable_presets(Some(vec![DashboardTemplateVariablePreset::new()
.name("my saved view".to_string())
.template_variables(vec![DashboardTemplateVariablePresetValue::new()
.name("datacenter".to_string())
.values(vec!["*".to_string(), "my-host".to_string()])])]))
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn available_values(self, value: Option<Vec<String>>) -> Self
pub fn available_values(self, value: Option<Vec<String>>) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_858397694.rs (lines 36-40)
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_2850365602.rs (lines 44-48)
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variable_presets(Some(vec![DashboardTemplateVariablePreset::new()
.name("my saved view".to_string())
.template_variables(vec![DashboardTemplateVariablePresetValue::new()
.name("datacenter".to_string())
.values(vec!["*".to_string(), "my-host".to_string()])])]))
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn default(self, value: Option<String>) -> Self
sourcepub fn defaults(self, value: Vec<String>) -> Self
pub fn defaults(self, value: Vec<String>) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_858397694.rs (line 41)
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_2850365602.rs (line 49)
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variable_presets(Some(vec![DashboardTemplateVariablePreset::new()
.name("my saved view".to_string())
.template_variables(vec![DashboardTemplateVariablePresetValue::new()
.name("datacenter".to_string())
.values(vec!["*".to_string(), "my-host".to_string()])])]))
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn prefix(self, value: Option<String>) -> Self
pub fn prefix(self, value: Option<String>) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_858397694.rs (line 42)
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_2850365602.rs (line 50)
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"".to_string(),
vec![Widget::new(WidgetDefinition::HostMapWidgetDefinition(
Box::new(HostMapWidgetDefinition::new(
HostMapWidgetDefinitionRequests::new()
.fill(HostMapRequest::new().q("avg:system.cpu.user{*}".to_string())),
HostMapWidgetDefinitionType::HOSTMAP,
)),
))],
)
.description(None)
.is_read_only(false)
.notify_list(Some(vec![]))
.reflow_type(DashboardReflowType::AUTO)
.restricted_roles(vec![])
.template_variable_presets(Some(vec![DashboardTemplateVariablePreset::new()
.name("my saved view".to_string())
.template_variables(vec![DashboardTemplateVariablePresetValue::new()
.name("datacenter".to_string())
.values(vec!["*".to_string(), "my-host".to_string()])])]))
.template_variables(Some(vec![DashboardTemplateVariable::new(
"host1".to_string(),
)
.available_values(Some(vec![
"my-host".to_string(),
"host1".to_string(),
"host2".to_string(),
]))
.defaults(vec!["my-host".to_string()])
.prefix(Some("host".to_string()))]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self