Struct datadog_api_client::datadogV1::model::model_event::Event

source ·
#[non_exhaustive]
pub struct Event {
Show 14 fields pub alert_type: Option<EventAlertType>, pub date_happened: Option<i64>, pub device_name: Option<String>, pub host: Option<String>, pub id: Option<i64>, pub id_str: Option<String>, pub payload: Option<String>, pub priority: Option<Option<EventPriority>>, pub source_type_name: Option<String>, pub tags: Option<Vec<String>>, pub text: Option<String>, pub title: Option<String>, pub url: Option<String>, pub additional_properties: BTreeMap<String, Value>, /* private fields */
}
Object representing an event.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
alert_type: Option<EventAlertType>

If an alert event is enabled, set its type. For example, error, warning, info, success, user_update, recommendation, and snapshot.

date_happened: Option<i64>

POSIX timestamp of the event. Must be sent as an integer (that is no quotes). Limited to events up to 18 hours in the past and two hours in the future.

device_name: Option<String>

A device name.

host: Option<String>

Host name to associate with the event. Any tags associated with the host are also applied to this event.

id: Option<i64>

Integer ID of the event.

id_str: Option<String>

Handling IDs as large 64-bit numbers can cause loss of accuracy issues with some programming languages. Instead, use the string representation of the Event ID to avoid losing accuracy.

payload: Option<String>

Payload of the event.

priority: Option<Option<EventPriority>>

The priority of the event. For example, normal or low.

source_type_name: Option<String>

The type of event being posted. Option examples include nagios, hudson, jenkins, my_apps, chef, puppet, git, bitbucket, etc. The list of standard source attribute values available here.

tags: Option<Vec<String>>

A list of tags to apply to the event.

text: Option<String>

The body of the event. Limited to 4000 characters. The text supports markdown. To use markdown in the event text, start the text block with %%% \n and end the text block with \n %%%. Use msg_text with the Datadog Ruby library.

title: Option<String>

The event title.

url: Option<String>

URL of the event.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl Event

source

pub fn new() -> Event

source

pub fn alert_type(self, value: EventAlertType) -> Self

source

pub fn date_happened(self, value: i64) -> Self

source

pub fn device_name(self, value: String) -> Self

source

pub fn host(self, value: String) -> Self

source

pub fn id(self, value: i64) -> Self

source

pub fn id_str(self, value: String) -> Self

source

pub fn payload(self, value: String) -> Self

source

pub fn priority(self, value: Option<EventPriority>) -> Self

source

pub fn source_type_name(self, value: String) -> Self

source

pub fn tags(self, value: Vec<String>) -> Self

source

pub fn text(self, value: String) -> Self

source

pub fn title(self, value: String) -> Self

source

pub fn url(self, value: String) -> Self

source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self