#[non_exhaustive]pub struct EventCreateRequest {
pub aggregation_key: Option<String>,
pub alert_type: Option<EventAlertType>,
pub date_happened: Option<i64>,
pub device_name: Option<String>,
pub host: Option<String>,
pub priority: Option<Option<EventPriority>>,
pub related_event_id: Option<i64>,
pub source_type_name: Option<String>,
pub tags: Option<Vec<String>>,
pub text: String,
pub title: String,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Object representing an event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aggregation_key: Option<String>An arbitrary string to use for aggregation. Limited to 100 characters. If you specify a key, all events using that key are grouped together in the Event Stream.
alert_type: Option<EventAlertType>If an alert event is enabled, set its type.
For example, error, warning, info, success, user_update,
recommendation, and snapshot.
date_happened: Option<i64>POSIX timestamp of the event. Must be sent as an integer (that is no quotes). Limited to events no older than 18 hours
device_name: Option<String>A device name.
host: Option<String>Host name to associate with the event. Any tags associated with the host are also applied to this event.
priority: Option<Option<EventPriority>>The priority of the event. For example, normal or low.
ID of the parent event. Must be sent as an integer (that is no quotes).
source_type_name: Option<String>The type of event being posted. Option examples include nagios, hudson, jenkins, my_apps, chef, puppet, git, bitbucket, etc. A complete list of source attribute values available here.
A list of tags to apply to the event.
text: StringThe body of the event. Limited to 4000 characters. The text supports markdown.
To use markdown in the event text, start the text block with %%% \n and end the text block with \n %%%.
Use msg_text with the Datadog Ruby library.
title: StringThe event title.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl EventCreateRequest
impl EventCreateRequest
sourcepub fn new(text: String, title: String) -> EventCreateRequest
pub fn new(text: String, title: String) -> EventCreateRequest
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let body = EventCreateRequest::new("A text message.".to_string(), "Example-Event".to_string())
.tags(vec!["test:ExampleEvent".to_string()]);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api.create_event(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let body =
EventCreateRequest::new(
"A text message.".to_string(),
"Example-Event very very very looooooooong looooooooooooong loooooooooooooooooooooong looooooooooooooooooooooooooong title with 100+ characters".to_string(),
).tags(vec!["test:ExampleEvent".to_string()]);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api.create_event(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn aggregation_key(self, value: String) -> Self
pub fn alert_type(self, value: EventAlertType) -> Self
pub fn date_happened(self, value: i64) -> Self
pub fn device_name(self, value: String) -> Self
pub fn host(self, value: String) -> Self
pub fn priority(self, value: Option<EventPriority>) -> Self
pub fn source_type_name(self, value: String) -> Self
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let body = EventCreateRequest::new("A text message.".to_string(), "Example-Event".to_string())
.tags(vec!["test:ExampleEvent".to_string()]);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api.create_event(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let body =
EventCreateRequest::new(
"A text message.".to_string(),
"Example-Event very very very looooooooong looooooooooooong loooooooooooooooooooooong looooooooooooooooooooooooooong title with 100+ characters".to_string(),
).tags(vec!["test:ExampleEvent".to_string()]);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api.create_event(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self