#[non_exhaustive]
pub struct EventStreamWidgetDefinition { pub event_size: Option<WidgetEventSize>, pub query: String, pub tags_execution: Option<String>, pub time: Option<WidgetTime>, pub title: Option<String>, pub title_align: Option<WidgetTextAlign>, pub title_size: Option<String>, pub type_: EventStreamWidgetDefinitionType, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
The event stream is a widget version of the stream of events on the Event Stream view. Only available on FREE layout dashboards.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
event_size: Option<WidgetEventSize>

Size to use to display an event.

query: String

Query to filter the event stream with.

tags_execution: Option<String>

The execution method for multi-value filters. Can be either and or or.

time: Option<WidgetTime>

Time setting for the widget.

title: Option<String>

Title of the widget.

title_align: Option<WidgetTextAlign>

How to align the text on the widget.

title_size: Option<String>

Size of the title.

type_: EventStreamWidgetDefinitionType

Type of the event stream widget.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl EventStreamWidgetDefinition

source

pub fn new( query: String, type_: EventStreamWidgetDefinitionType, ) -> EventStreamWidgetDefinition

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (lines 21-24)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn event_size(self, value: WidgetEventSize) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (line 25)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn tags_execution(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (line 26)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn time(self, value: WidgetTime) -> Self

source

pub fn title(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (line 27)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title_align(self, value: WidgetTextAlign) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (line 28)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title_size(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2634813877.rs (line 29)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventStreamWidgetDefinition(Box::new(
                EventStreamWidgetDefinition::new(
                    "example-query".to_string(),
                    EventStreamWidgetDefinitionType::EVENT_STREAM,
                )
                .event_size(WidgetEventSize::SMALL)
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(38, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self