#[non_exhaustive]
pub struct NoteWidgetDefinition { pub background_color: Option<String>, pub content: String, pub font_size: Option<String>, pub has_padding: Option<bool>, pub show_tick: Option<bool>, pub text_align: Option<WidgetTextAlign>, pub tick_edge: Option<WidgetTickEdge>, pub tick_pos: Option<String>, pub type_: NoteWidgetDefinitionType, pub vertical_align: Option<WidgetVerticalAlign>, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
The notes and links widget is similar to free text widget, but allows for more formatting options.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
background_color: Option<String>

Background color of the note.

content: String

Content of the note.

font_size: Option<String>

Size of the text.

has_padding: Option<bool>

Whether to add padding or not.

show_tick: Option<bool>

Whether to show a tick or not.

text_align: Option<WidgetTextAlign>

How to align the text on the widget.

tick_edge: Option<WidgetTickEdge>

Define how you want to align the text on the widget.

tick_pos: Option<String>

Where to position the tick on an edge.

type_: NoteWidgetDefinitionType

Type of the note widget.

vertical_align: Option<WidgetVerticalAlign>

Vertical alignment.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl NoteWidgetDefinition

source

pub fn new( content: String, type_: NoteWidgetDefinitionType, ) -> NoteWidgetDefinition

Examples found in repository?
examples/v1_dashboards_CreateDashboard_417992286.rs (line 18)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![Widget::new(WidgetDefinition::NoteWidgetDefinition(Box::new(
            NoteWidgetDefinition::new("# Example Note".to_string(), NoteWidgetDefinitionType::NOTE),
        )))
        .layout(WidgetLayout::new(24, 18, 0, 0))],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn background_color(self, value: String) -> Self

source

pub fn font_size(self, value: String) -> Self

source

pub fn has_padding(self, value: bool) -> Self

source

pub fn show_tick(self, value: bool) -> Self

source

pub fn text_align(self, value: WidgetTextAlign) -> Self

source

pub fn tick_edge(self, value: WidgetTickEdge) -> Self

source

pub fn tick_pos(self, value: String) -> Self

source

pub fn vertical_align(self, value: WidgetVerticalAlign) -> Self

source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self