Struct datadog_api_client::datadogV1::model::model_notebook_cell_update_request::NotebookCellUpdateRequest
source · #[non_exhaustive]pub struct NotebookCellUpdateRequest {
pub attributes: NotebookCellUpdateRequestAttributes,
pub id: String,
pub type_: NotebookCellResourceType,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The description of a notebook cell update request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attributes: NotebookCellUpdateRequestAttributesThe attributes of a notebook cell in update cell request. Valid cell types are markdown, timeseries, toplist, heatmap, distribution,
log_stream. More information on each graph visualization type.
id: StringNotebook cell ID.
type_: NotebookCellResourceTypeType of the Notebook Cell resource.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl NotebookCellUpdateRequest
impl NotebookCellUpdateRequest
pub fn new( attributes: NotebookCellUpdateRequestAttributes, id: String, type_: NotebookCellResourceType, ) -> NotebookCellUpdateRequest
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self