#[non_exhaustive]
pub struct QueryValueWidgetRequest {
Show 16 fields pub aggregator: Option<WidgetAggregator>, pub apm_query: Option<LogQueryDefinition>, pub audit_query: Option<LogQueryDefinition>, pub conditional_formats: Option<Vec<WidgetConditionalFormat>>, pub event_query: Option<LogQueryDefinition>, pub formulas: Option<Vec<WidgetFormula>>, pub log_query: Option<LogQueryDefinition>, pub network_query: Option<LogQueryDefinition>, pub process_query: Option<ProcessQueryDefinition>, pub profile_metrics_query: Option<LogQueryDefinition>, pub q: Option<String>, pub queries: Option<Vec<FormulaAndFunctionQueryDefinition>>, pub response_format: Option<FormulaAndFunctionResponseFormat>, pub rum_query: Option<LogQueryDefinition>, pub security_query: Option<LogQueryDefinition>, pub additional_properties: BTreeMap<String, Value>, /* private fields */
}
Updated query value widget.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
aggregator: Option<WidgetAggregator>

Aggregator used for the request.

apm_query: Option<LogQueryDefinition>

The log query.

audit_query: Option<LogQueryDefinition>

The log query.

conditional_formats: Option<Vec<WidgetConditionalFormat>>

List of conditional formats.

event_query: Option<LogQueryDefinition>

The log query.

formulas: Option<Vec<WidgetFormula>>

List of formulas that operate on queries.

log_query: Option<LogQueryDefinition>

The log query.

network_query: Option<LogQueryDefinition>

The log query.

process_query: Option<ProcessQueryDefinition>

The process query to use in the widget.

profile_metrics_query: Option<LogQueryDefinition>

The log query.

q: Option<String>

TODO.

queries: Option<Vec<FormulaAndFunctionQueryDefinition>>

List of queries that can be returned directly or used in formulas.

response_format: Option<FormulaAndFunctionResponseFormat>

Timeseries, scalar, or event list response. Event list response formats are supported by Geomap widgets.

rum_query: Option<LogQueryDefinition>

The log query.

security_query: Option<LogQueryDefinition>

The log query.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl QueryValueWidgetRequest

source

pub fn new() -> QueryValueWidgetRequest

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2644712913.rs (line 34)
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Percentile Aggregator".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "p90:dist.dd.dogweb.latency{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_dashboards_CreateDashboard_2349863258.rs (line 33)
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::FREE,
            "Example-Dashboard".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "avg:system.cpu.user{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::AVG),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(15, 47, 0, 0))
            ],
        )
            .description(Some("".to_string()))
            .is_read_only(false)
            .notify_list(Some(vec![]))
            .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_765140092.rs (line 37)
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Timeseries Background".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "sum:my.cool.count.metric{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .timeseries_background(
                                    TimeseriesBackground::new(
                                        TimeseriesBackgroundType::AREA,
                                    ).yaxis(WidgetAxis::new().include_zero(true)),
                                )
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn aggregator(self, value: WidgetAggregator) -> Self

source

pub fn apm_query(self, value: LogQueryDefinition) -> Self

source

pub fn audit_query(self, value: LogQueryDefinition) -> Self

source

pub fn conditional_formats(self, value: Vec<WidgetConditionalFormat>) -> Self

source

pub fn event_query(self, value: LogQueryDefinition) -> Self

source

pub fn formulas(self, value: Vec<WidgetFormula>) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2644712913.rs (line 35)
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Percentile Aggregator".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "p90:dist.dd.dogweb.latency{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_dashboards_CreateDashboard_765140092.rs (line 38)
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Timeseries Background".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "sum:my.cool.count.metric{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .timeseries_background(
                                    TimeseriesBackground::new(
                                        TimeseriesBackgroundType::AREA,
                                    ).yaxis(WidgetAxis::new().include_zero(true)),
                                )
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn log_query(self, value: LogQueryDefinition) -> Self

source

pub fn network_query(self, value: LogQueryDefinition) -> Self

source

pub fn process_query(self, value: ProcessQueryDefinition) -> Self

source

pub fn profile_metrics_query(self, value: LogQueryDefinition) -> Self

source

pub fn q(self, value: String) -> Self

source

pub fn queries(self, value: Vec<FormulaAndFunctionQueryDefinition>) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2644712913.rs (lines 36-49)
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Percentile Aggregator".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "p90:dist.dd.dogweb.latency{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_dashboards_CreateDashboard_2349863258.rs (lines 34-47)
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::FREE,
            "Example-Dashboard".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "avg:system.cpu.user{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::AVG),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(15, 47, 0, 0))
            ],
        )
            .description(Some("".to_string()))
            .is_read_only(false)
            .notify_list(Some(vec![]))
            .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_765140092.rs (lines 39-52)
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Timeseries Background".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "sum:my.cool.count.metric{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .timeseries_background(
                                    TimeseriesBackground::new(
                                        TimeseriesBackgroundType::AREA,
                                    ).yaxis(WidgetAxis::new().include_zero(true)),
                                )
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn response_format(self, value: FormulaAndFunctionResponseFormat) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2644712913.rs (line 50)
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Percentile Aggregator".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "p90:dist.dd.dogweb.latency{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_dashboards_CreateDashboard_2349863258.rs (line 48)
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::FREE,
            "Example-Dashboard".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "avg:system.cpu.user{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::AVG),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(15, 47, 0, 0))
            ],
        )
            .description(Some("".to_string()))
            .is_read_only(false)
            .notify_list(Some(vec![]))
            .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_765140092.rs (line 53)
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard with QVW Timeseries Background".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::QueryValueWidgetDefinition(
                        Box::new(
                            QueryValueWidgetDefinition::new(
                                vec![
                                    QueryValueWidgetRequest::new()
                                        .formulas(vec![WidgetFormula::new("query1".to_string())])
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionMetricQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionMetricQueryDefinition::new(
                                                            FormulaAndFunctionMetricDataSource::METRICS,
                                                            "query1".to_string(),
                                                            "sum:my.cool.count.metric{*}".to_string(),
                                                        ).aggregator(FormulaAndFunctionMetricAggregation::PERCENTILE),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                QueryValueWidgetDefinitionType::QUERY_VALUE,
                            )
                                .autoscale(true)
                                .precision(2)
                                .time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
                                .timeseries_background(
                                    TimeseriesBackground::new(
                                        TimeseriesBackgroundType::AREA,
                                    ).yaxis(WidgetAxis::new().include_zero(true)),
                                )
                                .title("".to_string())
                                .title_align(WidgetTextAlign::LEFT)
                                .title_size("16".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(2, 2, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn rum_query(self, value: LogQueryDefinition) -> Self

source

pub fn security_query(self, value: LogQueryDefinition) -> Self

source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self