#[non_exhaustive]
pub struct ServiceMapWidgetDefinition { pub custom_links: Option<Vec<WidgetCustomLink>>, pub filters: Vec<String>, pub service: String, pub title: Option<String>, pub title_align: Option<WidgetTextAlign>, pub title_size: Option<String>, pub type_: ServiceMapWidgetDefinitionType, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
This widget displays a map of a service to all of the services that call it, and all of the services that it calls.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
custom_links: Option<Vec<WidgetCustomLink>>

List of custom links.

filters: Vec<String>

Your environment and primary tag (or * if enabled for your account).

service: String

The ID of the service you want to map.

title: Option<String>

The title of your widget.

title_align: Option<WidgetTextAlign>

How to align the text on the widget.

title_size: Option<String>

Size of the title.

type_: ServiceMapWidgetDefinitionType

Type of the service map widget.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl ServiceMapWidgetDefinition

source

pub fn new( filters: Vec<String>, service: String, type_: ServiceMapWidgetDefinitionType, ) -> ServiceMapWidgetDefinition

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2034634967.rs (lines 20-24)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::ServiceMapWidgetDefinition(Box::new(
                ServiceMapWidgetDefinition::new(
                    vec!["env:none".to_string(), "environment:*".to_string()],
                    "".to_string(),
                    ServiceMapWidgetDefinitionType::SERVICEMAP,
                )
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(15, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2034634967.rs (line 25)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::ServiceMapWidgetDefinition(Box::new(
                ServiceMapWidgetDefinition::new(
                    vec!["env:none".to_string(), "environment:*".to_string()],
                    "".to_string(),
                    ServiceMapWidgetDefinitionType::SERVICEMAP,
                )
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(15, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title_align(self, value: WidgetTextAlign) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2034634967.rs (line 26)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::ServiceMapWidgetDefinition(Box::new(
                ServiceMapWidgetDefinition::new(
                    vec!["env:none".to_string(), "environment:*".to_string()],
                    "".to_string(),
                    ServiceMapWidgetDefinitionType::SERVICEMAP,
                )
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(15, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn title_size(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_2034634967.rs (line 27)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::ServiceMapWidgetDefinition(Box::new(
                ServiceMapWidgetDefinition::new(
                    vec!["env:none".to_string(), "environment:*".to_string()],
                    "".to_string(),
                    ServiceMapWidgetDefinitionType::SERVICEMAP,
                )
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(15, 47, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self