#[non_exhaustive]pub struct TableWidgetRequest {Show 21 fields
pub aggregator: Option<WidgetAggregator>,
pub alias: Option<String>,
pub apm_query: Option<LogQueryDefinition>,
pub apm_stats_query: Option<ApmStatsQueryDefinition>,
pub cell_display_mode: Option<Vec<TableWidgetCellDisplayMode>>,
pub conditional_formats: Option<Vec<WidgetConditionalFormat>>,
pub event_query: Option<LogQueryDefinition>,
pub formulas: Option<Vec<WidgetFormula>>,
pub limit: Option<i64>,
pub log_query: Option<LogQueryDefinition>,
pub network_query: Option<LogQueryDefinition>,
pub order: Option<WidgetSort>,
pub process_query: Option<ProcessQueryDefinition>,
pub profile_metrics_query: Option<LogQueryDefinition>,
pub q: Option<String>,
pub queries: Option<Vec<FormulaAndFunctionQueryDefinition>>,
pub response_format: Option<FormulaAndFunctionResponseFormat>,
pub rum_query: Option<LogQueryDefinition>,
pub security_query: Option<LogQueryDefinition>,
pub sort: Option<WidgetSortBy>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Updated table widget.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aggregator: Option<WidgetAggregator>Aggregator used for the request.
alias: Option<String>The column name (defaults to the metric name).
apm_query: Option<LogQueryDefinition>The log query.
apm_stats_query: Option<ApmStatsQueryDefinition>The APM stats query for table and distributions widgets.
cell_display_mode: Option<Vec<TableWidgetCellDisplayMode>>A list of display modes for each table cell.
conditional_formats: Option<Vec<WidgetConditionalFormat>>List of conditional formats.
event_query: Option<LogQueryDefinition>The log query.
formulas: Option<Vec<WidgetFormula>>List of formulas that operate on queries.
limit: Option<i64>For metric queries, the number of lines to show in the table. Only one request should have this property.
log_query: Option<LogQueryDefinition>The log query.
network_query: Option<LogQueryDefinition>The log query.
order: Option<WidgetSort>Widget sorting methods.
process_query: Option<ProcessQueryDefinition>The process query to use in the widget.
profile_metrics_query: Option<LogQueryDefinition>The log query.
q: Option<String>Query definition.
queries: Option<Vec<FormulaAndFunctionQueryDefinition>>List of queries that can be returned directly or used in formulas.
response_format: Option<FormulaAndFunctionResponseFormat>Timeseries, scalar, or event list response. Event list response formats are supported by Geomap widgets.
rum_query: Option<LogQueryDefinition>The log query.
security_query: Option<LogQueryDefinition>The log query.
sort: Option<WidgetSortBy>The controls for sorting the widget.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl TableWidgetRequest
impl TableWidgetRequest
sourcepub fn new() -> TableWidgetRequest
pub fn new() -> TableWidgetRequest
Examples found in repository?
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn aggregator(self, value: WidgetAggregator) -> Self
pub fn alias(self, value: String) -> Self
pub fn apm_query(self, value: LogQueryDefinition) -> Self
pub fn apm_stats_query(self, value: ApmStatsQueryDefinition) -> Self
pub fn cell_display_mode(self, value: Vec<TableWidgetCellDisplayMode>) -> Self
pub fn conditional_formats(self, value: Vec<WidgetConditionalFormat>) -> Self
pub fn event_query(self, value: LogQueryDefinition) -> Self
sourcepub fn formulas(self, value: Vec<WidgetFormula>) -> Self
pub fn formulas(self, value: Vec<WidgetFormula>) -> Self
Examples found in repository?
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn limit(self, value: i64) -> Self
pub fn log_query(self, value: LogQueryDefinition) -> Self
pub fn network_query(self, value: LogQueryDefinition) -> Self
pub fn order(self, value: WidgetSort) -> Self
pub fn process_query(self, value: ProcessQueryDefinition) -> Self
pub fn profile_metrics_query(self, value: LogQueryDefinition) -> Self
pub fn q(self, value: String) -> Self
sourcepub fn queries(self, value: Vec<FormulaAndFunctionQueryDefinition>) -> Self
pub fn queries(self, value: Vec<FormulaAndFunctionQueryDefinition>) -> Self
Examples found in repository?
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn response_format(self, value: FormulaAndFunctionResponseFormat) -> Self
pub fn response_format(self, value: FormulaAndFunctionResponseFormat) -> Self
Examples found in repository?
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn rum_query(self, value: LogQueryDefinition) -> Self
pub fn security_query(self, value: LogQueryDefinition) -> Self
sourcepub fn sort(self, value: WidgetSortBy) -> Self
pub fn sort(self, value: WidgetSortBy) -> Self
Examples found in repository?
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self