#[non_exhaustive]
pub struct TreeMapWidgetDefinition { pub color_by: Option<TreeMapColorBy>, pub custom_links: Option<Vec<WidgetCustomLink>>, pub group_by: Option<TreeMapGroupBy>, pub requests: Vec<TreeMapWidgetRequest>, pub size_by: Option<TreeMapSizeBy>, pub time: Option<WidgetTime>, pub title: Option<String>, pub type_: TreeMapWidgetDefinitionType, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
The treemap visualization enables you to display hierarchical and nested data. It is well suited for queries that describe part-whole relationships, such as resource usage by availability zone, data center, or team.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
color_by: Option<TreeMapColorBy>
👎Deprecated

(deprecated) The attribute formerly used to determine color in the widget.

custom_links: Option<Vec<WidgetCustomLink>>

List of custom links.

group_by: Option<TreeMapGroupBy>
👎Deprecated

(deprecated) The attribute formerly used to group elements in the widget.

requests: Vec<TreeMapWidgetRequest>

List of treemap widget requests.

size_by: Option<TreeMapSizeBy>
👎Deprecated

(deprecated) The attribute formerly used to determine size in the widget.

time: Option<WidgetTime>

Time setting for the widget.

title: Option<String>

Title of your widget.

type_: TreeMapWidgetDefinitionType

Type of the treemap widget.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl TreeMapWidgetDefinition

source

pub fn new( requests: Vec<TreeMapWidgetRequest>, type_: TreeMapWidgetDefinitionType, ) -> TreeMapWidgetDefinition

Examples found in repository?
examples/v1_dashboards_CreateDashboard_1024858348.rs (lines 31-66)
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::TreeMapWidgetDefinition(
                        Box::new(
                            TreeMapWidgetDefinition::new(
                                vec![
                                    TreeMapWidgetRequest::new()
                                        .formulas(
                                            vec![
                                                WidgetFormula::new("hour_before(query1)".to_string()),
                                                WidgetFormula::new("query1".to_string())
                                            ],
                                        )
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionEventQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionEventQueryDefinition::new(
                                                            FormulaAndFunctionEventQueryDefinitionCompute::new(
                                                                FormulaAndFunctionEventAggregation::COUNT,
                                                            ),
                                                            FormulaAndFunctionEventsDataSource::LOGS,
                                                            "query1".to_string(),
                                                        )
                                                            .group_by(vec![])
                                                            .indexes(vec!["*".to_string()])
                                                            .search(
                                                                FormulaAndFunctionEventQueryDefinitionSearch::new(
                                                                    "".to_string(),
                                                                ),
                                                            ),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                TreeMapWidgetDefinitionType::TREEMAP,
                            ).title("".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(4, 4, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn color_by(self, value: TreeMapColorBy) -> Self

source

pub fn group_by(self, value: TreeMapGroupBy) -> Self

source

pub fn size_by(self, value: TreeMapSizeBy) -> Self

source

pub fn time(self, value: WidgetTime) -> Self

source

pub fn title(self, value: String) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_1024858348.rs (line 66)
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
async fn main() {
    let body =
        Dashboard::new(
            DashboardLayoutType::ORDERED,
            "Example-Dashboard".to_string(),
            vec![
                Widget::new(
                    WidgetDefinition::TreeMapWidgetDefinition(
                        Box::new(
                            TreeMapWidgetDefinition::new(
                                vec![
                                    TreeMapWidgetRequest::new()
                                        .formulas(
                                            vec![
                                                WidgetFormula::new("hour_before(query1)".to_string()),
                                                WidgetFormula::new("query1".to_string())
                                            ],
                                        )
                                        .queries(
                                            vec![
                                                FormulaAndFunctionQueryDefinition
                                                ::FormulaAndFunctionEventQueryDefinition(
                                                    Box::new(
                                                        FormulaAndFunctionEventQueryDefinition::new(
                                                            FormulaAndFunctionEventQueryDefinitionCompute::new(
                                                                FormulaAndFunctionEventAggregation::COUNT,
                                                            ),
                                                            FormulaAndFunctionEventsDataSource::LOGS,
                                                            "query1".to_string(),
                                                        )
                                                            .group_by(vec![])
                                                            .indexes(vec!["*".to_string()])
                                                            .search(
                                                                FormulaAndFunctionEventQueryDefinitionSearch::new(
                                                                    "".to_string(),
                                                                ),
                                                            ),
                                                    ),
                                                )
                                            ],
                                        )
                                        .response_format(FormulaAndFunctionResponseFormat::SCALAR)
                                ],
                                TreeMapWidgetDefinitionType::TREEMAP,
                            ).title("".to_string()),
                        ),
                    ),
                ).layout(WidgetLayout::new(4, 4, 0, 0))
            ],
        );
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self