#[non_exhaustive]pub struct UsageHostHour {Show 18 fields
pub agent_host_count: Option<Option<i64>>,
pub alibaba_host_count: Option<Option<i64>>,
pub apm_azure_app_service_host_count: Option<Option<i64>>,
pub apm_host_count: Option<Option<i64>>,
pub aws_host_count: Option<Option<i64>>,
pub azure_host_count: Option<Option<i64>>,
pub container_count: Option<Option<i64>>,
pub gcp_host_count: Option<Option<i64>>,
pub heroku_host_count: Option<Option<i64>>,
pub host_count: Option<Option<i64>>,
pub hour: Option<Option<DateTime<Utc>>>,
pub infra_azure_app_service: Option<Option<i64>>,
pub opentelemetry_apm_host_count: Option<Option<i64>>,
pub opentelemetry_host_count: Option<Option<i64>>,
pub org_name: Option<String>,
pub public_id: Option<String>,
pub vsphere_host_count: Option<Option<i64>>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Number of hosts/containers recorded for each hour for a given organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.agent_host_count: Option<Option<i64>>Contains the total number of infrastructure hosts reporting during a given hour that were running the Datadog Agent.
alibaba_host_count: Option<Option<i64>>Contains the total number of hosts that reported through Alibaba integration (and were NOT running the Datadog Agent).
apm_azure_app_service_host_count: Option<Option<i64>>Contains the total number of Azure App Services hosts using APM.
apm_host_count: Option<Option<i64>>Shows the total number of hosts using APM during the hour, these are counted as billable (except during trial periods).
aws_host_count: Option<Option<i64>>Contains the total number of hosts that reported through the AWS integration (and were NOT running the Datadog Agent).
azure_host_count: Option<Option<i64>>Contains the total number of hosts that reported through Azure integration (and were NOT running the Datadog Agent).
container_count: Option<Option<i64>>Shows the total number of containers reported by the Docker integration during the hour.
gcp_host_count: Option<Option<i64>>Contains the total number of hosts that reported through the Google Cloud integration (and were NOT running the Datadog Agent).
heroku_host_count: Option<Option<i64>>Contains the total number of Heroku dynos reported by the Datadog Agent.
host_count: Option<Option<i64>>Contains the total number of billable infrastructure hosts reporting during a given hour.
This is the sum of agent_host_count, aws_host_count, and gcp_host_count.
hour: Option<Option<DateTime<Utc>>>The hour for the usage.
infra_azure_app_service: Option<Option<i64>>Contains the total number of hosts that reported through the Azure App Services integration (and were NOT running the Datadog Agent).
opentelemetry_apm_host_count: Option<Option<i64>>Contains the total number of hosts using APM reported by Datadog exporter for the OpenTelemetry Collector.
opentelemetry_host_count: Option<Option<i64>>Contains the total number of hosts reported by Datadog exporter for the OpenTelemetry Collector.
org_name: Option<String>The organization name.
public_id: Option<String>The organization public ID.
vsphere_host_count: Option<Option<i64>>Contains the total number of hosts that reported through vSphere integration (and were NOT running the Datadog Agent).
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl UsageHostHour
impl UsageHostHour
pub fn new() -> UsageHostHour
pub fn agent_host_count(self, value: Option<i64>) -> Self
pub fn alibaba_host_count(self, value: Option<i64>) -> Self
pub fn apm_azure_app_service_host_count(self, value: Option<i64>) -> Self
pub fn apm_host_count(self, value: Option<i64>) -> Self
pub fn aws_host_count(self, value: Option<i64>) -> Self
pub fn azure_host_count(self, value: Option<i64>) -> Self
pub fn container_count(self, value: Option<i64>) -> Self
pub fn gcp_host_count(self, value: Option<i64>) -> Self
pub fn heroku_host_count(self, value: Option<i64>) -> Self
pub fn host_count(self, value: Option<i64>) -> Self
pub fn hour(self, value: Option<DateTime<Utc>>) -> Self
pub fn infra_azure_app_service(self, value: Option<i64>) -> Self
pub fn opentelemetry_apm_host_count(self, value: Option<i64>) -> Self
pub fn opentelemetry_host_count(self, value: Option<i64>) -> Self
pub fn org_name(self, value: String) -> Self
pub fn public_id(self, value: String) -> Self
pub fn vsphere_host_count(self, value: Option<i64>) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self