#[non_exhaustive]pub struct UsageProfilingHour {
pub aas_count: Option<Option<i64>>,
pub avg_container_agent_count: Option<Option<i64>>,
pub host_count: Option<Option<i64>>,
pub hour: Option<DateTime<Utc>>,
pub org_name: Option<String>,
pub public_id: Option<String>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The number of profiled hosts for each hour for a given organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.aas_count: Option<Option<i64>>Contains the total number of profiled Azure app services reporting during a given hour.
avg_container_agent_count: Option<Option<i64>>Get average number of container agents for that hour.
host_count: Option<Option<i64>>Contains the total number of profiled hosts reporting during a given hour.
hour: Option<DateTime<Utc>>The hour for the usage.
org_name: Option<String>The organization name.
public_id: Option<String>The organization public ID.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl UsageProfilingHour
impl UsageProfilingHour
pub fn new() -> UsageProfilingHour
pub fn aas_count(self, value: Option<i64>) -> Self
pub fn avg_container_agent_count(self, value: Option<i64>) -> Self
pub fn host_count(self, value: Option<i64>) -> Self
pub fn hour(self, value: DateTime<Utc>) -> Self
pub fn org_name(self, value: String) -> Self
pub fn public_id(self, value: String) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self