#[non_exhaustive]
pub struct WidgetLayout { pub height: i64, pub is_column_break: Option<bool>, pub width: i64, pub x: i64, pub y: i64, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
The layout for a widget on a free or new dashboard layout dashboard.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
height: i64

The height of the widget. Should be a non-negative integer.

is_column_break: Option<bool>

Whether the widget should be the first one on the second column in high density or not. Note: Only for the new dashboard layout and only one widget in the dashboard should have this property set to true.

width: i64

The width of the widget. Should be a non-negative integer.

x: i64

The position of the widget on the x (horizontal) axis. Should be a non-negative integer.

y: i64

The position of the widget on the y (vertical) axis. Should be a non-negative integer.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl WidgetLayout

source

pub fn new(height: i64, width: i64, x: i64, y: i64) -> WidgetLayout

Examples found in repository?
examples/v1_dashboards_CreateDashboard_417992286.rs (line 20)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![Widget::new(WidgetDefinition::NoteWidgetDefinition(Box::new(
            NoteWidgetDefinition::new("# Example Note".to_string(), NoteWidgetDefinitionType::NOTE),
        )))
        .layout(WidgetLayout::new(24, 18, 0, 0))],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v1_dashboards_CreateDashboard_913313564.rs (line 24)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::IFrameWidgetDefinition(Box::new(
                IFrameWidgetDefinition::new(
                    IFrameWidgetDefinitionType::IFRAME,
                    "https://docs.datadoghq.com/api/latest/".to_string(),
                ),
            )))
            .layout(WidgetLayout::new(12, 12, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_651038379.rs (line 26)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::ImageWidgetDefinition(Box::new(
                ImageWidgetDefinition::new(
                    ImageWidgetDefinitionType::IMAGE,
                    "https://example.com/image.png".to_string(),
                )
                .sizing(WidgetImageSizing::COVER),
            )))
            .layout(WidgetLayout::new(12, 12, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_1738608750.rs (line 28)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::FreeTextWidgetDefinition(Box::new(
                FreeTextWidgetDefinition::new(
                    "Example free text".to_string(),
                    FreeTextWidgetDefinitionType::FREE_TEXT,
                )
                .color("#4d4d4d".to_string())
                .font_size("auto".to_string())
                .text_align(WidgetTextAlign::LEFT),
            )))
            .layout(WidgetLayout::new(6, 24, 0, 0)),
        ],
    )
    .description(None)
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_2607944105.rs (line 30)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::CheckStatusWidgetDefinition(Box::new(
                CheckStatusWidgetDefinition::new(
                    "datadog.agent.up".to_string(),
                    WidgetGrouping::CHECK,
                    CheckStatusWidgetDefinitionType::CHECK_STATUS,
                )
                .tags(vec!["*".to_string()])
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(8, 15, 0, 0)),
        ],
    )
    .description(Some("".to_string()))
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v1_dashboards_CreateDashboard_3250131584.rs (line 29)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
async fn main() {
    let body = Dashboard::new(
        DashboardLayoutType::FREE,
        "Example-Dashboard".to_string(),
        vec![
            Widget::new(WidgetDefinition::EventTimelineWidgetDefinition(Box::new(
                EventTimelineWidgetDefinition::new(
                    "status:error priority:all".to_string(),
                    EventTimelineWidgetDefinitionType::EVENT_TIMELINE,
                )
                .tags_execution("and".to_string())
                .title("".to_string())
                .title_align(WidgetTextAlign::LEFT)
                .title_size("16".to_string()),
            )))
            .layout(WidgetLayout::new(9, 47, 0, 0)),
        ],
    )
    .description(None)
    .is_read_only(false)
    .notify_list(Some(vec![]))
    .template_variables(Some(vec![]));
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn is_column_break(self, value: bool) -> Self

Examples found in repository?
examples/v1_dashboards_CreateDashboard_1754992756.rs (line 37)
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
async fn main() {
    // there is a valid "powerpack" in the system
    let powerpack_data_id = std::env::var("POWERPACK_DATA_ID").unwrap();
    let body = Dashboard::new(
        DashboardLayoutType::ORDERED,
        "Example-Dashboard with powerpack widget".to_string(),
        vec![
            Widget::new(WidgetDefinition::PowerpackWidgetDefinition(Box::new(
                PowerpackWidgetDefinition::new(
                    powerpack_data_id.clone(),
                    PowerpackWidgetDefinitionType::POWERPACK,
                )
                .template_variables(
                    PowerpackTemplateVariables::new()
                        .controlled_by_powerpack(vec![PowerpackTemplateVariableContents::new(
                            "foo".to_string(),
                            vec!["baz".to_string(), "qux".to_string(), "quuz".to_string()],
                        )
                        .prefix("bar".to_string())])
                        .controlled_externally(vec![]),
                ),
            )))
            .layout(WidgetLayout::new(2, 2, 1, 1).is_column_break(false)),
        ],
    )
    .description(Some("description".to_string()))
    .is_read_only(false);
    let configuration = datadog::Configuration::new();
    let api = DashboardsAPI::with_config(configuration);
    let resp = api.create_dashboard(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self