Module datadog_api_client::datadogV2::api::api_api_management
source · Structs
- Configure your API endpoints through the Datadog API.
- CreateOpenAPIOptionalParams is a struct for passing parameters to the method
APIManagementAPI::create_open_api - ListAPIsOptionalParams is a struct for passing parameters to the method
APIManagementAPI::list_apis - UpdateOpenAPIOptionalParams is a struct for passing parameters to the method
APIManagementAPI::update_open_api
Enums
- CreateOpenAPIError is a struct for typed errors of method
APIManagementAPI::create_open_api - DeleteOpenAPIError is a struct for typed errors of method
APIManagementAPI::delete_open_api - GetOpenAPIError is a struct for typed errors of method
APIManagementAPI::get_open_api - ListAPIsError is a struct for typed errors of method
APIManagementAPI::list_apis - UpdateOpenAPIError is a struct for typed errors of method
APIManagementAPI::update_open_api