Module datadog_api_client::datadogV2::api::api_case_management
source · Structs
- View and manage cases and projects within Case Management. See the Case Management page for more information.
- SearchCasesOptionalParams is a struct for passing parameters to the method
CaseManagementAPI::search_cases
Enums
- ArchiveCaseError is a struct for typed errors of method
CaseManagementAPI::archive_case - AssignCaseError is a struct for typed errors of method
CaseManagementAPI::assign_case - CreateCaseError is a struct for typed errors of method
CaseManagementAPI::create_case - CreateProjectError is a struct for typed errors of method
CaseManagementAPI::create_project - DeleteProjectError is a struct for typed errors of method
CaseManagementAPI::delete_project - GetCaseError is a struct for typed errors of method
CaseManagementAPI::get_case - GetProjectError is a struct for typed errors of method
CaseManagementAPI::get_project - GetProjectsError is a struct for typed errors of method
CaseManagementAPI::get_projects - SearchCasesError is a struct for typed errors of method
CaseManagementAPI::search_cases - UnarchiveCaseError is a struct for typed errors of method
CaseManagementAPI::unarchive_case - UnassignCaseError is a struct for typed errors of method
CaseManagementAPI::unassign_case - UpdatePriorityError is a struct for typed errors of method
CaseManagementAPI::update_priority - UpdateStatusError is a struct for typed errors of method
CaseManagementAPI::update_status