#[non_exhaustive]
pub struct ListCIAppTestEventsOptionalParams { pub filter_query: Option<String>, pub filter_from: Option<DateTime<Utc>>, pub filter_to: Option<DateTime<Utc>>, pub sort: Option<CIAppSort>, pub page_cursor: Option<String>, pub page_limit: Option<i32>, }
ListCIAppTestEventsOptionalParams is a struct for passing parameters to the method CIVisibilityTestsAPI::list_ci_app_test_events

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
filter_query: Option<String>

Search query following log syntax.

filter_from: Option<DateTime<Utc>>

Minimum timestamp for requested events.

filter_to: Option<DateTime<Utc>>

Maximum timestamp for requested events.

sort: Option<CIAppSort>

Order of events in results.

page_cursor: Option<String>

List following results with a cursor provided in the previous query.

page_limit: Option<i32>

Maximum number of events in the response.

Implementations

source

impl ListCIAppTestEventsOptionalParams

source

pub fn filter_query(self, value: String) -> Self

Search query following log syntax.

Examples found in repository?
examples/v2_ci-visibility-tests_ListCIAppTestEvents.rs (line 14)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let resp = api
        .list_ci_app_test_events(
            ListCIAppTestEventsOptionalParams::default()
                .filter_query("@test.service:web-ui-tests".to_string())
                .filter_from(
                    DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_from(self, value: DateTime<Utc>) -> Self

Minimum timestamp for requested events.

Examples found in repository?
examples/v2_ci-visibility-tests_ListCIAppTestEvents_3852605281.rs (lines 15-19)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let response = api.list_ci_app_test_events_with_pagination(
        ListCIAppTestEventsOptionalParams::default()
            .filter_from(
                DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .filter_to(
                DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .page_limit(2),
    );
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
More examples
Hide additional examples
examples/v2_ci-visibility-tests_ListCIAppTestEvents.rs (lines 15-19)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let resp = api
        .list_ci_app_test_events(
            ListCIAppTestEventsOptionalParams::default()
                .filter_query("@test.service:web-ui-tests".to_string())
                .filter_from(
                    DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_to(self, value: DateTime<Utc>) -> Self

Maximum timestamp for requested events.

Examples found in repository?
examples/v2_ci-visibility-tests_ListCIAppTestEvents_3852605281.rs (lines 20-24)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let response = api.list_ci_app_test_events_with_pagination(
        ListCIAppTestEventsOptionalParams::default()
            .filter_from(
                DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .filter_to(
                DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .page_limit(2),
    );
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
More examples
Hide additional examples
examples/v2_ci-visibility-tests_ListCIAppTestEvents.rs (lines 20-24)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let resp = api
        .list_ci_app_test_events(
            ListCIAppTestEventsOptionalParams::default()
                .filter_query("@test.service:web-ui-tests".to_string())
                .filter_from(
                    DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn sort(self, value: CIAppSort) -> Self

Order of events in results.

source

pub fn page_cursor(self, value: String) -> Self

List following results with a cursor provided in the previous query.

source

pub fn page_limit(self, value: i32) -> Self

Maximum number of events in the response.

Examples found in repository?
examples/v2_ci-visibility-tests_ListCIAppTestEvents_3852605281.rs (line 25)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let response = api.list_ci_app_test_events_with_pagination(
        ListCIAppTestEventsOptionalParams::default()
            .filter_from(
                DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .filter_to(
                DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                    .expect("Failed to parse datetime")
                    .with_timezone(&Utc),
            )
            .page_limit(2),
    );
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
More examples
Hide additional examples
examples/v2_ci-visibility-tests_ListCIAppTestEvents.rs (line 25)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = CIVisibilityTestsAPI::with_config(configuration);
    let resp = api
        .list_ci_app_test_events(
            ListCIAppTestEventsOptionalParams::default()
                .filter_query("@test.service:web-ui-tests".to_string())
                .filter_from(
                    DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}