Structs
- Manage your Datadog Cloudflare integration directly through the Datadog API. See the Cloudflare integration page for more information.
Enums
- CreateCloudflareAccountError is a struct for typed errors of method
CloudflareIntegrationAPI::create_cloudflare_account - DeleteCloudflareAccountError is a struct for typed errors of method
CloudflareIntegrationAPI::delete_cloudflare_account - GetCloudflareAccountError is a struct for typed errors of method
CloudflareIntegrationAPI::get_cloudflare_account - ListCloudflareAccountsError is a struct for typed errors of method
CloudflareIntegrationAPI::list_cloudflare_accounts - UpdateCloudflareAccountError is a struct for typed errors of method
CloudflareIntegrationAPI::update_cloudflare_account