#[non_exhaustive]
pub struct ListContainersOptionalParams { pub filter_tags: Option<String>, pub group_by: Option<String>, pub sort: Option<String>, pub page_size: Option<i32>, pub page_cursor: Option<String>, }
ListContainersOptionalParams is a struct for passing parameters to the method ContainersAPI::list_containers

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
filter_tags: Option<String>

Comma-separated list of tags to filter containers by.

group_by: Option<String>

Comma-separated list of tags to group containers by.

sort: Option<String>

Attribute to sort containers by.

page_size: Option<i32>

Maximum number of results returned.

page_cursor: Option<String>

String to query the next page of results. This key is provided with each valid response from the API in meta.pagination.next_cursor.

Implementations

source

impl ListContainersOptionalParams

source

pub fn filter_tags(self, value: String) -> Self

Comma-separated list of tags to filter containers by.

source

pub fn group_by(self, value: String) -> Self

Comma-separated list of tags to group containers by.

Examples found in repository?
examples/v2_containers_ListContainers_2175733917.rs (line 12)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = ContainersAPI::with_config(configuration);
    let resp = api
        .list_containers(
            ListContainersOptionalParams::default().group_by("short_image".to_string()),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn sort(self, value: String) -> Self

Attribute to sort containers by.

source

pub fn page_size(self, value: i32) -> Self

Maximum number of results returned.

Examples found in repository?
examples/v2_containers_ListContainers_931009654.rs (line 13)
9
10
11
12
13
14
15
16
17
18
19
20
21
22
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = ContainersAPI::with_config(configuration);
    let response =
        api.list_containers_with_pagination(ListContainersOptionalParams::default().page_size(2));
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
source

pub fn page_cursor(self, value: String) -> Self

String to query the next page of results. This key is provided with each valid response from the API in meta.pagination.next_cursor.