Module datadog_api_client::datadogV2::api::api_ip_allowlist
source · Structs
- The IP allowlist API is used to manage the IP addresses that can access the Datadog API and web UI. It does not block access to intake APIs or public dashboards.
Enums
- GetIPAllowlistError is a struct for typed errors of method
IPAllowlistAPI::get_ip_allowlist - UpdateIPAllowlistError is a struct for typed errors of method
IPAllowlistAPI::update_ip_allowlist