pub struct KeyManagementAPI { /* private fields */ }Expand description
Manage your Datadog API and application keys. You need an API key and an application key for a user with the required permissions to interact with these endpoints. The full list of API and application keys can be seen on your Datadog API page.
Implementations
sourceimpl KeyManagementAPI
impl KeyManagementAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.get_current_user_application_key("app_key_id".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.list_application_keys(ListApplicationKeysOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.list_current_user_application_keys(ListCurrentUserApplicationKeysOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_id = std::env::var("API_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.delete_api_key(api_key_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let body = APIKeyCreateRequest::new(APIKeyCreateData::new(
APIKeyCreateAttributes::new("Example-Key-Management".to_string()),
APIKeysType::API_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.create_api_key(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_id = std::env::var("API_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.get_api_key(api_key_data_id.clone(), GetAPIKeyOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}- examples/v2_key-management_DeleteApplicationKey.rs
- examples/v2_key-management_DeleteCurrentUserApplicationKey.rs
- examples/v2_key-management_CreateCurrentUserApplicationKey.rs
- examples/v2_key-management_ListAPIKeys.rs
- examples/v2_key-management_GetApplicationKey.rs
- examples/v2_key-management_UpdateAPIKey.rs
- examples/v2_key-management_CreateCurrentUserApplicationKey_3383369233.rs
- examples/v2_key-management_UpdateApplicationKey.rs
- examples/v2_key-management_UpdateCurrentUserApplicationKey.rs
pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_api_key(
&self,
body: APIKeyCreateRequest,
) -> Result<APIKeyResponse, Error<CreateAPIKeyError>>
pub async fn create_api_key( &self, body: APIKeyCreateRequest, ) -> Result<APIKeyResponse, Error<CreateAPIKeyError>>
Create an API key.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let body = APIKeyCreateRequest::new(APIKeyCreateData::new(
APIKeyCreateAttributes::new("Example-Key-Management".to_string()),
APIKeysType::API_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.create_api_key(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_api_key_with_http_info(
&self,
body: APIKeyCreateRequest,
) -> Result<ResponseContent<APIKeyResponse>, Error<CreateAPIKeyError>>
pub async fn create_api_key_with_http_info( &self, body: APIKeyCreateRequest, ) -> Result<ResponseContent<APIKeyResponse>, Error<CreateAPIKeyError>>
Create an API key.
sourcepub async fn create_current_user_application_key(
&self,
body: ApplicationKeyCreateRequest,
) -> Result<ApplicationKeyResponse, Error<CreateCurrentUserApplicationKeyError>>
pub async fn create_current_user_application_key( &self, body: ApplicationKeyCreateRequest, ) -> Result<ApplicationKeyResponse, Error<CreateCurrentUserApplicationKeyError>>
Create an application key for current user
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Key-Management".to_string()),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.create_current_user_application_key(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30
async fn main() {
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Key-Management".to_string()).scopes(Some(
vec![
"dashboards_read".to_string(),
"dashboards_write".to_string(),
"dashboards_public_share".to_string(),
],
)),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.create_current_user_application_key(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_current_user_application_key_with_http_info(
&self,
body: ApplicationKeyCreateRequest,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<CreateCurrentUserApplicationKeyError>>
pub async fn create_current_user_application_key_with_http_info( &self, body: ApplicationKeyCreateRequest, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<CreateCurrentUserApplicationKeyError>>
Create an application key for current user
sourcepub async fn delete_api_key(
&self,
api_key_id: String,
) -> Result<(), Error<DeleteAPIKeyError>>
pub async fn delete_api_key( &self, api_key_id: String, ) -> Result<(), Error<DeleteAPIKeyError>>
Delete an API key.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_id = std::env::var("API_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.delete_api_key(api_key_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_api_key_with_http_info(
&self,
api_key_id: String,
) -> Result<ResponseContent<()>, Error<DeleteAPIKeyError>>
pub async fn delete_api_key_with_http_info( &self, api_key_id: String, ) -> Result<ResponseContent<()>, Error<DeleteAPIKeyError>>
Delete an API key.
sourcepub async fn delete_application_key(
&self,
app_key_id: String,
) -> Result<(), Error<DeleteApplicationKeyError>>
pub async fn delete_application_key( &self, app_key_id: String, ) -> Result<(), Error<DeleteApplicationKeyError>>
Delete an application key
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "application_key" in the system
let application_key_data_id = std::env::var("APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.delete_application_key(application_key_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_application_key_with_http_info(
&self,
app_key_id: String,
) -> Result<ResponseContent<()>, Error<DeleteApplicationKeyError>>
pub async fn delete_application_key_with_http_info( &self, app_key_id: String, ) -> Result<ResponseContent<()>, Error<DeleteApplicationKeyError>>
Delete an application key
sourcepub async fn delete_current_user_application_key(
&self,
app_key_id: String,
) -> Result<(), Error<DeleteCurrentUserApplicationKeyError>>
pub async fn delete_current_user_application_key( &self, app_key_id: String, ) -> Result<(), Error<DeleteCurrentUserApplicationKeyError>>
Delete an application key owned by current user
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "application_key" in the system
let application_key_data_id = std::env::var("APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.delete_current_user_application_key(application_key_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_current_user_application_key_with_http_info(
&self,
app_key_id: String,
) -> Result<ResponseContent<()>, Error<DeleteCurrentUserApplicationKeyError>>
pub async fn delete_current_user_application_key_with_http_info( &self, app_key_id: String, ) -> Result<ResponseContent<()>, Error<DeleteCurrentUserApplicationKeyError>>
Delete an application key owned by current user
sourcepub async fn get_api_key(
&self,
api_key_id: String,
params: GetAPIKeyOptionalParams,
) -> Result<APIKeyResponse, Error<GetAPIKeyError>>
pub async fn get_api_key( &self, api_key_id: String, params: GetAPIKeyOptionalParams, ) -> Result<APIKeyResponse, Error<GetAPIKeyError>>
Get an API key.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_id = std::env::var("API_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.get_api_key(api_key_data_id.clone(), GetAPIKeyOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_api_key_with_http_info(
&self,
api_key_id: String,
params: GetAPIKeyOptionalParams,
) -> Result<ResponseContent<APIKeyResponse>, Error<GetAPIKeyError>>
pub async fn get_api_key_with_http_info( &self, api_key_id: String, params: GetAPIKeyOptionalParams, ) -> Result<ResponseContent<APIKeyResponse>, Error<GetAPIKeyError>>
Get an API key.
sourcepub async fn get_application_key(
&self,
app_key_id: String,
params: GetApplicationKeyOptionalParams,
) -> Result<ApplicationKeyResponse, Error<GetApplicationKeyError>>
pub async fn get_application_key( &self, app_key_id: String, params: GetApplicationKeyOptionalParams, ) -> Result<ApplicationKeyResponse, Error<GetApplicationKeyError>>
Get an application key for your org.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
// there is a valid "application_key" in the system
let application_key_data_id = std::env::var("APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.get_application_key(
application_key_data_id.clone(),
GetApplicationKeyOptionalParams::default(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_application_key_with_http_info(
&self,
app_key_id: String,
params: GetApplicationKeyOptionalParams,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<GetApplicationKeyError>>
pub async fn get_application_key_with_http_info( &self, app_key_id: String, params: GetApplicationKeyOptionalParams, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<GetApplicationKeyError>>
Get an application key for your org.
sourcepub async fn get_current_user_application_key(
&self,
app_key_id: String,
) -> Result<ApplicationKeyResponse, Error<GetCurrentUserApplicationKeyError>>
pub async fn get_current_user_application_key( &self, app_key_id: String, ) -> Result<ApplicationKeyResponse, Error<GetCurrentUserApplicationKeyError>>
Get an application key owned by current user
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.get_current_user_application_key("app_key_id".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_current_user_application_key_with_http_info(
&self,
app_key_id: String,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<GetCurrentUserApplicationKeyError>>
pub async fn get_current_user_application_key_with_http_info( &self, app_key_id: String, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<GetCurrentUserApplicationKeyError>>
Get an application key owned by current user
sourcepub async fn list_api_keys(
&self,
params: ListAPIKeysOptionalParams,
) -> Result<APIKeysResponse, Error<ListAPIKeysError>>
pub async fn list_api_keys( &self, params: ListAPIKeysOptionalParams, ) -> Result<APIKeysResponse, Error<ListAPIKeysError>>
List all API keys available for your account.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_attributes_name = std::env::var("API_KEY_DATA_ATTRIBUTES_NAME").unwrap();
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.list_api_keys(
ListAPIKeysOptionalParams::default().filter(api_key_data_attributes_name.clone()),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_api_keys_with_http_info(
&self,
params: ListAPIKeysOptionalParams,
) -> Result<ResponseContent<APIKeysResponse>, Error<ListAPIKeysError>>
pub async fn list_api_keys_with_http_info( &self, params: ListAPIKeysOptionalParams, ) -> Result<ResponseContent<APIKeysResponse>, Error<ListAPIKeysError>>
List all API keys available for your account.
sourcepub async fn list_application_keys(
&self,
params: ListApplicationKeysOptionalParams,
) -> Result<ListApplicationKeysResponse, Error<ListApplicationKeysError>>
pub async fn list_application_keys( &self, params: ListApplicationKeysOptionalParams, ) -> Result<ListApplicationKeysResponse, Error<ListApplicationKeysError>>
List all application keys available for your org
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.list_application_keys(ListApplicationKeysOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_application_keys_with_http_info(
&self,
params: ListApplicationKeysOptionalParams,
) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListApplicationKeysError>>
pub async fn list_application_keys_with_http_info( &self, params: ListApplicationKeysOptionalParams, ) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListApplicationKeysError>>
List all application keys available for your org
sourcepub async fn list_current_user_application_keys(
&self,
params: ListCurrentUserApplicationKeysOptionalParams,
) -> Result<ListApplicationKeysResponse, Error<ListCurrentUserApplicationKeysError>>
pub async fn list_current_user_application_keys( &self, params: ListCurrentUserApplicationKeysOptionalParams, ) -> Result<ListApplicationKeysResponse, Error<ListCurrentUserApplicationKeysError>>
List all application keys available for current user
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.list_current_user_application_keys(ListCurrentUserApplicationKeysOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_current_user_application_keys_with_http_info(
&self,
params: ListCurrentUserApplicationKeysOptionalParams,
) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListCurrentUserApplicationKeysError>>
pub async fn list_current_user_application_keys_with_http_info( &self, params: ListCurrentUserApplicationKeysOptionalParams, ) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListCurrentUserApplicationKeysError>>
List all application keys available for current user
sourcepub async fn update_api_key(
&self,
api_key_id: String,
body: APIKeyUpdateRequest,
) -> Result<APIKeyResponse, Error<UpdateAPIKeyError>>
pub async fn update_api_key( &self, api_key_id: String, body: APIKeyUpdateRequest, ) -> Result<APIKeyResponse, Error<UpdateAPIKeyError>>
Update an API key.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
// there is a valid "api_key" in the system
let api_key_data_id = std::env::var("API_KEY_DATA_ID").unwrap();
let body = APIKeyUpdateRequest::new(APIKeyUpdateData::new(
APIKeyUpdateAttributes::new("Example-Key-Management".to_string()),
api_key_data_id.clone(),
APIKeysType::API_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api.update_api_key(api_key_data_id.clone(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_api_key_with_http_info(
&self,
api_key_id: String,
body: APIKeyUpdateRequest,
) -> Result<ResponseContent<APIKeyResponse>, Error<UpdateAPIKeyError>>
pub async fn update_api_key_with_http_info( &self, api_key_id: String, body: APIKeyUpdateRequest, ) -> Result<ResponseContent<APIKeyResponse>, Error<UpdateAPIKeyError>>
Update an API key.
sourcepub async fn update_application_key(
&self,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<ApplicationKeyResponse, Error<UpdateApplicationKeyError>>
pub async fn update_application_key( &self, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<ApplicationKeyResponse, Error<UpdateApplicationKeyError>>
Edit an application key
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
async fn main() {
// there is a valid "application_key" in the system
let application_key_data_id = std::env::var("APPLICATION_KEY_DATA_ID").unwrap();
let body = ApplicationKeyUpdateRequest::new(ApplicationKeyUpdateData::new(
ApplicationKeyUpdateAttributes::new()
.name("Application Key for managing dashboards-updated".to_string()),
application_key_data_id.clone(),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.update_application_key(application_key_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_application_key_with_http_info(
&self,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<UpdateApplicationKeyError>>
pub async fn update_application_key_with_http_info( &self, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<UpdateApplicationKeyError>>
Edit an application key
sourcepub async fn update_current_user_application_key(
&self,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<ApplicationKeyResponse, Error<UpdateCurrentUserApplicationKeyError>>
pub async fn update_current_user_application_key( &self, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<ApplicationKeyResponse, Error<UpdateCurrentUserApplicationKeyError>>
Edit an application key owned by current user
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29
async fn main() {
// there is a valid "application_key" in the system
let application_key_data_id = std::env::var("APPLICATION_KEY_DATA_ID").unwrap();
let body = ApplicationKeyUpdateRequest::new(ApplicationKeyUpdateData::new(
ApplicationKeyUpdateAttributes::new()
.name("Application Key for managing dashboards-updated".to_string()),
application_key_data_id.clone(),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = KeyManagementAPI::with_config(configuration);
let resp = api
.update_current_user_application_key(application_key_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_current_user_application_key_with_http_info(
&self,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<UpdateCurrentUserApplicationKeyError>>
pub async fn update_current_user_application_key_with_http_info( &self, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<UpdateCurrentUserApplicationKeyError>>
Edit an application key owned by current user