Struct datadog_api_client::datadogV2::api::api_key_management::ListCurrentUserApplicationKeysOptionalParams
source · #[non_exhaustive]pub struct ListCurrentUserApplicationKeysOptionalParams {
pub page_size: Option<i64>,
pub page_number: Option<i64>,
pub sort: Option<ApplicationKeysSort>,
pub filter: Option<String>,
pub filter_created_at_start: Option<String>,
pub filter_created_at_end: Option<String>,
pub include: Option<String>,
}Expand description
ListCurrentUserApplicationKeysOptionalParams is a struct for passing parameters to the method KeyManagementAPI::list_current_user_application_keys
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.page_size: Option<i64>Size for a given page. The maximum allowed value is 100.
page_number: Option<i64>Specific page number to return.
sort: Option<ApplicationKeysSort>Application key attribute used to sort results. Sort order is ascending by default. In order to specify a descending sort, prefix the attribute with a minus sign.
filter: Option<String>Filter application keys by the specified string.
filter_created_at_start: Option<String>Only include application keys created on or after the specified date.
filter_created_at_end: Option<String>Only include application keys created on or before the specified date.
include: Option<String>Resource path for related resources to include in the response. Only owned_by is supported.
Implementations
sourceimpl ListCurrentUserApplicationKeysOptionalParams
impl ListCurrentUserApplicationKeysOptionalParams
sourcepub fn page_size(self, value: i64) -> Self
pub fn page_size(self, value: i64) -> Self
Size for a given page. The maximum allowed value is 100.
sourcepub fn page_number(self, value: i64) -> Self
pub fn page_number(self, value: i64) -> Self
Specific page number to return.
sourcepub fn sort(self, value: ApplicationKeysSort) -> Self
pub fn sort(self, value: ApplicationKeysSort) -> Self
Application key attribute used to sort results. Sort order is ascending by default. In order to specify a descending sort, prefix the attribute with a minus sign.
sourcepub fn filter_created_at_start(self, value: String) -> Self
pub fn filter_created_at_start(self, value: String) -> Self
Only include application keys created on or after the specified date.
sourcepub fn filter_created_at_end(self, value: String) -> Self
pub fn filter_created_at_end(self, value: String) -> Self
Only include application keys created on or before the specified date.