Module datadog_api_client::datadogV2::api::api_logs
source · Structs
- ListLogsGetOptionalParams is a struct for passing parameters to the method
LogsAPI::list_logs_get - ListLogsOptionalParams is a struct for passing parameters to the method
LogsAPI::list_logs - Search your logs and send them to your Datadog platform over HTTP. See the Log Management page for more information.
- SubmitLogOptionalParams is a struct for passing parameters to the method
LogsAPI::submit_log
Enums
- AggregateLogsError is a struct for typed errors of method
LogsAPI::aggregate_logs - ListLogsError is a struct for typed errors of method
LogsAPI::list_logs - ListLogsGetError is a struct for typed errors of method
LogsAPI::list_logs_get - SubmitLogError is a struct for typed errors of method
LogsAPI::submit_log