#[non_exhaustive]
pub struct ListLogsGetOptionalParams { pub filter_query: Option<String>, pub filter_indexes: Option<Vec<String>>, pub filter_from: Option<DateTime<Utc>>, pub filter_to: Option<DateTime<Utc>>, pub filter_storage_tier: Option<LogsStorageTier>, pub sort: Option<LogsSort>, pub page_cursor: Option<String>, pub page_limit: Option<i32>, }
ListLogsGetOptionalParams is a struct for passing parameters to the method LogsAPI::list_logs_get

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
filter_query: Option<String>

Search query following logs syntax.

filter_indexes: Option<Vec<String>>

For customers with multiple indexes, the indexes to search. Defaults to ‘*’ which means all indexes

filter_from: Option<DateTime<Utc>>

Minimum timestamp for requested logs.

filter_to: Option<DateTime<Utc>>

Maximum timestamp for requested logs.

filter_storage_tier: Option<LogsStorageTier>

Specifies the storage type to be used

sort: Option<LogsSort>

Order of logs in results.

page_cursor: Option<String>

List following results with a cursor provided in the previous query.

page_limit: Option<i32>

Maximum number of logs in the response.

Implementations

source

impl ListLogsGetOptionalParams

source

pub fn filter_query(self, value: String) -> Self

Search query following logs syntax.

Examples found in repository?
examples/v2_logs_ListLogsGet_2034110533.rs (line 14)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .list_logs_get(
            ListLogsGetOptionalParams::default()
                .filter_query("datadog-agent".to_string())
                .filter_indexes(vec!["main".to_string()])
                .filter_from(
                    DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_indexes(self, value: Vec<String>) -> Self

For customers with multiple indexes, the indexes to search. Defaults to ‘*’ which means all indexes

Examples found in repository?
examples/v2_logs_ListLogsGet_2034110533.rs (line 15)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .list_logs_get(
            ListLogsGetOptionalParams::default()
                .filter_query("datadog-agent".to_string())
                .filter_indexes(vec!["main".to_string()])
                .filter_from(
                    DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_from(self, value: DateTime<Utc>) -> Self

Minimum timestamp for requested logs.

Examples found in repository?
examples/v2_logs_ListLogsGet_2034110533.rs (lines 16-20)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .list_logs_get(
            ListLogsGetOptionalParams::default()
                .filter_query("datadog-agent".to_string())
                .filter_indexes(vec!["main".to_string()])
                .filter_from(
                    DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_to(self, value: DateTime<Utc>) -> Self

Maximum timestamp for requested logs.

Examples found in repository?
examples/v2_logs_ListLogsGet_2034110533.rs (lines 21-25)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .list_logs_get(
            ListLogsGetOptionalParams::default()
                .filter_query("datadog-agent".to_string())
                .filter_indexes(vec!["main".to_string()])
                .filter_from(
                    DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter_storage_tier(self, value: LogsStorageTier) -> Self

Specifies the storage type to be used

source

pub fn sort(self, value: LogsSort) -> Self

Order of logs in results.

source

pub fn page_cursor(self, value: String) -> Self

List following results with a cursor provided in the previous query.

source

pub fn page_limit(self, value: i32) -> Self

Maximum number of logs in the response.

Examples found in repository?
examples/v2_logs_ListLogsGet_738202670.rs (line 13)
9
10
11
12
13
14
15
16
17
18
19
20
21
22
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let response =
        api.list_logs_get_with_pagination(ListLogsGetOptionalParams::default().page_limit(2));
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
More examples
Hide additional examples
examples/v2_logs_ListLogsGet_2034110533.rs (line 26)
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = LogsAPI::with_config(configuration);
    let resp = api
        .list_logs_get(
            ListLogsGetOptionalParams::default()
                .filter_query("datadog-agent".to_string())
                .filter_indexes(vec!["main".to_string()])
                .filter_from(
                    DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .filter_to(
                    DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
                        .expect("Failed to parse datetime")
                        .with_timezone(&Utc),
                )
                .page_limit(5),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}