pub struct MonitorsAPI { /* private fields */ }
Monitors allow you to watch a metric or check that you care about and notifies your team when a defined threshold has exceeded.

For more information, see Creating Monitors and Tag Policies.

Implementations

source

impl MonitorsAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v2_monitors_ListMonitorConfigPolicies.rs (line 8)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api.list_monitor_config_policies().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v2_monitors_GetMonitorConfigPolicy.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .get_monitor_config_policy(monitor_configuration_policy_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_monitors_DeleteMonitorConfigPolicy.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .delete_monitor_config_policy(monitor_configuration_policy_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_monitors_CreateMonitorConfigPolicy.rs (line 28)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
async fn main() {
    let body = MonitorConfigPolicyCreateRequest::new(MonitorConfigPolicyCreateData::new(
        MonitorConfigPolicyAttributeCreateRequest::new(
            MonitorConfigPolicyPolicyCreateRequest::MonitorConfigPolicyTagPolicyCreateRequest(
                Box::new(MonitorConfigPolicyTagPolicyCreateRequest::new(
                    "examplemonitor".to_string(),
                    false,
                    vec!["prod".to_string(), "staging".to_string()],
                )),
            ),
            MonitorConfigPolicyType::TAG,
        ),
        MonitorConfigPolicyResourceType::MONITOR_CONFIG_POLICY,
    ));
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api.create_monitor_config_policy(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_monitors_UpdateMonitorConfigPolicy.rs (line 31)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let body = MonitorConfigPolicyEditRequest::new(MonitorConfigPolicyEditData::new(
        MonitorConfigPolicyAttributeEditRequest::new(
            MonitorConfigPolicyPolicy::MonitorConfigPolicyTagPolicy(Box::new(
                MonitorConfigPolicyTagPolicy::new()
                    .tag_key("examplemonitor".to_string())
                    .tag_key_required(false)
                    .valid_tag_values(vec!["prod".to_string(), "staging".to_string()]),
            )),
            MonitorConfigPolicyType::TAG,
        ),
        monitor_configuration_policy_data_id.clone(),
        MonitorConfigPolicyResourceType::MONITOR_CONFIG_POLICY,
    ));
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .update_monitor_config_policy(monitor_configuration_policy_data_id.clone(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn create_monitor_config_policy( &self, body: MonitorConfigPolicyCreateRequest, ) -> Result<MonitorConfigPolicyResponse, Error<CreateMonitorConfigPolicyError>>

Create a monitor configuration policy.

Examples found in repository?
examples/v2_monitors_CreateMonitorConfigPolicy.rs (line 29)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
async fn main() {
    let body = MonitorConfigPolicyCreateRequest::new(MonitorConfigPolicyCreateData::new(
        MonitorConfigPolicyAttributeCreateRequest::new(
            MonitorConfigPolicyPolicyCreateRequest::MonitorConfigPolicyTagPolicyCreateRequest(
                Box::new(MonitorConfigPolicyTagPolicyCreateRequest::new(
                    "examplemonitor".to_string(),
                    false,
                    vec!["prod".to_string(), "staging".to_string()],
                )),
            ),
            MonitorConfigPolicyType::TAG,
        ),
        MonitorConfigPolicyResourceType::MONITOR_CONFIG_POLICY,
    ));
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api.create_monitor_config_policy(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_monitor_config_policy_with_http_info( &self, body: MonitorConfigPolicyCreateRequest, ) -> Result<ResponseContent<MonitorConfigPolicyResponse>, Error<CreateMonitorConfigPolicyError>>

Create a monitor configuration policy.

source

pub async fn delete_monitor_config_policy( &self, policy_id: String, ) -> Result<(), Error<DeleteMonitorConfigPolicyError>>

Delete a monitor configuration policy.

Examples found in repository?
examples/v2_monitors_DeleteMonitorConfigPolicy.rs (line 13)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .delete_monitor_config_policy(monitor_configuration_policy_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn delete_monitor_config_policy_with_http_info( &self, policy_id: String, ) -> Result<ResponseContent<()>, Error<DeleteMonitorConfigPolicyError>>

Delete a monitor configuration policy.

source

pub async fn get_monitor_config_policy( &self, policy_id: String, ) -> Result<MonitorConfigPolicyResponse, Error<GetMonitorConfigPolicyError>>

Get a monitor configuration policy by policy_id.

Examples found in repository?
examples/v2_monitors_GetMonitorConfigPolicy.rs (line 13)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .get_monitor_config_policy(monitor_configuration_policy_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_monitor_config_policy_with_http_info( &self, policy_id: String, ) -> Result<ResponseContent<MonitorConfigPolicyResponse>, Error<GetMonitorConfigPolicyError>>

Get a monitor configuration policy by policy_id.

source

pub async fn list_monitor_config_policies( &self, ) -> Result<MonitorConfigPolicyListResponse, Error<ListMonitorConfigPoliciesError>>

Get all monitor configuration policies.

Examples found in repository?
examples/v2_monitors_ListMonitorConfigPolicies.rs (line 9)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api.list_monitor_config_policies().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_monitor_config_policies_with_http_info( &self, ) -> Result<ResponseContent<MonitorConfigPolicyListResponse>, Error<ListMonitorConfigPoliciesError>>

Get all monitor configuration policies.

source

pub async fn update_monitor_config_policy( &self, policy_id: String, body: MonitorConfigPolicyEditRequest, ) -> Result<MonitorConfigPolicyResponse, Error<UpdateMonitorConfigPolicyError>>

Edit a monitor configuration policy.

Examples found in repository?
examples/v2_monitors_UpdateMonitorConfigPolicy.rs (line 33)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
async fn main() {
    // there is a valid "monitor_configuration_policy" in the system
    let monitor_configuration_policy_data_id =
        std::env::var("MONITOR_CONFIGURATION_POLICY_DATA_ID").unwrap();
    let body = MonitorConfigPolicyEditRequest::new(MonitorConfigPolicyEditData::new(
        MonitorConfigPolicyAttributeEditRequest::new(
            MonitorConfigPolicyPolicy::MonitorConfigPolicyTagPolicy(Box::new(
                MonitorConfigPolicyTagPolicy::new()
                    .tag_key("examplemonitor".to_string())
                    .tag_key_required(false)
                    .valid_tag_values(vec!["prod".to_string(), "staging".to_string()]),
            )),
            MonitorConfigPolicyType::TAG,
        ),
        monitor_configuration_policy_data_id.clone(),
        MonitorConfigPolicyResourceType::MONITOR_CONFIG_POLICY,
    ));
    let configuration = datadog::Configuration::new();
    let api = MonitorsAPI::with_config(configuration);
    let resp = api
        .update_monitor_config_policy(monitor_configuration_policy_data_id.clone(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn update_monitor_config_policy_with_http_info( &self, policy_id: String, body: MonitorConfigPolicyEditRequest, ) -> Result<ResponseContent<MonitorConfigPolicyResponse>, Error<UpdateMonitorConfigPolicyError>>

Edit a monitor configuration policy.