pub struct OpsgenieIntegrationAPI { /* private fields */ }
Configure your Datadog Opsgenie integration directly through the Datadog API.

Implementations

source

impl OpsgenieIntegrationAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v2_opsgenie-integration_ListOpsgenieServices.rs (line 8)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api.list_opsgenie_services().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v2_opsgenie-integration_GetOpsgenieService.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .get_opsgenie_service(opsgenie_service_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_opsgenie-integration_DeleteOpsgenieService.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .delete_opsgenie_service(opsgenie_service_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_opsgenie-integration_CreateOpsgenieService.rs (line 21)
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    let body = OpsgenieServiceCreateRequest::new(OpsgenieServiceCreateData::new(
        OpsgenieServiceCreateAttributes::new(
            "Example-Opsgenie-Integration".to_string(),
            "00000000-0000-0000-0000-000000000000".to_string(),
            OpsgenieServiceRegionType::US,
        ),
        OpsgenieServiceType::OPSGENIE_SERVICE,
    ));
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api.create_opsgenie_service(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_opsgenie-integration_UpdateOpsgenieService.rs (line 23)
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let body = OpsgenieServiceUpdateRequest::new(OpsgenieServiceUpdateData::new(
        OpsgenieServiceUpdateAttributes::new()
            .name("fake-opsgenie-service-name--updated".to_string())
            .opsgenie_api_key("00000000-0000-0000-0000-000000000000".to_string())
            .region(OpsgenieServiceRegionType::EU),
        opsgenie_service_data_id.clone(),
        OpsgenieServiceType::OPSGENIE_SERVICE,
    ));
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .update_opsgenie_service(opsgenie_service_data_id.clone(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn create_opsgenie_service( &self, body: OpsgenieServiceCreateRequest, ) -> Result<OpsgenieServiceResponse, Error<CreateOpsgenieServiceError>>

Create a new service object in the Opsgenie integration.

Examples found in repository?
examples/v2_opsgenie-integration_CreateOpsgenieService.rs (line 22)
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    let body = OpsgenieServiceCreateRequest::new(OpsgenieServiceCreateData::new(
        OpsgenieServiceCreateAttributes::new(
            "Example-Opsgenie-Integration".to_string(),
            "00000000-0000-0000-0000-000000000000".to_string(),
            OpsgenieServiceRegionType::US,
        ),
        OpsgenieServiceType::OPSGENIE_SERVICE,
    ));
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api.create_opsgenie_service(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_opsgenie_service_with_http_info( &self, body: OpsgenieServiceCreateRequest, ) -> Result<ResponseContent<OpsgenieServiceResponse>, Error<CreateOpsgenieServiceError>>

Create a new service object in the Opsgenie integration.

source

pub async fn delete_opsgenie_service( &self, integration_service_id: String, ) -> Result<(), Error<DeleteOpsgenieServiceError>>

Delete a single service object in the Datadog Opsgenie integration.

Examples found in repository?
examples/v2_opsgenie-integration_DeleteOpsgenieService.rs (line 12)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .delete_opsgenie_service(opsgenie_service_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn delete_opsgenie_service_with_http_info( &self, integration_service_id: String, ) -> Result<ResponseContent<()>, Error<DeleteOpsgenieServiceError>>

Delete a single service object in the Datadog Opsgenie integration.

source

pub async fn get_opsgenie_service( &self, integration_service_id: String, ) -> Result<OpsgenieServiceResponse, Error<GetOpsgenieServiceError>>

Get a single service from the Datadog Opsgenie integration.

Examples found in repository?
examples/v2_opsgenie-integration_GetOpsgenieService.rs (line 12)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .get_opsgenie_service(opsgenie_service_data_id.clone())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_opsgenie_service_with_http_info( &self, integration_service_id: String, ) -> Result<ResponseContent<OpsgenieServiceResponse>, Error<GetOpsgenieServiceError>>

Get a single service from the Datadog Opsgenie integration.

source

pub async fn list_opsgenie_services( &self, ) -> Result<OpsgenieServicesResponse, Error<ListOpsgenieServicesError>>

Get a list of all services from the Datadog Opsgenie integration.

Examples found in repository?
examples/v2_opsgenie-integration_ListOpsgenieServices.rs (line 9)
6
7
8
9
10
11
12
13
14
15
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api.list_opsgenie_services().await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_opsgenie_services_with_http_info( &self, ) -> Result<ResponseContent<OpsgenieServicesResponse>, Error<ListOpsgenieServicesError>>

Get a list of all services from the Datadog Opsgenie integration.

source

pub async fn update_opsgenie_service( &self, integration_service_id: String, body: OpsgenieServiceUpdateRequest, ) -> Result<OpsgenieServiceResponse, Error<UpdateOpsgenieServiceError>>

Update a single service object in the Datadog Opsgenie integration.

Examples found in repository?
examples/v2_opsgenie-integration_UpdateOpsgenieService.rs (line 25)
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
async fn main() {
    // there is a valid "opsgenie_service" in the system
    let opsgenie_service_data_id = std::env::var("OPSGENIE_SERVICE_DATA_ID").unwrap();
    let body = OpsgenieServiceUpdateRequest::new(OpsgenieServiceUpdateData::new(
        OpsgenieServiceUpdateAttributes::new()
            .name("fake-opsgenie-service-name--updated".to_string())
            .opsgenie_api_key("00000000-0000-0000-0000-000000000000".to_string())
            .region(OpsgenieServiceRegionType::EU),
        opsgenie_service_data_id.clone(),
        OpsgenieServiceType::OPSGENIE_SERVICE,
    ));
    let configuration = datadog::Configuration::new();
    let api = OpsgenieIntegrationAPI::with_config(configuration);
    let resp = api
        .update_opsgenie_service(opsgenie_service_data_id.clone(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn update_opsgenie_service_with_http_info( &self, integration_service_id: String, body: OpsgenieServiceUpdateRequest, ) -> Result<ResponseContent<OpsgenieServiceResponse>, Error<UpdateOpsgenieServiceError>>

Update a single service object in the Datadog Opsgenie integration.