Module datadog_api_client::datadogV2::api::api_rum
source · Structs
- ListRUMEventsOptionalParams is a struct for passing parameters to the method
RUMAPI::list_rum_events - Manage your Real User Monitoring (RUM) applications, and search or aggregate your RUM events over HTTP. See the RUM & Session Replay page for more information
Enums
- AggregateRUMEventsError is a struct for typed errors of method
RUMAPI::aggregate_rum_events - CreateRUMApplicationError is a struct for typed errors of method
RUMAPI::create_rum_application - DeleteRUMApplicationError is a struct for typed errors of method
RUMAPI::delete_rum_application - GetRUMApplicationError is a struct for typed errors of method
RUMAPI::get_rum_application - GetRUMApplicationsError is a struct for typed errors of method
RUMAPI::get_rum_applications - ListRUMEventsError is a struct for typed errors of method
RUMAPI::list_rum_events - SearchRUMEventsError is a struct for typed errors of method
RUMAPI::search_rum_events - UpdateRUMApplicationError is a struct for typed errors of method
RUMAPI::update_rum_application