#[non_exhaustive]
pub struct ListFindingsOptionalParams { pub page_limit: Option<i64>, pub snapshot_timestamp: Option<i64>, pub page_cursor: Option<String>, pub filter_tags: Option<String>, pub filter_evaluation_changed_at: Option<String>, pub filter_muted: Option<bool>, pub filter_rule_id: Option<String>, pub filter_rule_name: Option<String>, pub filter_resource_type: Option<String>, pub filter_discovery_timestamp: Option<String>, pub filter_evaluation: Option<FindingEvaluation>, pub filter_status: Option<FindingStatus>, }
ListFindingsOptionalParams is a struct for passing parameters to the method SecurityMonitoringAPI::list_findings

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
page_limit: Option<i64>

Limit the number of findings returned. Must be <= 1000.

snapshot_timestamp: Option<i64>

Return findings for a given snapshot of time (Unix ms).

page_cursor: Option<String>

Return the next page of findings pointed to by the cursor.

filter_tags: Option<String>

Return findings that have these associated tags (repeatable).

filter_evaluation_changed_at: Option<String>

Return findings that have changed from pass to fail or vice versa on a specified date (Unix ms) or date range (using comparison operators).

filter_muted: Option<bool>

Set to true to return findings that are muted. Set to false to return unmuted findings.

filter_rule_id: Option<String>

Return findings for the specified rule ID.

filter_rule_name: Option<String>

Return findings for the specified rule.

filter_resource_type: Option<String>

Return only findings for the specified resource type.

filter_discovery_timestamp: Option<String>

Return findings that were found on a specified date (Unix ms) or date range (using comparison operators).

filter_evaluation: Option<FindingEvaluation>

Return only pass or fail findings.

filter_status: Option<FindingStatus>

Return only findings with the specified status.

Implementations

source

impl ListFindingsOptionalParams

source

pub fn page_limit(self, value: i64) -> Self

Limit the number of findings returned. Must be <= 1000.

source

pub fn snapshot_timestamp(self, value: i64) -> Self

Return findings for a given snapshot of time (Unix ms).

source

pub fn page_cursor(self, value: String) -> Self

Return the next page of findings pointed to by the cursor.

source

pub fn filter_tags(self, value: String) -> Self

Return findings that have these associated tags (repeatable).

source

pub fn filter_evaluation_changed_at(self, value: String) -> Self

Return findings that have changed from pass to fail or vice versa on a specified date (Unix ms) or date range (using comparison operators).

source

pub fn filter_muted(self, value: bool) -> Self

Set to true to return findings that are muted. Set to false to return unmuted findings.

source

pub fn filter_rule_id(self, value: String) -> Self

Return findings for the specified rule ID.

source

pub fn filter_rule_name(self, value: String) -> Self

Return findings for the specified rule.

source

pub fn filter_resource_type(self, value: String) -> Self

Return only findings for the specified resource type.

source

pub fn filter_discovery_timestamp(self, value: String) -> Self

Return findings that were found on a specified date (Unix ms) or date range (using comparison operators).

source

pub fn filter_evaluation(self, value: FindingEvaluation) -> Self

Return only pass or fail findings.

source

pub fn filter_status(self, value: FindingStatus) -> Self

Return only findings with the specified status.