Structs
- Create, update, delete, and retrieve sensitive data scanner groups and rules. See the Sensitive Data Scanner page for more information.
Enums
- CreateScanningGroupError is a struct for typed errors of method
SensitiveDataScannerAPI::create_scanning_group - CreateScanningRuleError is a struct for typed errors of method
SensitiveDataScannerAPI::create_scanning_rule - DeleteScanningGroupError is a struct for typed errors of method
SensitiveDataScannerAPI::delete_scanning_group - DeleteScanningRuleError is a struct for typed errors of method
SensitiveDataScannerAPI::delete_scanning_rule - ListScanningGroupsError is a struct for typed errors of method
SensitiveDataScannerAPI::list_scanning_groups - ListStandardPatternsError is a struct for typed errors of method
SensitiveDataScannerAPI::list_standard_patterns - ReorderScanningGroupsError is a struct for typed errors of method
SensitiveDataScannerAPI::reorder_scanning_groups - UpdateScanningGroupError is a struct for typed errors of method
SensitiveDataScannerAPI::update_scanning_group - UpdateScanningRuleError is a struct for typed errors of method
SensitiveDataScannerAPI::update_scanning_rule