Module datadog_api_client::datadogV2::api::api_software_catalog
source · Structs
- ListCatalogEntityOptionalParams is a struct for passing parameters to the method
SoftwareCatalogAPI::list_catalog_entity - API to create, update, retrieve and delete Software Catalog entities.
Enums
- DeleteCatalogEntityError is a struct for typed errors of method
SoftwareCatalogAPI::delete_catalog_entity - ListCatalogEntityError is a struct for typed errors of method
SoftwareCatalogAPI::list_catalog_entity - UpsertCatalogEntityError is a struct for typed errors of method
SoftwareCatalogAPI::upsert_catalog_entity