#[non_exhaustive]pub struct ListSpansGetOptionalParams {
pub filter_query: Option<String>,
pub filter_from: Option<String>,
pub filter_to: Option<String>,
pub sort: Option<SpansSort>,
pub page_cursor: Option<String>,
pub page_limit: Option<i32>,
}Expand description
ListSpansGetOptionalParams is a struct for passing parameters to the method SpansAPI::list_spans_get
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter_query: Option<String>Search query following spans syntax.
filter_from: Option<String>Minimum timestamp for requested spans. Supports date-time ISO8601, date math, and regular timestamps (milliseconds).
filter_to: Option<String>Maximum timestamp for requested spans. Supports date-time ISO8601, date math, and regular timestamps (milliseconds).
sort: Option<SpansSort>Order of spans in results.
page_cursor: Option<String>List following results with a cursor provided in the previous query.
page_limit: Option<i32>Maximum number of spans in the response.
Implementations
sourceimpl ListSpansGetOptionalParams
impl ListSpansGetOptionalParams
sourcepub fn filter_query(self, value: String) -> Self
pub fn filter_query(self, value: String) -> Self
Search query following spans syntax.
sourcepub fn filter_from(self, value: String) -> Self
pub fn filter_from(self, value: String) -> Self
Minimum timestamp for requested spans. Supports date-time ISO8601, date math, and regular timestamps (milliseconds).
sourcepub fn filter_to(self, value: String) -> Self
pub fn filter_to(self, value: String) -> Self
Maximum timestamp for requested spans. Supports date-time ISO8601, date math, and regular timestamps (milliseconds).
sourcepub fn page_cursor(self, value: String) -> Self
pub fn page_cursor(self, value: String) -> Self
List following results with a cursor provided in the previous query.
sourcepub fn page_limit(self, value: i32) -> Self
pub fn page_limit(self, value: i32) -> Self
Maximum number of spans in the response.
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = SpansAPI::with_config(configuration);
let response =
api.list_spans_get_with_pagination(ListSpansGetOptionalParams::default().page_limit(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}Trait Implementations
sourceimpl Clone for ListSpansGetOptionalParams
impl Clone for ListSpansGetOptionalParams
sourcefn clone(&self) -> ListSpansGetOptionalParams
fn clone(&self) -> ListSpansGetOptionalParams
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for ListSpansGetOptionalParams
impl Debug for ListSpansGetOptionalParams
sourceimpl Default for ListSpansGetOptionalParams
impl Default for ListSpansGetOptionalParams
sourcefn default() -> ListSpansGetOptionalParams
fn default() -> ListSpansGetOptionalParams