#[non_exhaustive]pub struct GetHourlyUsageOptionalParams {
pub filter_timestamp_end: Option<DateTime<Utc>>,
pub filter_include_descendants: Option<bool>,
pub filter_include_connected_accounts: Option<bool>,
pub filter_include_breakdown: Option<bool>,
pub filter_versions: Option<String>,
pub page_limit: Option<i32>,
pub page_next_record_id: Option<String>,
}Expand description
GetHourlyUsageOptionalParams is a struct for passing parameters to the method UsageMeteringAPI::get_hourly_usage
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter_timestamp_end: Option<DateTime<Utc>>Datetime in ISO-8601 format, UTC, precise to hour: [YYYY-MM-DDThh] for usage ending before this hour.
filter_include_descendants: Option<bool>Include child org usage in the response. Defaults to false.
filter_include_connected_accounts: Option<bool>Boolean to specify whether to include accounts connected to the current account as partner customers in the Datadog partner network program. Defaults to false.
filter_include_breakdown: Option<bool>Include breakdown of usage by subcategories where applicable (for product family logs only). Defaults to false.
filter_versions: Option<String>Comma separated list of product family versions to use in the format product_family:version. For example,
infra_hosts:1.0.0. If this parameter is not used, the API will use the latest version of each requested
product family. Currently all families have one version 1.0.0.
page_limit: Option<i32>Maximum number of results to return (between 1 and 500) - defaults to 500 if limit not specified.
page_next_record_id: Option<String>List following results with a next_record_id provided in the previous query.
Implementations
sourceimpl GetHourlyUsageOptionalParams
impl GetHourlyUsageOptionalParams
sourcepub fn filter_timestamp_end(self, value: DateTime<Utc>) -> Self
pub fn filter_timestamp_end(self, value: DateTime<Utc>) -> Self
Datetime in ISO-8601 format, UTC, precise to hour: [YYYY-MM-DDThh] for usage ending before this hour.
sourcepub fn filter_include_descendants(self, value: bool) -> Self
pub fn filter_include_descendants(self, value: bool) -> Self
Include child org usage in the response. Defaults to false.
sourcepub fn filter_include_connected_accounts(self, value: bool) -> Self
pub fn filter_include_connected_accounts(self, value: bool) -> Self
Boolean to specify whether to include accounts connected to the current account as partner customers in the Datadog partner network program. Defaults to false.
sourcepub fn filter_include_breakdown(self, value: bool) -> Self
pub fn filter_include_breakdown(self, value: bool) -> Self
Include breakdown of usage by subcategories where applicable (for product family logs only). Defaults to false.
sourcepub fn filter_versions(self, value: String) -> Self
pub fn filter_versions(self, value: String) -> Self
Comma separated list of product family versions to use in the format product_family:version. For example,
infra_hosts:1.0.0. If this parameter is not used, the API will use the latest version of each requested
product family. Currently all families have one version 1.0.0.
sourcepub fn page_limit(self, value: i32) -> Self
pub fn page_limit(self, value: i32) -> Self
Maximum number of results to return (between 1 and 500) - defaults to 500 if limit not specified.
sourcepub fn page_next_record_id(self, value: String) -> Self
pub fn page_next_record_id(self, value: String) -> Self
List following results with a next_record_id provided in the previous query.