Module datadog_api_client::datadogV2::api::api_users
source · Structs
- ListUsersOptionalParams is a struct for passing parameters to the method
UsersAPI::list_users - Create, edit, and disable users.
Enums
- CreateUserError is a struct for typed errors of method
UsersAPI::create_user - DisableUserError is a struct for typed errors of method
UsersAPI::disable_user - GetInvitationError is a struct for typed errors of method
UsersAPI::get_invitation - GetUserError is a struct for typed errors of method
UsersAPI::get_user - ListUserOrganizationsError is a struct for typed errors of method
UsersAPI::list_user_organizations - ListUserPermissionsError is a struct for typed errors of method
UsersAPI::list_user_permissions - ListUsersError is a struct for typed errors of method
UsersAPI::list_users - SendInvitationsError is a struct for typed errors of method
UsersAPI::send_invitations - UpdateUserError is a struct for typed errors of method
UsersAPI::update_user