Struct datadog_api_client::datadogV2::api::api_users::UsersAPI

source ·
pub struct UsersAPI { /* private fields */ }
Create, edit, and disable users.

Implementations

source

impl UsersAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v2_users_ListUserOrganizations.rs (line 8)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api
        .list_user_organizations("00000000-0000-9999-0000-000000000000".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v2_users_GetUser.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_user(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_users_DisableUser.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.disable_user(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_users_ListUserPermissions.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.list_user_permissions(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_users_GetInvitation.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // the "user" has a "user_invitation"
    let user_invitation_id = std::env::var("USER_INVITATION_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_invitation(user_invitation_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_users_ListUsers_4075885358.rs (line 11)
9
10
11
12
13
14
15
16
17
18
19
20
21
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let response = api.list_users_with_pagination(ListUsersOptionalParams::default().page_size(2));
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn create_user( &self, body: UserCreateRequest, ) -> Result<UserResponse, Error<CreateUserError>>

Create a user for your organization.

Examples found in repository?
examples/v2_users_CreateUser.rs (line 18)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
async fn main() {
    let body = UserCreateRequest::new(UserCreateData::new(
        UserCreateAttributes::new("Example-User@datadoghq.com".to_string())
            .name("Datadog API Client Python".to_string()),
        UsersType::USERS,
    ));
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.create_user(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_user_with_http_info( &self, body: UserCreateRequest, ) -> Result<ResponseContent<UserResponse>, Error<CreateUserError>>

Create a user for your organization.

source

pub async fn disable_user( &self, user_id: String, ) -> Result<(), Error<DisableUserError>>

Disable a user. Can only be used with an application key belonging to an administrator user.

Examples found in repository?
examples/v2_users_DisableUser.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.disable_user(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn disable_user_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<()>, Error<DisableUserError>>

Disable a user. Can only be used with an application key belonging to an administrator user.

source

pub async fn get_invitation( &self, user_invitation_uuid: String, ) -> Result<UserInvitationResponse, Error<GetInvitationError>>

Returns a single user invitation by its UUID.

Examples found in repository?
examples/v2_users_GetInvitation.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // the "user" has a "user_invitation"
    let user_invitation_id = std::env::var("USER_INVITATION_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_invitation(user_invitation_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_invitation_with_http_info( &self, user_invitation_uuid: String, ) -> Result<ResponseContent<UserInvitationResponse>, Error<GetInvitationError>>

Returns a single user invitation by its UUID.

source

pub async fn get_user( &self, user_id: String, ) -> Result<UserResponse, Error<GetUserError>>

Get a user in the organization specified by the user’s user_id.

Examples found in repository?
examples/v2_users_GetUser.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.get_user(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_user_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<UserResponse>, Error<GetUserError>>

Get a user in the organization specified by the user’s user_id.

source

pub async fn list_user_organizations( &self, user_id: String, ) -> Result<UserResponse, Error<ListUserOrganizationsError>>

Get a user organization. Returns the user information and all organizations joined by this user.

Examples found in repository?
examples/v2_users_ListUserOrganizations.rs (line 10)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api
        .list_user_organizations("00000000-0000-9999-0000-000000000000".to_string())
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_user_organizations_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<UserResponse>, Error<ListUserOrganizationsError>>

Get a user organization. Returns the user information and all organizations joined by this user.

source

pub async fn list_user_permissions( &self, user_id: String, ) -> Result<PermissionsResponse, Error<ListUserPermissionsError>>

Get a user permission set. Returns a list of the user’s permissions granted by the associated user’s roles.

Examples found in repository?
examples/v2_users_ListUserPermissions.rs (line 11)
6
7
8
9
10
11
12
13
14
15
16
17
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.list_user_permissions(user_data_id.clone()).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_user_permissions_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<PermissionsResponse>, Error<ListUserPermissionsError>>

Get a user permission set. Returns a list of the user’s permissions granted by the associated user’s roles.

source

pub async fn list_users( &self, params: ListUsersOptionalParams, ) -> Result<UsersResponse, Error<ListUsersError>>

Get the list of all users in the organization. This list includes all users even if they are deactivated or unverified.

Examples found in repository?
examples/v2_users_ListUsers.rs (line 13)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    // there is a valid "user" in the system
    let user_data_attributes_email = std::env::var("USER_DATA_ATTRIBUTES_EMAIL").unwrap();
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api
        .list_users(ListUsersOptionalParams::default().filter(user_data_attributes_email.clone()))
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn list_users_with_pagination( &self, params: ListUsersOptionalParams, ) -> impl Stream<Item = Result<User, Error<ListUsersError>>> + '_

Examples found in repository?
examples/v2_users_ListUsers_4075885358.rs (line 12)
9
10
11
12
13
14
15
16
17
18
19
20
21
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let response = api.list_users_with_pagination(ListUsersOptionalParams::default().page_size(2));
    pin_mut!(response);
    while let Some(resp) = response.next().await {
        if let Ok(value) = resp {
            println!("{:#?}", value);
        } else {
            println!("{:#?}", resp.unwrap_err());
        }
    }
}
source

pub async fn list_users_with_http_info( &self, params: ListUsersOptionalParams, ) -> Result<ResponseContent<UsersResponse>, Error<ListUsersError>>

Get the list of all users in the organization. This list includes all users even if they are deactivated or unverified.

source

pub async fn send_invitations( &self, body: UserInvitationsRequest, ) -> Result<UserInvitationsResponse, Error<SendInvitationsError>>

Sends emails to one or more users inviting them to join the organization.

Examples found in repository?
examples/v2_users_SendInvitations.rs (line 25)
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let body = UserInvitationsRequest::new(vec![UserInvitationData::new(
        UserInvitationRelationships::new(RelationshipToUser::new(RelationshipToUserData::new(
            user_data_id.clone(),
            UsersType::USERS,
        ))),
        UserInvitationsType::USER_INVITATIONS,
    )]);
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.send_invitations(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn send_invitations_with_http_info( &self, body: UserInvitationsRequest, ) -> Result<ResponseContent<UserInvitationsResponse>, Error<SendInvitationsError>>

Sends emails to one or more users inviting them to join the organization.

source

pub async fn update_user( &self, user_id: String, body: UserUpdateRequest, ) -> Result<UserResponse, Error<UpdateUserError>>

Edit a user. Can only be used with an application key belonging to an administrator user.

Examples found in repository?
examples/v2_users_UpdateUser.rs (line 22)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
async fn main() {
    // there is a valid "user" in the system
    let user_data_id = std::env::var("USER_DATA_ID").unwrap();
    let body = UserUpdateRequest::new(UserUpdateData::new(
        UserUpdateAttributes::new()
            .disabled(true)
            .name("updated".to_string()),
        user_data_id.clone(),
        UsersType::USERS,
    ));
    let configuration = datadog::Configuration::new();
    let api = UsersAPI::with_config(configuration);
    let resp = api.update_user(user_data_id.clone(), body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn update_user_with_http_info( &self, user_id: String, body: UserUpdateRequest, ) -> Result<ResponseContent<UserResponse>, Error<UpdateUserError>>

Edit a user. Can only be used with an application key belonging to an administrator user.