pub struct WorkflowAutomationAPI { /* private fields */ }
Automate your teams operational processes with Datadog Workflow Automation.

Implementations

source

impl WorkflowAutomationAPI

source

pub fn new() -> Self

source

pub fn with_config(config: Configuration) -> Self

Examples found in repository?
examples/v2_workflow-automation_ListWorkflowInstances.rs (line 9)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .list_workflow_instances(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            ListWorkflowInstancesOptionalParams::default(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
More examples
Hide additional examples
examples/v2_workflow-automation_GetWorkflowInstance.rs (line 8)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .get_workflow_instance(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            "305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_workflow-automation_CancelWorkflowInstance.rs (line 8)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .cancel_workflow_instance(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            "305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
examples/v2_workflow-automation_CreateWorkflowInstance.rs (line 16)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
async fn main() {
    let body =
        WorkflowInstanceCreateRequest::new().meta(WorkflowInstanceCreateMeta::new().payload(
            BTreeMap::from([("input".to_string(), Value::from("value"))]),
        ));
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .create_workflow_instance("ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self

source

pub async fn cancel_workflow_instance( &self, workflow_id: String, instance_id: String, ) -> Result<WorklflowCancelInstanceResponse, Error<CancelWorkflowInstanceError>>

Cancels a specific execution of a given workflow. This API requires an application key scoped with the workflows_run permission.

Examples found in repository?
examples/v2_workflow-automation_CancelWorkflowInstance.rs (lines 10-13)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .cancel_workflow_instance(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            "305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn cancel_workflow_instance_with_http_info( &self, workflow_id: String, instance_id: String, ) -> Result<ResponseContent<WorklflowCancelInstanceResponse>, Error<CancelWorkflowInstanceError>>

Cancels a specific execution of a given workflow. This API requires an application key scoped with the workflows_run permission.

source

pub async fn create_workflow_instance( &self, workflow_id: String, body: WorkflowInstanceCreateRequest, ) -> Result<WorkflowInstanceCreateResponse, Error<CreateWorkflowInstanceError>>

Execute the given workflow. This API requires an application key scoped with the workflows_run permission.

Examples found in repository?
examples/v2_workflow-automation_CreateWorkflowInstance.rs (line 18)
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
async fn main() {
    let body =
        WorkflowInstanceCreateRequest::new().meta(WorkflowInstanceCreateMeta::new().payload(
            BTreeMap::from([("input".to_string(), Value::from("value"))]),
        ));
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .create_workflow_instance("ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(), body)
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn create_workflow_instance_with_http_info( &self, workflow_id: String, body: WorkflowInstanceCreateRequest, ) -> Result<ResponseContent<WorkflowInstanceCreateResponse>, Error<CreateWorkflowInstanceError>>

Execute the given workflow. This API requires an application key scoped with the workflows_run permission.

source

pub async fn get_workflow_instance( &self, workflow_id: String, instance_id: String, ) -> Result<WorklflowGetInstanceResponse, Error<GetWorkflowInstanceError>>

Get a specific execution of a given workflow. This API requires an application key scoped with the workflows_read permission.

Examples found in repository?
examples/v2_workflow-automation_GetWorkflowInstance.rs (lines 10-13)
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .get_workflow_instance(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            "305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn get_workflow_instance_with_http_info( &self, workflow_id: String, instance_id: String, ) -> Result<ResponseContent<WorklflowGetInstanceResponse>, Error<GetWorkflowInstanceError>>

Get a specific execution of a given workflow. This API requires an application key scoped with the workflows_read permission.

source

pub async fn list_workflow_instances( &self, workflow_id: String, params: ListWorkflowInstancesOptionalParams, ) -> Result<WorkflowListInstancesResponse, Error<ListWorkflowInstancesError>>

List all instances of a given workflow. This API requires an application key scoped with the workflows_read permission.

Examples found in repository?
examples/v2_workflow-automation_ListWorkflowInstances.rs (lines 11-14)
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
async fn main() {
    let configuration = datadog::Configuration::new();
    let api = WorkflowAutomationAPI::with_config(configuration);
    let resp = api
        .list_workflow_instances(
            "ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
            ListWorkflowInstancesOptionalParams::default(),
        )
        .await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub async fn list_workflow_instances_with_http_info( &self, workflow_id: String, params: ListWorkflowInstancesOptionalParams, ) -> Result<ResponseContent<WorkflowListInstancesResponse>, Error<ListWorkflowInstancesError>>

List all instances of a given workflow. This API requires an application key scoped with the workflows_read permission.