Struct datadog_api_client::datadogV2::model::model_container_image_attributes::ContainerImageAttributes
source · #[non_exhaustive]pub struct ContainerImageAttributes {Show 18 fields
pub container_count: Option<i64>,
pub image_flavors: Option<Vec<ContainerImageFlavor>>,
pub image_tags: Option<Vec<String>>,
pub images_built_at: Option<Vec<String>>,
pub name: Option<String>,
pub os_architectures: Option<Vec<String>>,
pub os_names: Option<Vec<String>>,
pub os_versions: Option<Vec<String>>,
pub published_at: Option<String>,
pub registry: Option<String>,
pub repo_digest: Option<String>,
pub repository: Option<String>,
pub short_image: Option<String>,
pub sizes: Option<Vec<i64>>,
pub sources: Option<Vec<String>>,
pub tags: Option<Vec<String>>,
pub vulnerability_count: Option<ContainerImageVulnerabilities>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Attributes for a Container Image.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.container_count: Option<i64>Number of containers running the image.
image_flavors: Option<Vec<ContainerImageFlavor>>List of platform-specific images associated with the image record. The list contains more than 1 entry for multi-architecture images.
List of image tags associated with the Container Image.
images_built_at: Option<Vec<String>>List of build times associated with the Container Image. The list contains more than 1 entry for multi-architecture images.
name: Option<String>Name of the Container Image.
os_architectures: Option<Vec<String>>List of Operating System architectures supported by the Container Image.
os_names: Option<Vec<String>>List of Operating System names supported by the Container Image.
os_versions: Option<Vec<String>>List of Operating System versions supported by the Container Image.
published_at: Option<String>Time the image was pushed to the container registry.
registry: Option<String>Registry the Container Image was pushed to.
repo_digest: Option<String>Digest of the compressed image manifest.
repository: Option<String>Repository where the Container Image is stored in.
short_image: Option<String>Short version of the Container Image name.
sizes: Option<Vec<i64>>List of size for each platform-specific image associated with the image record. The list contains more than 1 entry for multi-architecture images.
sources: Option<Vec<String>>List of sources where the Container Image was collected from.
List of tags associated with the Container Image.
vulnerability_count: Option<ContainerImageVulnerabilities>Vulnerability counts associated with the Container Image.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl ContainerImageAttributes
impl ContainerImageAttributes
pub fn new() -> ContainerImageAttributes
pub fn container_count(self, value: i64) -> Self
pub fn image_flavors(self, value: Vec<ContainerImageFlavor>) -> Self
pub fn images_built_at(self, value: Vec<String>) -> Self
pub fn name(self, value: String) -> Self
pub fn os_architectures(self, value: Vec<String>) -> Self
pub fn os_names(self, value: Vec<String>) -> Self
pub fn os_versions(self, value: Vec<String>) -> Self
pub fn published_at(self, value: String) -> Self
pub fn registry(self, value: String) -> Self
pub fn repo_digest(self, value: String) -> Self
pub fn repository(self, value: String) -> Self
pub fn short_image(self, value: String) -> Self
pub fn sizes(self, value: Vec<i64>) -> Self
pub fn sources(self, value: Vec<String>) -> Self
pub fn vulnerability_count(self, value: ContainerImageVulnerabilities) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self