Struct datadog_api_client::datadogV2::model::model_custom_destination_create_request_attributes::CustomDestinationCreateRequestAttributes
source · #[non_exhaustive]pub struct CustomDestinationCreateRequestAttributes {
pub enabled: Option<bool>,
pub forward_tags: Option<bool>,
pub forward_tags_restriction_list: Option<Vec<String>>,
pub forward_tags_restriction_list_type: Option<CustomDestinationAttributeTagsRestrictionListType>,
pub forwarder_destination: CustomDestinationForwardDestination,
pub name: String,
pub query: Option<String>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The attributes associated with the custom destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>Whether logs matching this custom destination should be forwarded or not.
Whether tags from the forwarded logs should be forwarded or not.
List of keys of tags to be filtered.
An empty list represents no restriction is in place and either all or no tags will be
forwarded depending on forward_tags_restriction_list_type parameter.
How forward_tags_restriction_list parameter should be interpreted.
If ALLOW_LIST, then only tags whose keys on the forwarded logs match the ones on the restriction list
are forwarded.
BLOCK_LIST works the opposite way. It does not forward the tags matching the ones on the list.
forwarder_destination: CustomDestinationForwardDestinationA custom destination’s location to forward logs.
name: StringThe custom destination name.
query: Option<String>The custom destination query and filter. Logs matching this query are forwarded to the destination.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl CustomDestinationCreateRequestAttributes
impl CustomDestinationCreateRequestAttributes
sourcepub fn new(
forwarder_destination: CustomDestinationForwardDestination,
name: String,
) -> CustomDestinationCreateRequestAttributes
pub fn new( forwarder_destination: CustomDestinationForwardDestination, name: String, ) -> CustomDestinationCreateRequestAttributes
Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn enabled(self, value: bool) -> Self
pub fn enabled(self, value: bool) -> Self
Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn query(self, value: String) -> Self
pub fn query(self, value: String) -> Self
Examples found in repository?
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44
async fn main() {
let body =
CustomDestinationCreateRequest::new().data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationSplunk(
Box::new(CustomDestinationForwardDestinationSplunk::new(
"my-access-token".to_string(),
"https://example.com".to_string(),
CustomDestinationForwardDestinationSplunkType::SPLUNK_HEC,
)),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationElasticsearch(
Box::new(
CustomDestinationForwardDestinationElasticsearch::new(
CustomDestinationElasticsearchDestinationAuth::new(
"my-password".to_string(),
"my-username".to_string(),
),
"https://example.com".to_string(),
"nginx-logs".to_string(),
CustomDestinationForwardDestinationElasticsearchType::ELASTICSEARCH,
)
.index_rotation("yyyy-MM-dd".to_string()),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(true)
.forward_tags(true)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53
async fn main() {
let body = CustomDestinationCreateRequest::new()
.data(CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthBasic(
Box::new(CustomDestinationHttpDestinationAuthBasic::new(
"datadog-custom-destination-password".to_string(),
CustomDestinationHttpDestinationAuthBasicType::BASIC,
"datadog-custom-destination-username".to_string(),
)),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
)),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(
CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST,
)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
));
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58
async fn main() {
let body =
CustomDestinationCreateRequest
::new().data(
CustomDestinationCreateRequestDefinition::new(
CustomDestinationCreateRequestAttributes::new(
CustomDestinationForwardDestination::CustomDestinationForwardDestinationHttp(
Box::new(
CustomDestinationForwardDestinationHttp::new(
CustomDestinationHttpDestinationAuth::CustomDestinationHttpDestinationAuthCustomHeader(
Box::new(
CustomDestinationHttpDestinationAuthCustomHeader::new(
"MY-AUTHENTICATION-HEADER".to_string(),
"my-secret".to_string(),
CustomDestinationHttpDestinationAuthCustomHeaderType::CUSTOM_HEADER,
),
),
),
"https://example.com".to_string(),
CustomDestinationForwardDestinationHttpType::HTTP,
),
),
),
"Nginx logs".to_string(),
)
.enabled(false)
.forward_tags(false)
.forward_tags_restriction_list(vec!["datacenter".to_string(), "host".to_string()])
.forward_tags_restriction_list_type(CustomDestinationAttributeTagsRestrictionListType::ALLOW_LIST)
.query("source:nginx".to_string()),
CustomDestinationType::CUSTOM_DESTINATION,
),
);
let configuration = datadog::Configuration::new();
let api = LogsCustomDestinationsAPI::with_config(configuration);
let resp = api.create_logs_custom_destination(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self