Struct datadog_api_client::datadogV2::model::model_custom_destination_response_attributes::CustomDestinationResponseAttributes
source · #[non_exhaustive]pub struct CustomDestinationResponseAttributes {
pub enabled: Option<bool>,
pub forward_tags: Option<bool>,
pub forward_tags_restriction_list: Option<Vec<String>>,
pub forward_tags_restriction_list_type: Option<CustomDestinationAttributeTagsRestrictionListType>,
pub forwarder_destination: Option<CustomDestinationResponseForwardDestination>,
pub name: Option<String>,
pub query: Option<String>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The attributes associated with the custom destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>Whether logs matching this custom destination should be forwarded or not.
Whether tags from the forwarded logs should be forwarded or not.
List of keys of tags to be filtered.
An empty list represents no restriction is in place and either all or no tags will be
forwarded depending on forward_tags_restriction_list_type parameter.
How forward_tags_restriction_list parameter should be interpreted.
If ALLOW_LIST, then only tags whose keys on the forwarded logs match the ones on the restriction list
are forwarded.
BLOCK_LIST works the opposite way. It does not forward the tags matching the ones on the list.
forwarder_destination: Option<CustomDestinationResponseForwardDestination>A custom destination’s location to forward logs.
name: Option<String>The custom destination name.
query: Option<String>The custom destination query filter. Logs matching this query are forwarded to the destination.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl CustomDestinationResponseAttributes
impl CustomDestinationResponseAttributes
pub fn new() -> CustomDestinationResponseAttributes
pub fn enabled(self, value: bool) -> Self
pub fn forwarder_destination( self, value: CustomDestinationResponseForwardDestination, ) -> Self
pub fn name(self, value: String) -> Self
pub fn query(self, value: String) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self