#[non_exhaustive]pub struct EventsListRequest {
pub filter: Option<EventsQueryFilter>,
pub options: Option<EventsQueryOptions>,
pub page: Option<EventsRequestPage>,
pub sort: Option<EventsSort>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The object sent with the request to retrieve a list of events from your organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter: Option<EventsQueryFilter>The search and filter query settings.
options: Option<EventsQueryOptions>The global query options that are used. Either provide a timezone or a time offset but not both, otherwise the query fails.
page: Option<EventsRequestPage>Pagination settings.
sort: Option<EventsSort>The sort parameters when querying events.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl EventsListRequest
impl EventsListRequest
sourcepub fn new() -> EventsListRequest
pub fn new() -> EventsListRequest
Examples found in repository?
examples/v2_events_SearchEvents.rs (line 12)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("2020-09-17T11:48:36+01:00".to_string())
.query("datadog-agent".to_string())
.to("2020-09-17T12:48:36+01:00".to_string()),
)
.page(EventsRequestPage::new().limit(5))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api
.search_events(SearchEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_events_SearchEvents_3856995058.rs (line 15)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("now-15m".to_string())
.to("now".to_string()),
)
.options(EventsQueryOptions::new().timezone("GMT".to_string()))
.page(EventsRequestPage::new().limit(2))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let response =
api.search_events_with_pagination(SearchEventsOptionalParams::default().body(body));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn filter(self, value: EventsQueryFilter) -> Self
pub fn filter(self, value: EventsQueryFilter) -> Self
Examples found in repository?
examples/v2_events_SearchEvents.rs (lines 13-18)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("2020-09-17T11:48:36+01:00".to_string())
.query("datadog-agent".to_string())
.to("2020-09-17T12:48:36+01:00".to_string()),
)
.page(EventsRequestPage::new().limit(5))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api
.search_events(SearchEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_events_SearchEvents_3856995058.rs (lines 16-20)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("now-15m".to_string())
.to("now".to_string()),
)
.options(EventsQueryOptions::new().timezone("GMT".to_string()))
.page(EventsRequestPage::new().limit(2))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let response =
api.search_events_with_pagination(SearchEventsOptionalParams::default().body(body));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn options(self, value: EventsQueryOptions) -> Self
pub fn options(self, value: EventsQueryOptions) -> Self
Examples found in repository?
examples/v2_events_SearchEvents_3856995058.rs (line 21)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("now-15m".to_string())
.to("now".to_string()),
)
.options(EventsQueryOptions::new().timezone("GMT".to_string()))
.page(EventsRequestPage::new().limit(2))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let response =
api.search_events_with_pagination(SearchEventsOptionalParams::default().body(body));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn page(self, value: EventsRequestPage) -> Self
pub fn page(self, value: EventsRequestPage) -> Self
Examples found in repository?
examples/v2_events_SearchEvents.rs (line 19)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("2020-09-17T11:48:36+01:00".to_string())
.query("datadog-agent".to_string())
.to("2020-09-17T12:48:36+01:00".to_string()),
)
.page(EventsRequestPage::new().limit(5))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api
.search_events(SearchEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_events_SearchEvents_3856995058.rs (line 22)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("now-15m".to_string())
.to("now".to_string()),
)
.options(EventsQueryOptions::new().timezone("GMT".to_string()))
.page(EventsRequestPage::new().limit(2))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let response =
api.search_events_with_pagination(SearchEventsOptionalParams::default().body(body));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn sort(self, value: EventsSort) -> Self
pub fn sort(self, value: EventsSort) -> Self
Examples found in repository?
examples/v2_events_SearchEvents.rs (line 20)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("2020-09-17T11:48:36+01:00".to_string())
.query("datadog-agent".to_string())
.to("2020-09-17T12:48:36+01:00".to_string()),
)
.page(EventsRequestPage::new().limit(5))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let resp = api
.search_events(SearchEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_events_SearchEvents_3856995058.rs (line 23)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = EventsListRequest::new()
.filter(
EventsQueryFilter::new()
.from("now-15m".to_string())
.to("now".to_string()),
)
.options(EventsQueryOptions::new().timezone("GMT".to_string()))
.page(EventsRequestPage::new().limit(2))
.sort(EventsSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = EventsAPI::with_config(configuration);
let response =
api.search_events_with_pagination(SearchEventsOptionalParams::default().body(body));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self