#[non_exhaustive]pub struct FindingAttributes {
pub evaluation: Option<FindingEvaluation>,
pub evaluation_changed_at: Option<i64>,
pub mute: Option<FindingMute>,
pub resource: Option<String>,
pub resource_discovery_date: Option<i64>,
pub resource_type: Option<String>,
pub rule: Option<FindingRule>,
pub status: Option<FindingStatus>,
pub tags: Option<Vec<String>>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The JSON:API attributes of the finding.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation: Option<FindingEvaluation>The evaluation of the finding.
evaluation_changed_at: Option<i64>The date on which the evaluation for this finding changed (Unix ms).
mute: Option<FindingMute>Information about the mute status of this finding.
resource: Option<String>The resource name of this finding.
resource_discovery_date: Option<i64>The date on which the resource was discovered (Unix ms).
resource_type: Option<String>The resource type of this finding.
rule: Option<FindingRule>The rule that triggered this finding.
status: Option<FindingStatus>The status of the finding.
The tags associated with this finding.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl FindingAttributes
impl FindingAttributes
pub fn new() -> FindingAttributes
pub fn evaluation(self, value: FindingEvaluation) -> Self
pub fn evaluation_changed_at(self, value: i64) -> Self
pub fn mute(self, value: FindingMute) -> Self
pub fn resource(self, value: String) -> Self
pub fn resource_discovery_date(self, value: i64) -> Self
pub fn resource_type(self, value: String) -> Self
pub fn rule(self, value: FindingRule) -> Self
pub fn status(self, value: FindingStatus) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self