#[non_exhaustive]pub struct Log {
pub attributes: Option<LogAttributes>,
pub id: Option<String>,
pub type_: Option<LogType>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Object description of a log after being processed and stored by Datadog.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.attributes: Option<LogAttributes>JSON object containing all log attributes and their associated values.
id: Option<String>Unique ID of the Log.
type_: Option<LogType>Type of the event.
additional_properties: BTreeMap<String, Value>Implementations