#[non_exhaustive]
pub struct SpansAggregateRequestAttributes { pub compute: Option<Vec<SpansCompute>>, pub filter: Option<SpansQueryFilter>, pub group_by: Option<Vec<SpansGroupBy>>, pub options: Option<SpansQueryOptions>, pub additional_properties: BTreeMap<String, Value>, /* private fields */ }
The object containing all the query parameters.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
compute: Option<Vec<SpansCompute>>

The list of metrics or timeseries to compute for the retrieved buckets.

filter: Option<SpansQueryFilter>

The search and filter query settings.

group_by: Option<Vec<SpansGroupBy>>

The rules for the group by.

options: Option<SpansQueryOptions>

Global query options that are used during the query. Note: You should only supply timezone or time offset but not both otherwise the query will fail.

additional_properties: BTreeMap<String, Value>

Implementations

source

impl SpansAggregateRequestAttributes

source

pub fn new() -> SpansAggregateRequestAttributes

Examples found in repository?
examples/v2_spans_AggregateSpans.rs (line 18)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
async fn main() {
    let body = SpansAggregateRequest::new().data(
        SpansAggregateData::new()
            .attributes(
                SpansAggregateRequestAttributes::new()
                    .compute(vec![SpansCompute::new(SpansAggregationFunction::COUNT)
                        .interval("5m".to_string())
                        .type_(SpansComputeType::TIMESERIES)])
                    .filter(
                        SpansQueryFilter::new()
                            .from("now-15m".to_string())
                            .query("*".to_string())
                            .to("now".to_string()),
                    ),
            )
            .type_(SpansAggregateRequestType::AGGREGATE_REQUEST),
    );
    let configuration = datadog::Configuration::new();
    let api = SpansAPI::with_config(configuration);
    let resp = api.aggregate_spans(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn compute(self, value: Vec<SpansCompute>) -> Self

Examples found in repository?
examples/v2_spans_AggregateSpans.rs (lines 19-21)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
async fn main() {
    let body = SpansAggregateRequest::new().data(
        SpansAggregateData::new()
            .attributes(
                SpansAggregateRequestAttributes::new()
                    .compute(vec![SpansCompute::new(SpansAggregationFunction::COUNT)
                        .interval("5m".to_string())
                        .type_(SpansComputeType::TIMESERIES)])
                    .filter(
                        SpansQueryFilter::new()
                            .from("now-15m".to_string())
                            .query("*".to_string())
                            .to("now".to_string()),
                    ),
            )
            .type_(SpansAggregateRequestType::AGGREGATE_REQUEST),
    );
    let configuration = datadog::Configuration::new();
    let api = SpansAPI::with_config(configuration);
    let resp = api.aggregate_spans(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn filter(self, value: SpansQueryFilter) -> Self

Examples found in repository?
examples/v2_spans_AggregateSpans.rs (lines 22-27)
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
async fn main() {
    let body = SpansAggregateRequest::new().data(
        SpansAggregateData::new()
            .attributes(
                SpansAggregateRequestAttributes::new()
                    .compute(vec![SpansCompute::new(SpansAggregationFunction::COUNT)
                        .interval("5m".to_string())
                        .type_(SpansComputeType::TIMESERIES)])
                    .filter(
                        SpansQueryFilter::new()
                            .from("now-15m".to_string())
                            .query("*".to_string())
                            .to("now".to_string()),
                    ),
            )
            .type_(SpansAggregateRequestType::AGGREGATE_REQUEST),
    );
    let configuration = datadog::Configuration::new();
    let api = SpansAPI::with_config(configuration);
    let resp = api.aggregate_spans(body).await;
    if let Ok(value) = resp {
        println!("{:#?}", value);
    } else {
        println!("{:#?}", resp.unwrap_err());
    }
}
source

pub fn group_by(self, value: Vec<SpansGroupBy>) -> Self

source

pub fn options(self, value: SpansQueryOptions) -> Self

source

pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self