pub struct OrganizationsAPI { /* private fields */ }Expand description
Create, edit, and manage your organizations. Read more about multi-org accounts.
Implementations
sourceimpl OrganizationsAPI
impl OrganizationsAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
More examples
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api
.upload_idp_for_org(
"abc123".to_string(),
fs::read("./idp_metadata.xml").unwrap(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let body = OrganizationCreateBody::new("New child org".to_string())
.billing(OrganizationBilling::new().type_("parent_billing".to_string()))
.subscription(OrganizationSubscription::new().type_("pro".to_string()));
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api.create_child_org(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50
async fn main() {
let body = Organization::new()
.billing(OrganizationBilling::new().type_("parent_billing".to_string()))
.description("some description".to_string())
.name("New child org".to_string())
.public_id("abcdef12345".to_string())
.settings(
OrganizationSettings::new()
.private_widget_share(false)
.saml(OrganizationSettingsSaml::new().enabled(false))
.saml_autocreate_access_role(Some(AccessRole::READ_ONLY))
.saml_autocreate_users_domains(
OrganizationSettingsSamlAutocreateUsersDomains::new()
.domains(vec!["example.com".to_string()])
.enabled(false),
)
.saml_can_be_enabled(false)
.saml_idp_endpoint("https://my.saml.endpoint".to_string())
.saml_idp_initiated_login(
OrganizationSettingsSamlIdpInitiatedLogin::new().enabled(false),
)
.saml_idp_metadata_uploaded(false)
.saml_login_url("https://my.saml.login.url".to_string())
.saml_strict_mode(OrganizationSettingsSamlStrictMode::new().enabled(false)),
)
.subscription(OrganizationSubscription::new().type_("pro".to_string()))
.trial(false);
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api.update_org("abc123".to_string(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_child_org(
&self,
body: OrganizationCreateBody,
) -> Result<OrganizationCreateResponse, Error<CreateChildOrgError>>
pub async fn create_child_org( &self, body: OrganizationCreateBody, ) -> Result<OrganizationCreateResponse, Error<CreateChildOrgError>>
Create a child organization.
This endpoint requires the multi-organization account feature and must be enabled by contacting support.
Once a new child organization is created, you can interact with it
by using the org.public_id, api_key.key, and
application_key.hash provided in the response.
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let body = OrganizationCreateBody::new("New child org".to_string())
.billing(OrganizationBilling::new().type_("parent_billing".to_string()))
.subscription(OrganizationSubscription::new().type_("pro".to_string()));
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api.create_child_org(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_child_org_with_http_info(
&self,
body: OrganizationCreateBody,
) -> Result<ResponseContent<OrganizationCreateResponse>, Error<CreateChildOrgError>>
pub async fn create_child_org_with_http_info( &self, body: OrganizationCreateBody, ) -> Result<ResponseContent<OrganizationCreateResponse>, Error<CreateChildOrgError>>
Create a child organization.
This endpoint requires the multi-organization account feature and must be enabled by contacting support.
Once a new child organization is created, you can interact with it
by using the org.public_id, api_key.key, and
application_key.hash provided in the response.
sourcepub async fn downgrade_org(
&self,
public_id: String,
) -> Result<OrgDowngradedResponse, Error<DowngradeOrgError>>
pub async fn downgrade_org( &self, public_id: String, ) -> Result<OrgDowngradedResponse, Error<DowngradeOrgError>>
Only available for MSP customers. Removes a child organization from the hierarchy of the master organization and places the child organization on a 30-day trial.
sourcepub async fn downgrade_org_with_http_info(
&self,
public_id: String,
) -> Result<ResponseContent<OrgDowngradedResponse>, Error<DowngradeOrgError>>
pub async fn downgrade_org_with_http_info( &self, public_id: String, ) -> Result<ResponseContent<OrgDowngradedResponse>, Error<DowngradeOrgError>>
Only available for MSP customers. Removes a child organization from the hierarchy of the master organization and places the child organization on a 30-day trial.
sourcepub async fn get_org(
&self,
public_id: String,
) -> Result<OrganizationResponse, Error<GetOrgError>>
pub async fn get_org( &self, public_id: String, ) -> Result<OrganizationResponse, Error<GetOrgError>>
Get organization information.
sourcepub async fn get_org_with_http_info(
&self,
public_id: String,
) -> Result<ResponseContent<OrganizationResponse>, Error<GetOrgError>>
pub async fn get_org_with_http_info( &self, public_id: String, ) -> Result<ResponseContent<OrganizationResponse>, Error<GetOrgError>>
Get organization information.
sourcepub async fn list_orgs(
&self,
) -> Result<OrganizationListResponse, Error<ListOrgsError>>
pub async fn list_orgs( &self, ) -> Result<OrganizationListResponse, Error<ListOrgsError>>
This endpoint returns data on your top-level organization.
sourcepub async fn list_orgs_with_http_info(
&self,
) -> Result<ResponseContent<OrganizationListResponse>, Error<ListOrgsError>>
pub async fn list_orgs_with_http_info( &self, ) -> Result<ResponseContent<OrganizationListResponse>, Error<ListOrgsError>>
This endpoint returns data on your top-level organization.
sourcepub async fn update_org(
&self,
public_id: String,
body: Organization,
) -> Result<OrganizationResponse, Error<UpdateOrgError>>
pub async fn update_org( &self, public_id: String, body: Organization, ) -> Result<OrganizationResponse, Error<UpdateOrgError>>
Update your organization.
Examples found in repository?
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50
async fn main() {
let body = Organization::new()
.billing(OrganizationBilling::new().type_("parent_billing".to_string()))
.description("some description".to_string())
.name("New child org".to_string())
.public_id("abcdef12345".to_string())
.settings(
OrganizationSettings::new()
.private_widget_share(false)
.saml(OrganizationSettingsSaml::new().enabled(false))
.saml_autocreate_access_role(Some(AccessRole::READ_ONLY))
.saml_autocreate_users_domains(
OrganizationSettingsSamlAutocreateUsersDomains::new()
.domains(vec!["example.com".to_string()])
.enabled(false),
)
.saml_can_be_enabled(false)
.saml_idp_endpoint("https://my.saml.endpoint".to_string())
.saml_idp_initiated_login(
OrganizationSettingsSamlIdpInitiatedLogin::new().enabled(false),
)
.saml_idp_metadata_uploaded(false)
.saml_login_url("https://my.saml.login.url".to_string())
.saml_strict_mode(OrganizationSettingsSamlStrictMode::new().enabled(false)),
)
.subscription(OrganizationSubscription::new().type_("pro".to_string()))
.trial(false);
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api.update_org("abc123".to_string(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_org_with_http_info(
&self,
public_id: String,
body: Organization,
) -> Result<ResponseContent<OrganizationResponse>, Error<UpdateOrgError>>
pub async fn update_org_with_http_info( &self, public_id: String, body: Organization, ) -> Result<ResponseContent<OrganizationResponse>, Error<UpdateOrgError>>
Update your organization.
sourcepub async fn upload_idp_for_org(
&self,
public_id: String,
idp_file: Vec<u8>,
) -> Result<IdpResponse, Error<UploadIdPForOrgError>>
pub async fn upload_idp_for_org( &self, public_id: String, idp_file: Vec<u8>, ) -> Result<IdpResponse, Error<UploadIdPForOrgError>>
There are a couple of options for updating the Identity Provider (IdP) metadata from your SAML IdP.
-
Multipart Form-Data: Post the IdP metadata file using a form post.
-
XML Body: Post the IdP metadata file as the body of the request.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = OrganizationsAPI::with_config(configuration);
let resp = api
.upload_idp_for_org(
"abc123".to_string(),
fs::read("./idp_metadata.xml").unwrap(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn upload_idp_for_org_with_http_info(
&self,
public_id: String,
idp_file: Vec<u8>,
) -> Result<ResponseContent<IdpResponse>, Error<UploadIdPForOrgError>>
pub async fn upload_idp_for_org_with_http_info( &self, public_id: String, idp_file: Vec<u8>, ) -> Result<ResponseContent<IdpResponse>, Error<UploadIdPForOrgError>>
There are a couple of options for updating the Identity Provider (IdP) metadata from your SAML IdP.
-
Multipart Form-Data: Post the IdP metadata file using a form post.
-
XML Body: Post the IdP metadata file as the body of the request.