Struct datadog_api_client::datadogV1::model::model_logs_message_remapper::LogsMessageRemapper
source · #[non_exhaustive]pub struct LogsMessageRemapper {
pub is_enabled: Option<bool>,
pub name: Option<String>,
pub sources: Vec<String>,
pub type_: LogsMessageRemapperType,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The message is a key attribute in Datadog. It is displayed in the message column of the Log Explorer and you can do full string search on it. Use this Processor to define one or more attributes as the official log message.
Note: If multiple log message remapper processors can be applied to a given log, only the first one (according to the pipeline order) is taken into account.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_enabled: Option<bool>Whether or not the processor is enabled.
name: Option<String>Name of the processor.
sources: Vec<String>Array of source attributes.
type_: LogsMessageRemapperTypeType of logs message remapper.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl LogsMessageRemapper
impl LogsMessageRemapper
pub fn new( sources: Vec<String>, type_: LogsMessageRemapperType, ) -> LogsMessageRemapper
pub fn is_enabled(self, value: bool) -> Self
pub fn name(self, value: String) -> Self
pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self