Struct datadog_api_client::datadogV1::model::model_table_widget_definition::TableWidgetDefinition
source · #[non_exhaustive]pub struct TableWidgetDefinition {
pub custom_links: Option<Vec<WidgetCustomLink>>,
pub has_search_bar: Option<TableWidgetHasSearchBar>,
pub requests: Vec<TableWidgetRequest>,
pub time: Option<WidgetTime>,
pub title: Option<String>,
pub title_align: Option<WidgetTextAlign>,
pub title_size: Option<String>,
pub type_: TableWidgetDefinitionType,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
The table visualization is available on timeboards and screenboards. It displays columns of metrics grouped by tag key.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.custom_links: Option<Vec<WidgetCustomLink>>List of custom links.
has_search_bar: Option<TableWidgetHasSearchBar>Controls the display of the search bar.
requests: Vec<TableWidgetRequest>Widget definition.
time: Option<WidgetTime>Time setting for the widget.
title: Option<String>Title of your widget.
title_align: Option<WidgetTextAlign>How to align the text on the widget.
title_size: Option<String>Size of the title.
type_: TableWidgetDefinitionTypeType of the table widget.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl TableWidgetDefinition
impl TableWidgetDefinition
sourcepub fn new(
requests: Vec<TableWidgetRequest>,
type_: TableWidgetDefinitionType,
) -> TableWidgetDefinition
pub fn new( requests: Vec<TableWidgetRequest>, type_: TableWidgetDefinitionType, ) -> TableWidgetDefinition
Examples found in repository?
examples/v1_dashboards_CreateDashboard_3669695268.rs (lines 32-65)
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard with query table widget and storage parameter".to_string(),
vec![Widget::new(WidgetDefinition::TableWidgetDefinition(
Box::new(TableWidgetDefinition::new(
vec![TableWidgetRequest::new()
.formulas(vec![WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])])
.queries(vec![
FormulaAndFunctionQueryDefinition::FormulaAndFunctionEventQueryDefinition(
Box::new(
FormulaAndFunctionEventQueryDefinition::new(
FormulaAndFunctionEventQueryDefinitionCompute::new(
FormulaAndFunctionEventAggregation::COUNT,
),
FormulaAndFunctionEventsDataSource::LOGS,
"query1".to_string(),
)
.group_by(vec![])
.indexes(vec!["*".to_string()])
.search(FormulaAndFunctionEventQueryDefinitionSearch::new(
"".to_string(),
))
.storage("online_archives".to_string()),
),
),
])
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(WidgetSortBy::new().count(50).order_by(vec![
WidgetSortOrderBy::WidgetFormulaSort(Box::new(WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
))),
]))],
TableWidgetDefinitionType::QUERY_TABLE,
)),
))],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_145494973.rs (lines 29-56)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_798168180.rs (lines 29-56)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2336428357.rs (lines 39-83)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn custom_links(self, value: Vec<WidgetCustomLink>) -> Self
sourcepub fn has_search_bar(self, value: TableWidgetHasSearchBar) -> Self
pub fn has_search_bar(self, value: TableWidgetHasSearchBar) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_2336428357.rs (line 84)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn time(self, value: WidgetTime) -> Self
pub fn time(self, value: WidgetTime) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_2336428357.rs (line 85)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn title(self, value: String) -> Self
pub fn title(self, value: String) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_145494973.rs (line 57)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_798168180.rs (line 57)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2336428357.rs (line 86)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn title_align(self, value: WidgetTextAlign) -> Self
pub fn title_align(self, value: WidgetTextAlign) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_145494973.rs (line 58)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_798168180.rs (line 58)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2336428357.rs (line 87)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn title_size(self, value: String) -> Self
pub fn title_size(self, value: String) -> Self
Examples found in repository?
examples/v1_dashboards_CreateDashboard_145494973.rs (line 59)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmResourceStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmResourceStatsQueryDefinition::new(
FormulaAndFunctionApmResourceStatsDataSource
::APM_RESOURCE_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmResourceStatName::HITS,
)
.group_by(vec!["resource_name".to_string()])
.operation_name("cassandra.query".to_string())
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v1_dashboards_CreateDashboard_798168180.rs (line 59)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::ORDERED,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionApmDependencyStatsQueryDefinition(
Box::new(
FormulaAndFunctionApmDependencyStatsQueryDefinition::new(
FormulaAndFunctionApmDependencyStatsDataSource
::APM_DEPENDENCY_STATS,
"ci".to_string(),
"query1".to_string(),
"cassandra.query".to_string(),
"DELETE FROM monitor_history.monitor_state_change_history WHERE org_id = ? AND monitor_id IN ? AND group = ?".to_string(),
"cassandra".to_string(),
FormulaAndFunctionApmDependencyStatName::AVG_DURATION,
)
.primary_tag_name("datacenter".to_string())
.primary_tag_value("edge-eu1.prod.dog".to_string()),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(4, 4, 0, 0))
],
);
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v1_dashboards_CreateDashboard_2336428357.rs (line 88)
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106
async fn main() {
let body =
Dashboard::new(
DashboardLayoutType::FREE,
"Example-Dashboard".to_string(),
vec![
Widget::new(
WidgetDefinition::TableWidgetDefinition(
Box::new(
TableWidgetDefinition::new(
vec![
TableWidgetRequest::new()
.formulas(
vec![
WidgetFormula::new("query1".to_string())
.cell_display_mode(TableWidgetCellDisplayMode::BAR)
.conditional_formats(vec![])
],
)
.queries(
vec![
FormulaAndFunctionQueryDefinition
::FormulaAndFunctionMetricQueryDefinition(
Box::new(
FormulaAndFunctionMetricQueryDefinition::new(
FormulaAndFunctionMetricDataSource::METRICS,
"query1".to_string(),
"avg:system.cpu.user{*} by {host}".to_string(),
).aggregator(FormulaAndFunctionMetricAggregation::AVG),
),
)
],
)
.response_format(FormulaAndFunctionResponseFormat::SCALAR)
.sort(
WidgetSortBy::new()
.count(500)
.order_by(
vec![
WidgetSortOrderBy::WidgetFormulaSort(
Box::new(
WidgetFormulaSort::new(
0,
WidgetSort::DESCENDING,
FormulaType::FORMULA,
),
),
)
],
),
)
],
TableWidgetDefinitionType::QUERY_TABLE,
)
.has_search_bar(TableWidgetHasSearchBar::AUTO)
.time(WidgetTime::WidgetLegacyLiveSpan(Box::new(WidgetLegacyLiveSpan::new())))
.title("".to_string())
.title_align(WidgetTextAlign::LEFT)
.title_size("16".to_string()),
),
),
).layout(WidgetLayout::new(32, 54, 0, 0))
],
)
.description(Some("".to_string()))
.is_read_only(false)
.notify_list(Some(vec![]))
.template_variables(Some(vec![]));
let configuration = datadog::Configuration::new();
let api = DashboardsAPI::with_config(configuration);
let resp = api.create_dashboard(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self