pub struct CIVisibilityTestsAPI { /* private fields */ }Expand description
Search or aggregate your CI Visibility test events over HTTP. See the Test Visibility in Datadog page for more information.
Implementations
sourceimpl CIVisibilityTestsAPI
impl CIVisibilityTestsAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let body = CIAppTestEventsRequest::new()
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@test.service:web-ui-tests AND @test.status:skip".to_string())
.to("now".to_string()),
)
.options(CIAppQueryOptions::new().timezone("GMT".to_string()))
.page(CIAppQueryPageOptions::new().limit(25))
.sort(CIAppSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api
.search_ci_app_test_events(SearchCIAppTestEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = CIAppTestEventsRequest::new()
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@test.status:pass AND -@language:python".to_string())
.to("now".to_string()),
)
.page(CIAppQueryPageOptions::new().limit(2))
.sort(CIAppSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let response = api.search_ci_app_test_events_with_pagination(
SearchCIAppTestEventsOptionalParams::default().body(body),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35
async fn main() {
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let response = api.list_ci_app_test_events_with_pagination(
ListCIAppTestEventsOptionalParams::default()
.filter_from(
DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(2),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api
.list_ci_app_test_events(
ListCIAppTestEventsOptionalParams::default()
.filter_query("@test.service:web-ui-tests".to_string())
.filter_from(
DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40
async fn main() {
let body = CIAppTestsAggregateRequest::new()
.compute(vec![CIAppCompute::new(CIAppAggregationFunction::COUNT)
.metric("@test.is_flaky".to_string())
.type_(CIAppComputeType::TOTAL)])
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@language:(python OR go)".to_string())
.to("now".to_string()),
)
.group_by(vec![CIAppTestsGroupBy::new("@git.branch".to_string())
.limit(10)
.sort(CIAppAggregateSort::new().order(CIAppSortOrder::ASCENDING))
.total(CIAppGroupByTotal::CIAppGroupByTotalBoolean(false))])
.options(CIAppQueryOptions::new().timezone("GMT".to_string()));
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api.aggregate_ci_app_test_events(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn aggregate_ci_app_test_events(
&self,
body: CIAppTestsAggregateRequest,
) -> Result<CIAppTestsAnalyticsAggregateResponse, Error<AggregateCIAppTestEventsError>>
pub async fn aggregate_ci_app_test_events( &self, body: CIAppTestsAggregateRequest, ) -> Result<CIAppTestsAnalyticsAggregateResponse, Error<AggregateCIAppTestEventsError>>
The API endpoint to aggregate CI Visibility test events into buckets of computed metrics and timeseries.
Examples found in repository?
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40
async fn main() {
let body = CIAppTestsAggregateRequest::new()
.compute(vec![CIAppCompute::new(CIAppAggregationFunction::COUNT)
.metric("@test.is_flaky".to_string())
.type_(CIAppComputeType::TOTAL)])
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@language:(python OR go)".to_string())
.to("now".to_string()),
)
.group_by(vec![CIAppTestsGroupBy::new("@git.branch".to_string())
.limit(10)
.sort(CIAppAggregateSort::new().order(CIAppSortOrder::ASCENDING))
.total(CIAppGroupByTotal::CIAppGroupByTotalBoolean(false))])
.options(CIAppQueryOptions::new().timezone("GMT".to_string()));
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api.aggregate_ci_app_test_events(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn aggregate_ci_app_test_events_with_http_info(
&self,
body: CIAppTestsAggregateRequest,
) -> Result<ResponseContent<CIAppTestsAnalyticsAggregateResponse>, Error<AggregateCIAppTestEventsError>>
pub async fn aggregate_ci_app_test_events_with_http_info( &self, body: CIAppTestsAggregateRequest, ) -> Result<ResponseContent<CIAppTestsAnalyticsAggregateResponse>, Error<AggregateCIAppTestEventsError>>
The API endpoint to aggregate CI Visibility test events into buckets of computed metrics and timeseries.
sourcepub async fn list_ci_app_test_events(
&self,
params: ListCIAppTestEventsOptionalParams,
) -> Result<CIAppTestEventsResponse, Error<ListCIAppTestEventsError>>
pub async fn list_ci_app_test_events( &self, params: ListCIAppTestEventsOptionalParams, ) -> Result<CIAppTestEventsResponse, Error<ListCIAppTestEventsError>>
List endpoint returns CI Visibility test events that match a search query. Results are paginated similarly to logs.
Use this endpoint to see your latest test events.
Examples found in repository?
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api
.list_ci_app_test_events(
ListCIAppTestEventsOptionalParams::default()
.filter_query("@test.service:web-ui-tests".to_string())
.filter_from(
DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn list_ci_app_test_events_with_pagination(
&self,
params: ListCIAppTestEventsOptionalParams,
) -> impl Stream<Item = Result<CIAppTestEvent, Error<ListCIAppTestEventsError>>> + '_
pub fn list_ci_app_test_events_with_pagination( &self, params: ListCIAppTestEventsOptionalParams, ) -> impl Stream<Item = Result<CIAppTestEvent, Error<ListCIAppTestEventsError>>> + '_
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35
async fn main() {
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let response = api.list_ci_app_test_events_with_pagination(
ListCIAppTestEventsOptionalParams::default()
.filter_from(
DateTime::parse_from_rfc3339("2021-11-11T11:10:41+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2021-11-11T11:11:11+00:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(2),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn list_ci_app_test_events_with_http_info(
&self,
params: ListCIAppTestEventsOptionalParams,
) -> Result<ResponseContent<CIAppTestEventsResponse>, Error<ListCIAppTestEventsError>>
pub async fn list_ci_app_test_events_with_http_info( &self, params: ListCIAppTestEventsOptionalParams, ) -> Result<ResponseContent<CIAppTestEventsResponse>, Error<ListCIAppTestEventsError>>
List endpoint returns CI Visibility test events that match a search query. Results are paginated similarly to logs.
Use this endpoint to see your latest test events.
sourcepub async fn search_ci_app_test_events(
&self,
params: SearchCIAppTestEventsOptionalParams,
) -> Result<CIAppTestEventsResponse, Error<SearchCIAppTestEventsError>>
pub async fn search_ci_app_test_events( &self, params: SearchCIAppTestEventsOptionalParams, ) -> Result<CIAppTestEventsResponse, Error<SearchCIAppTestEventsError>>
List endpoint returns CI Visibility test events that match a search query. Results are paginated similarly to logs.
Use this endpoint to build complex events filtering and search.
Examples found in repository?
12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let body = CIAppTestEventsRequest::new()
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@test.service:web-ui-tests AND @test.status:skip".to_string())
.to("now".to_string()),
)
.options(CIAppQueryOptions::new().timezone("GMT".to_string()))
.page(CIAppQueryPageOptions::new().limit(25))
.sort(CIAppSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let resp = api
.search_ci_app_test_events(SearchCIAppTestEventsOptionalParams::default().body(body))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn search_ci_app_test_events_with_pagination(
&self,
params: SearchCIAppTestEventsOptionalParams,
) -> impl Stream<Item = Result<CIAppTestEvent, Error<SearchCIAppTestEventsError>>> + '_
pub fn search_ci_app_test_events_with_pagination( &self, params: SearchCIAppTestEventsOptionalParams, ) -> impl Stream<Item = Result<CIAppTestEvent, Error<SearchCIAppTestEventsError>>> + '_
Examples found in repository?
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36
async fn main() {
let body = CIAppTestEventsRequest::new()
.filter(
CIAppTestsQueryFilter::new()
.from("now-15m".to_string())
.query("@test.status:pass AND -@language:python".to_string())
.to("now".to_string()),
)
.page(CIAppQueryPageOptions::new().limit(2))
.sort(CIAppSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = CIVisibilityTestsAPI::with_config(configuration);
let response = api.search_ci_app_test_events_with_pagination(
SearchCIAppTestEventsOptionalParams::default().body(body),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn search_ci_app_test_events_with_http_info(
&self,
params: SearchCIAppTestEventsOptionalParams,
) -> Result<ResponseContent<CIAppTestEventsResponse>, Error<SearchCIAppTestEventsError>>
pub async fn search_ci_app_test_events_with_http_info( &self, params: SearchCIAppTestEventsOptionalParams, ) -> Result<ResponseContent<CIAppTestEventsResponse>, Error<SearchCIAppTestEventsError>>
List endpoint returns CI Visibility test events that match a search query. Results are paginated similarly to logs.
Use this endpoint to build complex events filtering and search.