Struct datadog_api_client::datadogV2::api::api_dora_metrics::DORAMetricsAPI
source · pub struct DORAMetricsAPI { /* private fields */ }Expand description
Send events for DORA Metrics to measure and improve software delivery. See the DORA Metrics page for more information.
Implementations
sourceimpl DORAMetricsAPI
impl DORAMetricsAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
examples/v2_dora-metrics_CreateDORADeployment.rs (line 25)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32
async fn main() {
let body = DORADeploymentRequest::new(DORADeploymentRequestData::new(
DORADeploymentRequestAttributes::new(
1693491984000000000,
"shopist".to_string(),
1693491974000000000,
)
.git(DORAGitInfo::new(
"66adc9350f2cc9b250b69abddab733dd55e1a588".to_string(),
"https://github.com/organization/example-repository".to_string(),
))
.version("v1.12.07".to_string()),
));
let mut configuration = datadog::Configuration::new();
configuration.set_unstable_operation_enabled("v2.CreateDORADeployment", true);
let api = DORAMetricsAPI::with_config(configuration);
let resp = api.create_dora_deployment(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_dora-metrics_CreateDORAIncident.rs (line 26)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let body = DORAIncidentRequest::new(DORAIncidentRequestData::new(
DORAIncidentRequestAttributes::new(1707842944500000000)
.finished_at(1707842944600000000)
.git(DORAGitInfo::new(
"66adc9350f2cc9b250b69abddab733dd55e1a588".to_string(),
"https://github.com/organization/example-repository".to_string(),
))
.name("Webserver is down failing all requests".to_string())
.services(vec!["shopist".to_string()])
.severity("High".to_string())
.team("backend".to_string())
.version("v1.12.07".to_string()),
));
let mut configuration = datadog::Configuration::new();
configuration.set_unstable_operation_enabled("v2.CreateDORAIncident", true);
let api = DORAMetricsAPI::with_config(configuration);
let resp = api.create_dora_incident(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_dora_deployment(
&self,
body: DORADeploymentRequest,
) -> Result<DORADeploymentResponse, Error<CreateDORADeploymentError>>
pub async fn create_dora_deployment( &self, body: DORADeploymentRequest, ) -> Result<DORADeploymentResponse, Error<CreateDORADeploymentError>>
Use this API endpoint to provide data about deployments for DORA metrics.
This is necessary for:
- Deployment Frequency
- Change Lead Time
- Change Failure Rate
Examples found in repository?
examples/v2_dora-metrics_CreateDORADeployment.rs (line 26)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32
async fn main() {
let body = DORADeploymentRequest::new(DORADeploymentRequestData::new(
DORADeploymentRequestAttributes::new(
1693491984000000000,
"shopist".to_string(),
1693491974000000000,
)
.git(DORAGitInfo::new(
"66adc9350f2cc9b250b69abddab733dd55e1a588".to_string(),
"https://github.com/organization/example-repository".to_string(),
))
.version("v1.12.07".to_string()),
));
let mut configuration = datadog::Configuration::new();
configuration.set_unstable_operation_enabled("v2.CreateDORADeployment", true);
let api = DORAMetricsAPI::with_config(configuration);
let resp = api.create_dora_deployment(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_dora_deployment_with_http_info(
&self,
body: DORADeploymentRequest,
) -> Result<ResponseContent<DORADeploymentResponse>, Error<CreateDORADeploymentError>>
pub async fn create_dora_deployment_with_http_info( &self, body: DORADeploymentRequest, ) -> Result<ResponseContent<DORADeploymentResponse>, Error<CreateDORADeploymentError>>
Use this API endpoint to provide data about deployments for DORA metrics.
This is necessary for:
- Deployment Frequency
- Change Lead Time
- Change Failure Rate
sourcepub async fn create_dora_incident(
&self,
body: DORAIncidentRequest,
) -> Result<DORAIncidentResponse, Error<CreateDORAIncidentError>>
pub async fn create_dora_incident( &self, body: DORAIncidentRequest, ) -> Result<DORAIncidentResponse, Error<CreateDORAIncidentError>>
Use this API endpoint to provide data about incidents for DORA metrics.
This is necessary for:
- Change Failure Rate
- Time to Restore
Examples found in repository?
examples/v2_dora-metrics_CreateDORAIncident.rs (line 27)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33
async fn main() {
let body = DORAIncidentRequest::new(DORAIncidentRequestData::new(
DORAIncidentRequestAttributes::new(1707842944500000000)
.finished_at(1707842944600000000)
.git(DORAGitInfo::new(
"66adc9350f2cc9b250b69abddab733dd55e1a588".to_string(),
"https://github.com/organization/example-repository".to_string(),
))
.name("Webserver is down failing all requests".to_string())
.services(vec!["shopist".to_string()])
.severity("High".to_string())
.team("backend".to_string())
.version("v1.12.07".to_string()),
));
let mut configuration = datadog::Configuration::new();
configuration.set_unstable_operation_enabled("v2.CreateDORAIncident", true);
let api = DORAMetricsAPI::with_config(configuration);
let resp = api.create_dora_incident(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_dora_incident_with_http_info(
&self,
body: DORAIncidentRequest,
) -> Result<ResponseContent<DORAIncidentResponse>, Error<CreateDORAIncidentError>>
pub async fn create_dora_incident_with_http_info( &self, body: DORAIncidentRequest, ) -> Result<ResponseContent<DORAIncidentResponse>, Error<CreateDORAIncidentError>>
Use this API endpoint to provide data about incidents for DORA metrics.
This is necessary for:
- Change Failure Rate
- Time to Restore