#[non_exhaustive]pub struct ListLogsGetOptionalParams {
pub filter_query: Option<String>,
pub filter_indexes: Option<Vec<String>>,
pub filter_from: Option<DateTime<Utc>>,
pub filter_to: Option<DateTime<Utc>>,
pub filter_storage_tier: Option<LogsStorageTier>,
pub sort: Option<LogsSort>,
pub page_cursor: Option<String>,
pub page_limit: Option<i32>,
}Expand description
ListLogsGetOptionalParams is a struct for passing parameters to the method LogsAPI::list_logs_get
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.filter_query: Option<String>Search query following logs syntax.
filter_indexes: Option<Vec<String>>For customers with multiple indexes, the indexes to search. Defaults to ‘*’ which means all indexes
filter_from: Option<DateTime<Utc>>Minimum timestamp for requested logs.
filter_to: Option<DateTime<Utc>>Maximum timestamp for requested logs.
filter_storage_tier: Option<LogsStorageTier>Specifies the storage type to be used
sort: Option<LogsSort>Order of logs in results.
page_cursor: Option<String>List following results with a cursor provided in the previous query.
page_limit: Option<i32>Maximum number of logs in the response.
Implementations
sourceimpl ListLogsGetOptionalParams
impl ListLogsGetOptionalParams
sourcepub fn filter_query(self, value: String) -> Self
pub fn filter_query(self, value: String) -> Self
Search query following logs syntax.
Examples found in repository?
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let resp = api
.list_logs_get(
ListLogsGetOptionalParams::default()
.filter_query("datadog-agent".to_string())
.filter_indexes(vec!["main".to_string()])
.filter_from(
DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn filter_indexes(self, value: Vec<String>) -> Self
pub fn filter_indexes(self, value: Vec<String>) -> Self
For customers with multiple indexes, the indexes to search. Defaults to ‘*’ which means all indexes
Examples found in repository?
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let resp = api
.list_logs_get(
ListLogsGetOptionalParams::default()
.filter_query("datadog-agent".to_string())
.filter_indexes(vec!["main".to_string()])
.filter_from(
DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn filter_from(self, value: DateTime<Utc>) -> Self
pub fn filter_from(self, value: DateTime<Utc>) -> Self
Minimum timestamp for requested logs.
Examples found in repository?
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let resp = api
.list_logs_get(
ListLogsGetOptionalParams::default()
.filter_query("datadog-agent".to_string())
.filter_indexes(vec!["main".to_string()])
.filter_from(
DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn filter_to(self, value: DateTime<Utc>) -> Self
pub fn filter_to(self, value: DateTime<Utc>) -> Self
Maximum timestamp for requested logs.
Examples found in repository?
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let resp = api
.list_logs_get(
ListLogsGetOptionalParams::default()
.filter_query("datadog-agent".to_string())
.filter_indexes(vec!["main".to_string()])
.filter_from(
DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn filter_storage_tier(self, value: LogsStorageTier) -> Self
pub fn filter_storage_tier(self, value: LogsStorageTier) -> Self
Specifies the storage type to be used
sourcepub fn page_cursor(self, value: String) -> Self
pub fn page_cursor(self, value: String) -> Self
List following results with a cursor provided in the previous query.
sourcepub fn page_limit(self, value: i32) -> Self
pub fn page_limit(self, value: i32) -> Self
Maximum number of logs in the response.
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let response =
api.list_logs_get_with_pagination(ListLogsGetOptionalParams::default().page_limit(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}More examples
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let configuration = datadog::Configuration::new();
let api = LogsAPI::with_config(configuration);
let resp = api
.list_logs_get(
ListLogsGetOptionalParams::default()
.filter_query("datadog-agent".to_string())
.filter_indexes(vec!["main".to_string()])
.filter_from(
DateTime::parse_from_rfc3339("2020-09-17T11:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.filter_to(
DateTime::parse_from_rfc3339("2020-09-17T12:48:36+01:00")
.expect("Failed to parse datetime")
.with_timezone(&Utc),
)
.page_limit(5),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Trait Implementations
sourceimpl Clone for ListLogsGetOptionalParams
impl Clone for ListLogsGetOptionalParams
sourcefn clone(&self) -> ListLogsGetOptionalParams
fn clone(&self) -> ListLogsGetOptionalParams
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for ListLogsGetOptionalParams
impl Debug for ListLogsGetOptionalParams
sourceimpl Default for ListLogsGetOptionalParams
impl Default for ListLogsGetOptionalParams
sourcefn default() -> ListLogsGetOptionalParams
fn default() -> ListLogsGetOptionalParams