Module datadog_api_client::datadogV2::api::api_monitors
source · Structs
- Monitors allow you to watch a metric or check that you care about and notifies your team when a defined threshold has exceeded.
Enums
- CreateMonitorConfigPolicyError is a struct for typed errors of method
MonitorsAPI::create_monitor_config_policy - DeleteMonitorConfigPolicyError is a struct for typed errors of method
MonitorsAPI::delete_monitor_config_policy - GetMonitorConfigPolicyError is a struct for typed errors of method
MonitorsAPI::get_monitor_config_policy - ListMonitorConfigPoliciesError is a struct for typed errors of method
MonitorsAPI::list_monitor_config_policies - UpdateMonitorConfigPolicyError is a struct for typed errors of method
MonitorsAPI::update_monitor_config_policy