pub struct RUMAPI { /* private fields */ }Expand description
Manage your Real User Monitoring (RUM) applications, and search or aggregate your RUM events over HTTP. See the RUM & Session Replay page for more information
Implementations
sourceimpl RUMAPI
impl RUMAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
More examples
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.list_rum_events(ListRUMEventsOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let response =
api.list_rum_events_with_pagination(ListRUMEventsOptionalParams::default().page_limit(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "rum_application" in the system
let rum_application_data_id = std::env::var("RUM_APPLICATION_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.get_rum_application(rum_application_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "rum_application" in the system
let rum_application_data_id = std::env::var("RUM_APPLICATION_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.delete_rum_application(rum_application_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
async fn main() {
let body = RUMApplicationCreateRequest::new(RUMApplicationCreate::new(
RUMApplicationCreateAttributes::new("test-rum-5c67ebb32077e1d9".to_string())
.type_("ios".to_string()),
RUMApplicationCreateType::RUM_APPLICATION_CREATE,
));
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api.create_rum_application(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn aggregate_rum_events(
&self,
body: RUMAggregateRequest,
) -> Result<RUMAnalyticsAggregateResponse, Error<AggregateRUMEventsError>>
pub async fn aggregate_rum_events( &self, body: RUMAggregateRequest, ) -> Result<RUMAnalyticsAggregateResponse, Error<AggregateRUMEventsError>>
The API endpoint to aggregate RUM events into buckets of computed metrics and timeseries.
Examples found in repository?
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
let body = RUMAggregateRequest::new()
.compute(vec![RUMCompute::new(RUMAggregationFunction::PERCENTILE_90)
.metric("@view.time_spent".to_string())
.type_(RUMComputeType::TOTAL)])
.filter(
RUMQueryFilter::new()
.from("now-15m".to_string())
.query("@type:view AND @session.type:user".to_string())
.to("now".to_string()),
)
.group_by(vec![RUMGroupBy::new("@view.time_spent".to_string())
.limit(10)
.total(RUMGroupByTotal::RUMGroupByTotalBoolean(false))])
.options(RUMQueryOptions::new().timezone("GMT".to_string()))
.page(RUMQueryPageOptions::new().limit(25));
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api.aggregate_rum_events(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn aggregate_rum_events_with_http_info(
&self,
body: RUMAggregateRequest,
) -> Result<ResponseContent<RUMAnalyticsAggregateResponse>, Error<AggregateRUMEventsError>>
pub async fn aggregate_rum_events_with_http_info( &self, body: RUMAggregateRequest, ) -> Result<ResponseContent<RUMAnalyticsAggregateResponse>, Error<AggregateRUMEventsError>>
The API endpoint to aggregate RUM events into buckets of computed metrics and timeseries.
sourcepub async fn create_rum_application(
&self,
body: RUMApplicationCreateRequest,
) -> Result<RUMApplicationResponse, Error<CreateRUMApplicationError>>
pub async fn create_rum_application( &self, body: RUMApplicationCreateRequest, ) -> Result<RUMApplicationResponse, Error<CreateRUMApplicationError>>
Create a new RUM application in your organization.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
async fn main() {
let body = RUMApplicationCreateRequest::new(RUMApplicationCreate::new(
RUMApplicationCreateAttributes::new("test-rum-5c67ebb32077e1d9".to_string())
.type_("ios".to_string()),
RUMApplicationCreateType::RUM_APPLICATION_CREATE,
));
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api.create_rum_application(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_rum_application_with_http_info(
&self,
body: RUMApplicationCreateRequest,
) -> Result<ResponseContent<RUMApplicationResponse>, Error<CreateRUMApplicationError>>
pub async fn create_rum_application_with_http_info( &self, body: RUMApplicationCreateRequest, ) -> Result<ResponseContent<RUMApplicationResponse>, Error<CreateRUMApplicationError>>
Create a new RUM application in your organization.
sourcepub async fn delete_rum_application(
&self,
id: String,
) -> Result<(), Error<DeleteRUMApplicationError>>
pub async fn delete_rum_application( &self, id: String, ) -> Result<(), Error<DeleteRUMApplicationError>>
Delete an existing RUM application in your organization.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "rum_application" in the system
let rum_application_data_id = std::env::var("RUM_APPLICATION_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.delete_rum_application(rum_application_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_rum_application_with_http_info(
&self,
id: String,
) -> Result<ResponseContent<()>, Error<DeleteRUMApplicationError>>
pub async fn delete_rum_application_with_http_info( &self, id: String, ) -> Result<ResponseContent<()>, Error<DeleteRUMApplicationError>>
Delete an existing RUM application in your organization.
sourcepub async fn get_rum_application(
&self,
id: String,
) -> Result<RUMApplicationResponse, Error<GetRUMApplicationError>>
pub async fn get_rum_application( &self, id: String, ) -> Result<RUMApplicationResponse, Error<GetRUMApplicationError>>
Get the RUM application with given ID in your organization.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19
async fn main() {
// there is a valid "rum_application" in the system
let rum_application_data_id = std::env::var("RUM_APPLICATION_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.get_rum_application(rum_application_data_id.clone())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_rum_application_with_http_info(
&self,
id: String,
) -> Result<ResponseContent<RUMApplicationResponse>, Error<GetRUMApplicationError>>
pub async fn get_rum_application_with_http_info( &self, id: String, ) -> Result<ResponseContent<RUMApplicationResponse>, Error<GetRUMApplicationError>>
Get the RUM application with given ID in your organization.
sourcepub async fn get_rum_applications(
&self,
) -> Result<RUMApplicationsResponse, Error<GetRUMApplicationsError>>
pub async fn get_rum_applications( &self, ) -> Result<RUMApplicationsResponse, Error<GetRUMApplicationsError>>
List all the RUM applications in your organization.
sourcepub async fn get_rum_applications_with_http_info(
&self,
) -> Result<ResponseContent<RUMApplicationsResponse>, Error<GetRUMApplicationsError>>
pub async fn get_rum_applications_with_http_info( &self, ) -> Result<ResponseContent<RUMApplicationsResponse>, Error<GetRUMApplicationsError>>
List all the RUM applications in your organization.
sourcepub async fn list_rum_events(
&self,
params: ListRUMEventsOptionalParams,
) -> Result<RUMEventsResponse, Error<ListRUMEventsError>>
pub async fn list_rum_events( &self, params: ListRUMEventsOptionalParams, ) -> Result<RUMEventsResponse, Error<ListRUMEventsError>>
List endpoint returns events that match a RUM search query. Results are paginated.
Use this endpoint to see your latest RUM events.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18
async fn main() {
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.list_rum_events(ListRUMEventsOptionalParams::default())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn list_rum_events_with_pagination(
&self,
params: ListRUMEventsOptionalParams,
) -> impl Stream<Item = Result<RUMEvent, Error<ListRUMEventsError>>> + '_
pub fn list_rum_events_with_pagination( &self, params: ListRUMEventsOptionalParams, ) -> impl Stream<Item = Result<RUMEvent, Error<ListRUMEventsError>>> + '_
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let response =
api.list_rum_events_with_pagination(ListRUMEventsOptionalParams::default().page_limit(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn list_rum_events_with_http_info(
&self,
params: ListRUMEventsOptionalParams,
) -> Result<ResponseContent<RUMEventsResponse>, Error<ListRUMEventsError>>
pub async fn list_rum_events_with_http_info( &self, params: ListRUMEventsOptionalParams, ) -> Result<ResponseContent<RUMEventsResponse>, Error<ListRUMEventsError>>
List endpoint returns events that match a RUM search query. Results are paginated.
Use this endpoint to see your latest RUM events.
sourcepub async fn search_rum_events(
&self,
body: RUMSearchEventsRequest,
) -> Result<RUMEventsResponse, Error<SearchRUMEventsError>>
pub async fn search_rum_events( &self, body: RUMSearchEventsRequest, ) -> Result<RUMEventsResponse, Error<SearchRUMEventsError>>
List endpoint returns RUM events that match a RUM search query. Results are paginated.
Use this endpoint to build complex RUM events filtering and search.
Examples found in repository?
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
let body = RUMSearchEventsRequest::new()
.filter(
RUMQueryFilter::new()
.from("now-15m".to_string())
.query("@type:session AND @session.type:user".to_string())
.to("now".to_string()),
)
.options(
RUMQueryOptions::new()
.time_offset(0)
.timezone("GMT".to_string()),
)
.page(RUMQueryPageOptions::new().limit(25))
.sort(RUMSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api.search_rum_events(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn search_rum_events_with_pagination(
&self,
body: RUMSearchEventsRequest,
) -> impl Stream<Item = Result<RUMEvent, Error<SearchRUMEventsError>>> + '_
pub fn search_rum_events_with_pagination( &self, body: RUMSearchEventsRequest, ) -> impl Stream<Item = Result<RUMEvent, Error<SearchRUMEventsError>>> + '_
Examples found in repository?
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39
async fn main() {
let body = RUMSearchEventsRequest::new()
.filter(
RUMQueryFilter::new()
.from("now-15m".to_string())
.query("@type:session AND @session.type:user".to_string())
.to("now".to_string()),
)
.options(
RUMQueryOptions::new()
.time_offset(0)
.timezone("GMT".to_string()),
)
.page(RUMQueryPageOptions::new().limit(2))
.sort(RUMSort::TIMESTAMP_ASCENDING);
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let response = api.search_rum_events_with_pagination(body);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn search_rum_events_with_http_info(
&self,
body: RUMSearchEventsRequest,
) -> Result<ResponseContent<RUMEventsResponse>, Error<SearchRUMEventsError>>
pub async fn search_rum_events_with_http_info( &self, body: RUMSearchEventsRequest, ) -> Result<ResponseContent<RUMEventsResponse>, Error<SearchRUMEventsError>>
List endpoint returns RUM events that match a RUM search query. Results are paginated.
Use this endpoint to build complex RUM events filtering and search.
sourcepub async fn update_rum_application(
&self,
id: String,
body: RUMApplicationUpdateRequest,
) -> Result<RUMApplicationResponse, Error<UpdateRUMApplicationError>>
pub async fn update_rum_application( &self, id: String, body: RUMApplicationUpdateRequest, ) -> Result<RUMApplicationResponse, Error<UpdateRUMApplicationError>>
Update the RUM application with given ID in your organization.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
// there is a valid "rum_application" in the system
let rum_application_data_id = std::env::var("RUM_APPLICATION_DATA_ID").unwrap();
let body = RUMApplicationUpdateRequest::new(
RUMApplicationUpdate::new(
rum_application_data_id.clone(),
RUMApplicationUpdateType::RUM_APPLICATION_UPDATE,
)
.attributes(
RUMApplicationUpdateAttributes::new()
.name("updated_name_for_my_existing_rum_application".to_string())
.type_("browser".to_string()),
),
);
let configuration = datadog::Configuration::new();
let api = RUMAPI::with_config(configuration);
let resp = api
.update_rum_application(rum_application_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_rum_application_with_http_info(
&self,
id: String,
body: RUMApplicationUpdateRequest,
) -> Result<ResponseContent<RUMApplicationResponse>, Error<UpdateRUMApplicationError>>
pub async fn update_rum_application_with_http_info( &self, id: String, body: RUMApplicationUpdateRequest, ) -> Result<ResponseContent<RUMApplicationResponse>, Error<UpdateRUMApplicationError>>
Update the RUM application with given ID in your organization.