pub struct ServiceAccountsAPI { /* private fields */ }Expand description
Create, edit, and disable service accounts. See the Service Accounts page for more information.
Implementations
sourceimpl ServiceAccountsAPI
impl ServiceAccountsAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
examples/v2_service-accounts_ListServiceAccountApplicationKeys.rs (line 11)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.list_service_account_application_keys(
service_account_user_data_id.clone(),
ListServiceAccountApplicationKeysOptionalParams::default(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_service-accounts_CreateServiceAccountApplicationKey.rs (line 18)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Service-Account".to_string()),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.create_service_account_application_key(service_account_user_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-accounts_GetServiceAccountApplicationKey.rs (line 14)
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
// there is a valid "service_account_application_key" for "service_account_user"
let service_account_application_key_data_id =
std::env::var("SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.get_service_account_application_key(
service_account_user_data_id.clone(),
service_account_application_key_data_id.clone(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-accounts_DeleteServiceAccountApplicationKey.rs (line 14)
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
// there is a valid "service_account_application_key" for "service_account_user"
let service_account_application_key_data_id =
std::env::var("SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.delete_service_account_application_key(
service_account_user_data_id.clone(),
service_account_application_key_data_id.clone(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-accounts_CreateServiceAccountApplicationKey_3480494373.rs (line 25)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Service-Account".to_string()).scopes(Some(
vec![
"dashboards_read".to_string(),
"dashboards_write".to_string(),
"dashboards_public_share".to_string(),
],
)),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.create_service_account_application_key(service_account_user_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-accounts_CreateServiceAccount.rs (line 34)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41
async fn main() {
// there is a valid "role" in the system
let role_data_id = std::env::var("ROLE_DATA_ID").unwrap();
let body =
ServiceAccountCreateRequest::new(
ServiceAccountCreateData::new(
ServiceAccountCreateAttributes::new(
"Example-Service-Account@datadoghq.com".to_string(),
true,
)
.name("Test API Client".to_string()),
UsersType::USERS,
)
.relationships(UserRelationships::new().roles(
RelationshipToRoles::new().data(vec![RelationshipToRoleData::new()
.id(role_data_id.clone())
.type_(RolesType::ROLES)]),
)),
);
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api.create_service_account(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Additional examples can be found in:
pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_service_account(
&self,
body: ServiceAccountCreateRequest,
) -> Result<UserResponse, Error<CreateServiceAccountError>>
pub async fn create_service_account( &self, body: ServiceAccountCreateRequest, ) -> Result<UserResponse, Error<CreateServiceAccountError>>
Create a service account for your organization.
Examples found in repository?
examples/v2_service-accounts_CreateServiceAccount.rs (line 35)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41
async fn main() {
// there is a valid "role" in the system
let role_data_id = std::env::var("ROLE_DATA_ID").unwrap();
let body =
ServiceAccountCreateRequest::new(
ServiceAccountCreateData::new(
ServiceAccountCreateAttributes::new(
"Example-Service-Account@datadoghq.com".to_string(),
true,
)
.name("Test API Client".to_string()),
UsersType::USERS,
)
.relationships(UserRelationships::new().roles(
RelationshipToRoles::new().data(vec![RelationshipToRoleData::new()
.id(role_data_id.clone())
.type_(RolesType::ROLES)]),
)),
);
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api.create_service_account(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_service_account_with_http_info(
&self,
body: ServiceAccountCreateRequest,
) -> Result<ResponseContent<UserResponse>, Error<CreateServiceAccountError>>
pub async fn create_service_account_with_http_info( &self, body: ServiceAccountCreateRequest, ) -> Result<ResponseContent<UserResponse>, Error<CreateServiceAccountError>>
Create a service account for your organization.
sourcepub async fn create_service_account_application_key(
&self,
service_account_id: String,
body: ApplicationKeyCreateRequest,
) -> Result<ApplicationKeyResponse, Error<CreateServiceAccountApplicationKeyError>>
pub async fn create_service_account_application_key( &self, service_account_id: String, body: ApplicationKeyCreateRequest, ) -> Result<ApplicationKeyResponse, Error<CreateServiceAccountApplicationKeyError>>
Create an application key for this service account.
Examples found in repository?
examples/v2_service-accounts_CreateServiceAccountApplicationKey.rs (line 20)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Service-Account".to_string()),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.create_service_account_application_key(service_account_user_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_service-accounts_CreateServiceAccountApplicationKey_3480494373.rs (line 27)
11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let body = ApplicationKeyCreateRequest::new(ApplicationKeyCreateData::new(
ApplicationKeyCreateAttributes::new("Example-Service-Account".to_string()).scopes(Some(
vec![
"dashboards_read".to_string(),
"dashboards_write".to_string(),
"dashboards_public_share".to_string(),
],
)),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.create_service_account_application_key(service_account_user_data_id.clone(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_service_account_application_key_with_http_info(
&self,
service_account_id: String,
body: ApplicationKeyCreateRequest,
) -> Result<ResponseContent<ApplicationKeyResponse>, Error<CreateServiceAccountApplicationKeyError>>
pub async fn create_service_account_application_key_with_http_info( &self, service_account_id: String, body: ApplicationKeyCreateRequest, ) -> Result<ResponseContent<ApplicationKeyResponse>, Error<CreateServiceAccountApplicationKeyError>>
Create an application key for this service account.
sourcepub async fn delete_service_account_application_key(
&self,
service_account_id: String,
app_key_id: String,
) -> Result<(), Error<DeleteServiceAccountApplicationKeyError>>
pub async fn delete_service_account_application_key( &self, service_account_id: String, app_key_id: String, ) -> Result<(), Error<DeleteServiceAccountApplicationKeyError>>
Delete an application key owned by this service account.
Examples found in repository?
examples/v2_service-accounts_DeleteServiceAccountApplicationKey.rs (lines 16-19)
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
// there is a valid "service_account_application_key" for "service_account_user"
let service_account_application_key_data_id =
std::env::var("SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.delete_service_account_application_key(
service_account_user_data_id.clone(),
service_account_application_key_data_id.clone(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_service_account_application_key_with_http_info(
&self,
service_account_id: String,
app_key_id: String,
) -> Result<ResponseContent<()>, Error<DeleteServiceAccountApplicationKeyError>>
pub async fn delete_service_account_application_key_with_http_info( &self, service_account_id: String, app_key_id: String, ) -> Result<ResponseContent<()>, Error<DeleteServiceAccountApplicationKeyError>>
Delete an application key owned by this service account.
sourcepub async fn get_service_account_application_key(
&self,
service_account_id: String,
app_key_id: String,
) -> Result<PartialApplicationKeyResponse, Error<GetServiceAccountApplicationKeyError>>
pub async fn get_service_account_application_key( &self, service_account_id: String, app_key_id: String, ) -> Result<PartialApplicationKeyResponse, Error<GetServiceAccountApplicationKeyError>>
Get an application key owned by this service account.
Examples found in repository?
examples/v2_service-accounts_GetServiceAccountApplicationKey.rs (lines 16-19)
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
// there is a valid "service_account_application_key" for "service_account_user"
let service_account_application_key_data_id =
std::env::var("SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.get_service_account_application_key(
service_account_user_data_id.clone(),
service_account_application_key_data_id.clone(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_service_account_application_key_with_http_info(
&self,
service_account_id: String,
app_key_id: String,
) -> Result<ResponseContent<PartialApplicationKeyResponse>, Error<GetServiceAccountApplicationKeyError>>
pub async fn get_service_account_application_key_with_http_info( &self, service_account_id: String, app_key_id: String, ) -> Result<ResponseContent<PartialApplicationKeyResponse>, Error<GetServiceAccountApplicationKeyError>>
Get an application key owned by this service account.
sourcepub async fn list_service_account_application_keys(
&self,
service_account_id: String,
params: ListServiceAccountApplicationKeysOptionalParams,
) -> Result<ListApplicationKeysResponse, Error<ListServiceAccountApplicationKeysError>>
pub async fn list_service_account_application_keys( &self, service_account_id: String, params: ListServiceAccountApplicationKeysOptionalParams, ) -> Result<ListApplicationKeysResponse, Error<ListServiceAccountApplicationKeysError>>
List all application keys available for this service account.
Examples found in repository?
examples/v2_service-accounts_ListServiceAccountApplicationKeys.rs (lines 13-16)
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.list_service_account_application_keys(
service_account_user_data_id.clone(),
ListServiceAccountApplicationKeysOptionalParams::default(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_service_account_application_keys_with_http_info(
&self,
service_account_id: String,
params: ListServiceAccountApplicationKeysOptionalParams,
) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListServiceAccountApplicationKeysError>>
pub async fn list_service_account_application_keys_with_http_info( &self, service_account_id: String, params: ListServiceAccountApplicationKeysOptionalParams, ) -> Result<ResponseContent<ListApplicationKeysResponse>, Error<ListServiceAccountApplicationKeysError>>
List all application keys available for this service account.
sourcepub async fn update_service_account_application_key(
&self,
service_account_id: String,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<PartialApplicationKeyResponse, Error<UpdateServiceAccountApplicationKeyError>>
pub async fn update_service_account_application_key( &self, service_account_id: String, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<PartialApplicationKeyResponse, Error<UpdateServiceAccountApplicationKeyError>>
Edit an application key owned by this service account.
Examples found in repository?
examples/v2_service-accounts_UpdateServiceAccountApplicationKey.rs (lines 26-30)
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37
async fn main() {
// there is a valid "service_account_user" in the system
let service_account_user_data_id = std::env::var("SERVICE_ACCOUNT_USER_DATA_ID").unwrap();
// there is a valid "service_account_application_key" for "service_account_user"
let service_account_application_key_data_id =
std::env::var("SERVICE_ACCOUNT_APPLICATION_KEY_DATA_ID").unwrap();
let body = ApplicationKeyUpdateRequest::new(ApplicationKeyUpdateData::new(
ApplicationKeyUpdateAttributes::new()
.name("Application Key for managing dashboards-updated".to_string()),
service_account_application_key_data_id.clone(),
ApplicationKeysType::APPLICATION_KEYS,
));
let configuration = datadog::Configuration::new();
let api = ServiceAccountsAPI::with_config(configuration);
let resp = api
.update_service_account_application_key(
service_account_user_data_id.clone(),
service_account_application_key_data_id.clone(),
body,
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_service_account_application_key_with_http_info(
&self,
service_account_id: String,
app_key_id: String,
body: ApplicationKeyUpdateRequest,
) -> Result<ResponseContent<PartialApplicationKeyResponse>, Error<UpdateServiceAccountApplicationKeyError>>
pub async fn update_service_account_application_key_with_http_info( &self, service_account_id: String, app_key_id: String, body: ApplicationKeyUpdateRequest, ) -> Result<ResponseContent<PartialApplicationKeyResponse>, Error<UpdateServiceAccountApplicationKeyError>>
Edit an application key owned by this service account.