pub struct ServiceDefinitionAPI { /* private fields */ }Expand description
API to create, update, retrieve and delete service definitions.
Implementations
sourceimpl ServiceDefinitionAPI
impl ServiceDefinitionAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
examples/v2_service-definition_DeleteServiceDefinition.rs (line 8)
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.delete_service_definition("service-definition-test".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_service-definition_ListServiceDefinitions.rs (line 10)
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.list_service_definitions(
ListServiceDefinitionsOptionalParams::default()
.schema_version(ServiceDefinitionSchemaVersions::V2_1),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-definition_ListServiceDefinitions_336468013.rs (line 11)
9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let response = api.list_service_definitions_with_pagination(
ListServiceDefinitionsOptionalParams::default().page_size(2),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}examples/v2_service-definition_GetServiceDefinition.rs (line 10)
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.get_service_definition(
"service-definition-test".to_string(),
GetServiceDefinitionOptionalParams::default()
.schema_version(ServiceDefinitionSchemaVersions::V2_1),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-definition_CreateOrUpdateServiceDefinitions_1808735248.rs (line 71)
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2(Box::new(
ServiceDefinitionV2::new(
"service-exampleservicedefinition".to_string(),
ServiceDefinitionV2Version::V2,
)
.contacts(vec![ServiceDefinitionV2Contact::ServiceDefinitionV2Email(
Box::new(
ServiceDefinitionV2Email::new(
"contact@datadoghq.com".to_string(),
ServiceDefinitionV2EmailType::EMAIL,
)
.name("Team Email".to_string()),
),
)])
.dd_team("my-team".to_string())
.docs(vec![ServiceDefinitionV2Doc::new(
"Architecture".to_string(),
"https://gdrive/mydoc".to_string(),
)
.provider("google drive".to_string())])
.extensions(BTreeMap::from([(
"myorgextension".to_string(),
Value::from("extensionvalue"),
)]))
.integrations(
ServiceDefinitionV2Integrations::new()
.opsgenie(
ServiceDefinitionV2Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2OpsgenieRegion::US),
)
.pagerduty("https://my-org.pagerduty.com/service-directory/PMyService".to_string()),
)
.links(vec![ServiceDefinitionV2Link::new(
"Runbook".to_string(),
ServiceDefinitionV2LinkType::RUNBOOK,
"https://my-runbook".to_string(),
)])
.repos(vec![ServiceDefinitionV2Repo::new(
"Source Code".to_string(),
"https://github.com/DataDog/schema".to_string(),
)
.provider("GitHub".to_string())])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string()),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-definition_CreateOrUpdateServiceDefinitions_2621709423.rs (line 68)
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2Dot2(Box::new(
ServiceDefinitionV2Dot2::new(
"service-exampleservicedefinition".to_string(),
ServiceDefinitionV2Dot2Version::V2_2,
)
.contacts(vec![ServiceDefinitionV2Dot2Contact::new(
"contact@datadoghq.com".to_string(),
"email".to_string(),
)
.name("Team Email".to_string())])
.extensions(BTreeMap::from([(
"myorgextension".to_string(),
Value::from("extensionvalue"),
)]))
.integrations(
ServiceDefinitionV2Dot2Integrations::new()
.opsgenie(
ServiceDefinitionV2Dot2Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2Dot2OpsgenieRegion::US),
)
.pagerduty(ServiceDefinitionV2Dot2Pagerduty::new().service_url(
"https://my-org.pagerduty.com/service-directory/PMyService".to_string(),
)),
)
.links(vec![
ServiceDefinitionV2Dot2Link::new(
"Runbook".to_string(),
"runbook".to_string(),
"https://my-runbook".to_string(),
),
ServiceDefinitionV2Dot2Link::new(
"Source Code".to_string(),
"repo".to_string(),
"https://github.com/DataDog/schema".to_string(),
)
.provider("GitHub".to_string()),
ServiceDefinitionV2Dot2Link::new(
"Architecture".to_string(),
"doc".to_string(),
"https://my-runbook".to_string(),
)
.provider("Gigoogle drivetHub".to_string()),
])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string()),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Additional examples can be found in:
pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_or_update_service_definitions(
&self,
body: ServiceDefinitionsCreateRequest,
) -> Result<ServiceDefinitionCreateResponse, Error<CreateOrUpdateServiceDefinitionsError>>
pub async fn create_or_update_service_definitions( &self, body: ServiceDefinitionsCreateRequest, ) -> Result<ServiceDefinitionCreateResponse, Error<CreateOrUpdateServiceDefinitionsError>>
Create or update service definition in the Datadog Service Catalog.
Examples found in repository?
examples/v2_service-definition_CreateOrUpdateServiceDefinitions_1808735248.rs (line 72)
21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2(Box::new(
ServiceDefinitionV2::new(
"service-exampleservicedefinition".to_string(),
ServiceDefinitionV2Version::V2,
)
.contacts(vec![ServiceDefinitionV2Contact::ServiceDefinitionV2Email(
Box::new(
ServiceDefinitionV2Email::new(
"contact@datadoghq.com".to_string(),
ServiceDefinitionV2EmailType::EMAIL,
)
.name("Team Email".to_string()),
),
)])
.dd_team("my-team".to_string())
.docs(vec![ServiceDefinitionV2Doc::new(
"Architecture".to_string(),
"https://gdrive/mydoc".to_string(),
)
.provider("google drive".to_string())])
.extensions(BTreeMap::from([(
"myorgextension".to_string(),
Value::from("extensionvalue"),
)]))
.integrations(
ServiceDefinitionV2Integrations::new()
.opsgenie(
ServiceDefinitionV2Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2OpsgenieRegion::US),
)
.pagerduty("https://my-org.pagerduty.com/service-directory/PMyService".to_string()),
)
.links(vec![ServiceDefinitionV2Link::new(
"Runbook".to_string(),
ServiceDefinitionV2LinkType::RUNBOOK,
"https://my-runbook".to_string(),
)])
.repos(vec![ServiceDefinitionV2Repo::new(
"Source Code".to_string(),
"https://github.com/DataDog/schema".to_string(),
)
.provider("GitHub".to_string())])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string()),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_service-definition_CreateOrUpdateServiceDefinitions_2621709423.rs (line 69)
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2Dot2(Box::new(
ServiceDefinitionV2Dot2::new(
"service-exampleservicedefinition".to_string(),
ServiceDefinitionV2Dot2Version::V2_2,
)
.contacts(vec![ServiceDefinitionV2Dot2Contact::new(
"contact@datadoghq.com".to_string(),
"email".to_string(),
)
.name("Team Email".to_string())])
.extensions(BTreeMap::from([(
"myorgextension".to_string(),
Value::from("extensionvalue"),
)]))
.integrations(
ServiceDefinitionV2Dot2Integrations::new()
.opsgenie(
ServiceDefinitionV2Dot2Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2Dot2OpsgenieRegion::US),
)
.pagerduty(ServiceDefinitionV2Dot2Pagerduty::new().service_url(
"https://my-org.pagerduty.com/service-directory/PMyService".to_string(),
)),
)
.links(vec![
ServiceDefinitionV2Dot2Link::new(
"Runbook".to_string(),
"runbook".to_string(),
"https://my-runbook".to_string(),
),
ServiceDefinitionV2Dot2Link::new(
"Source Code".to_string(),
"repo".to_string(),
"https://github.com/DataDog/schema".to_string(),
)
.provider("GitHub".to_string()),
ServiceDefinitionV2Dot2Link::new(
"Architecture".to_string(),
"doc".to_string(),
"https://my-runbook".to_string(),
)
.provider("Gigoogle drivetHub".to_string()),
])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string()),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-definition_CreateOrUpdateServiceDefinitions.rs (line 73)
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2Dot2(Box::new(
ServiceDefinitionV2Dot2::new(
"my-service".to_string(),
ServiceDefinitionV2Dot2Version::V2_2,
)
.application("my-app".to_string())
.ci_pipeline_fingerprints(vec!["j88xdEy0J5lc".to_string(), "eZ7LMljCk8vo".to_string()])
.contacts(vec![ServiceDefinitionV2Dot2Contact::new(
"https://teams.microsoft.com/myteam".to_string(),
"slack".to_string(),
)
.name("My team channel".to_string())])
.description("My service description".to_string())
.extensions(BTreeMap::from([(
"myorg/extension".to_string(),
Value::from("extensionValue"),
)]))
.integrations(
ServiceDefinitionV2Dot2Integrations::new()
.opsgenie(
ServiceDefinitionV2Dot2Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2Dot2OpsgenieRegion::US),
)
.pagerduty(ServiceDefinitionV2Dot2Pagerduty::new().service_url(
"https://my-org.pagerduty.com/service-directory/PMyService".to_string(),
)),
)
.languages(vec![
"dotnet".to_string(),
"go".to_string(),
"java".to_string(),
"js".to_string(),
"php".to_string(),
"python".to_string(),
"ruby".to_string(),
"c++".to_string(),
])
.lifecycle("sandbox".to_string())
.links(vec![ServiceDefinitionV2Dot2Link::new(
"Runbook".to_string(),
"runbook".to_string(),
"https://my-runbook".to_string(),
)
.provider("Github".to_string())])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string())
.tier("High".to_string())
.type_(ServiceDefinitionV2Dot2Type::WEB),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}examples/v2_service-definition_CreateOrUpdateServiceDefinitions_2619874414.rs (line 76)
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82
async fn main() {
let body = ServiceDefinitionsCreateRequest::ServiceDefinitionV2Dot1(Box::new(
ServiceDefinitionV2Dot1::new(
"service-exampleservicedefinition".to_string(),
ServiceDefinitionV2Dot1Version::V2_1,
)
.contacts(vec![
ServiceDefinitionV2Dot1Contact::ServiceDefinitionV2Dot1Email(Box::new(
ServiceDefinitionV2Dot1Email::new(
"contact@datadoghq.com".to_string(),
ServiceDefinitionV2Dot1EmailType::EMAIL,
)
.name("Team Email".to_string()),
)),
])
.extensions(BTreeMap::from([(
"myorgextension".to_string(),
Value::from("extensionvalue"),
)]))
.integrations(
ServiceDefinitionV2Dot1Integrations::new()
.opsgenie(
ServiceDefinitionV2Dot1Opsgenie::new(
"https://my-org.opsgenie.com/service/123e4567-e89b-12d3-a456-426614174000"
.to_string(),
)
.region(ServiceDefinitionV2Dot1OpsgenieRegion::US),
)
.pagerduty(ServiceDefinitionV2Dot1Pagerduty::new().service_url(
"https://my-org.pagerduty.com/service-directory/PMyService".to_string(),
)),
)
.links(vec![
ServiceDefinitionV2Dot1Link::new(
"Runbook".to_string(),
ServiceDefinitionV2Dot1LinkType::RUNBOOK,
"https://my-runbook".to_string(),
),
ServiceDefinitionV2Dot1Link::new(
"Source Code".to_string(),
ServiceDefinitionV2Dot1LinkType::REPO,
"https://github.com/DataDog/schema".to_string(),
)
.provider("GitHub".to_string()),
ServiceDefinitionV2Dot1Link::new(
"Architecture".to_string(),
ServiceDefinitionV2Dot1LinkType::DOC,
"https://my-runbook".to_string(),
)
.provider("Gigoogle drivetHub".to_string()),
])
.tags(vec!["my:tag".to_string(), "service:tag".to_string()])
.team("my-team".to_string()),
));
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api.create_or_update_service_definitions(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_or_update_service_definitions_with_http_info(
&self,
body: ServiceDefinitionsCreateRequest,
) -> Result<ResponseContent<ServiceDefinitionCreateResponse>, Error<CreateOrUpdateServiceDefinitionsError>>
pub async fn create_or_update_service_definitions_with_http_info( &self, body: ServiceDefinitionsCreateRequest, ) -> Result<ResponseContent<ServiceDefinitionCreateResponse>, Error<CreateOrUpdateServiceDefinitionsError>>
Create or update service definition in the Datadog Service Catalog.
sourcepub async fn delete_service_definition(
&self,
service_name: String,
) -> Result<(), Error<DeleteServiceDefinitionError>>
pub async fn delete_service_definition( &self, service_name: String, ) -> Result<(), Error<DeleteServiceDefinitionError>>
Delete a single service definition in the Datadog Service Catalog.
Examples found in repository?
examples/v2_service-definition_DeleteServiceDefinition.rs (line 10)
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.delete_service_definition("service-definition-test".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn delete_service_definition_with_http_info(
&self,
service_name: String,
) -> Result<ResponseContent<()>, Error<DeleteServiceDefinitionError>>
pub async fn delete_service_definition_with_http_info( &self, service_name: String, ) -> Result<ResponseContent<()>, Error<DeleteServiceDefinitionError>>
Delete a single service definition in the Datadog Service Catalog.
sourcepub async fn get_service_definition(
&self,
service_name: String,
params: GetServiceDefinitionOptionalParams,
) -> Result<ServiceDefinitionGetResponse, Error<GetServiceDefinitionError>>
pub async fn get_service_definition( &self, service_name: String, params: GetServiceDefinitionOptionalParams, ) -> Result<ServiceDefinitionGetResponse, Error<GetServiceDefinitionError>>
Get a single service definition from the Datadog Service Catalog.
Examples found in repository?
examples/v2_service-definition_GetServiceDefinition.rs (lines 12-16)
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.get_service_definition(
"service-definition-test".to_string(),
GetServiceDefinitionOptionalParams::default()
.schema_version(ServiceDefinitionSchemaVersions::V2_1),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_service_definition_with_http_info(
&self,
service_name: String,
params: GetServiceDefinitionOptionalParams,
) -> Result<ResponseContent<ServiceDefinitionGetResponse>, Error<GetServiceDefinitionError>>
pub async fn get_service_definition_with_http_info( &self, service_name: String, params: GetServiceDefinitionOptionalParams, ) -> Result<ResponseContent<ServiceDefinitionGetResponse>, Error<GetServiceDefinitionError>>
Get a single service definition from the Datadog Service Catalog.
sourcepub async fn list_service_definitions(
&self,
params: ListServiceDefinitionsOptionalParams,
) -> Result<ServiceDefinitionsListResponse, Error<ListServiceDefinitionsError>>
pub async fn list_service_definitions( &self, params: ListServiceDefinitionsOptionalParams, ) -> Result<ServiceDefinitionsListResponse, Error<ListServiceDefinitionsError>>
Get a list of all service definitions from the Datadog Service Catalog.
Examples found in repository?
examples/v2_service-definition_ListServiceDefinitions.rs (lines 12-15)
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let resp = api
.list_service_definitions(
ListServiceDefinitionsOptionalParams::default()
.schema_version(ServiceDefinitionSchemaVersions::V2_1),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn list_service_definitions_with_pagination(
&self,
params: ListServiceDefinitionsOptionalParams,
) -> impl Stream<Item = Result<ServiceDefinitionData, Error<ListServiceDefinitionsError>>> + '_
pub fn list_service_definitions_with_pagination( &self, params: ListServiceDefinitionsOptionalParams, ) -> impl Stream<Item = Result<ServiceDefinitionData, Error<ListServiceDefinitionsError>>> + '_
Examples found in repository?
examples/v2_service-definition_ListServiceDefinitions_336468013.rs (lines 12-14)
9 10 11 12 13 14 15 16 17 18 19 20 21 22 23
async fn main() {
let configuration = datadog::Configuration::new();
let api = ServiceDefinitionAPI::with_config(configuration);
let response = api.list_service_definitions_with_pagination(
ListServiceDefinitionsOptionalParams::default().page_size(2),
);
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn list_service_definitions_with_http_info(
&self,
params: ListServiceDefinitionsOptionalParams,
) -> Result<ResponseContent<ServiceDefinitionsListResponse>, Error<ListServiceDefinitionsError>>
pub async fn list_service_definitions_with_http_info( &self, params: ListServiceDefinitionsOptionalParams, ) -> Result<ResponseContent<ServiceDefinitionsListResponse>, Error<ListServiceDefinitionsError>>
Get a list of all service definitions from the Datadog Service Catalog.