Struct datadog_api_client::datadogV2::api::api_users::ListUsersOptionalParams
source · #[non_exhaustive]pub struct ListUsersOptionalParams {
pub page_size: Option<i64>,
pub page_number: Option<i64>,
pub sort: Option<String>,
pub sort_dir: Option<QuerySortOrder>,
pub filter: Option<String>,
pub filter_status: Option<String>,
}Expand description
ListUsersOptionalParams is a struct for passing parameters to the method UsersAPI::list_users
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.page_size: Option<i64>Size for a given page. The maximum allowed value is 100.
page_number: Option<i64>Specific page number to return.
sort: Option<String>User attribute to order results by. Sort order is ascending by default.
Sort order is descending if the field
is prefixed by a negative sign, for example sort=-name. Options: name,
modified_at, user_count.
sort_dir: Option<QuerySortOrder>Direction of sort. Options: asc, desc.
filter: Option<String>Filter all users by the given string. Defaults to no filtering.
filter_status: Option<String>Filter on status attribute.
Comma separated list, with possible values Active, Pending, and Disabled.
Defaults to no filtering.
Implementations
sourceimpl ListUsersOptionalParams
impl ListUsersOptionalParams
sourcepub fn page_size(self, value: i64) -> Self
pub fn page_size(self, value: i64) -> Self
Size for a given page. The maximum allowed value is 100.
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let response = api.list_users_with_pagination(ListUsersOptionalParams::default().page_size(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub fn page_number(self, value: i64) -> Self
pub fn page_number(self, value: i64) -> Self
Specific page number to return.
sourcepub fn sort(self, value: String) -> Self
pub fn sort(self, value: String) -> Self
User attribute to order results by. Sort order is ascending by default.
Sort order is descending if the field
is prefixed by a negative sign, for example sort=-name. Options: name,
modified_at, user_count.
sourcepub fn sort_dir(self, value: QuerySortOrder) -> Self
pub fn sort_dir(self, value: QuerySortOrder) -> Self
Direction of sort. Options: asc, desc.
sourcepub fn filter(self, value: String) -> Self
pub fn filter(self, value: String) -> Self
Filter all users by the given string. Defaults to no filtering.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
// there is a valid "user" in the system
let user_data_attributes_email = std::env::var("USER_DATA_ATTRIBUTES_EMAIL").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api
.list_users(ListUsersOptionalParams::default().filter(user_data_attributes_email.clone()))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn filter_status(self, value: String) -> Self
pub fn filter_status(self, value: String) -> Self
Filter on status attribute.
Comma separated list, with possible values Active, Pending, and Disabled.
Defaults to no filtering.