pub struct UsersAPI { /* private fields */ }Expand description
Create, edit, and disable users.
Implementations
sourceimpl UsersAPI
impl UsersAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api
.list_user_organizations("00000000-0000-9999-0000-000000000000".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.get_user(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.disable_user(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.list_user_permissions(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// the "user" has a "user_invitation"
let user_invitation_id = std::env::var("USER_INVITATION_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.get_invitation(user_invitation_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let response = api.list_users_with_pagination(ListUsersOptionalParams::default().page_size(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn create_user(
&self,
body: UserCreateRequest,
) -> Result<UserResponse, Error<CreateUserError>>
pub async fn create_user( &self, body: UserCreateRequest, ) -> Result<UserResponse, Error<CreateUserError>>
Create a user for your organization.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
async fn main() {
let body = UserCreateRequest::new(UserCreateData::new(
UserCreateAttributes::new("Example-User@datadoghq.com".to_string())
.name("Datadog API Client Python".to_string()),
UsersType::USERS,
));
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.create_user(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_user_with_http_info(
&self,
body: UserCreateRequest,
) -> Result<ResponseContent<UserResponse>, Error<CreateUserError>>
pub async fn create_user_with_http_info( &self, body: UserCreateRequest, ) -> Result<ResponseContent<UserResponse>, Error<CreateUserError>>
Create a user for your organization.
sourcepub async fn disable_user(
&self,
user_id: String,
) -> Result<(), Error<DisableUserError>>
pub async fn disable_user( &self, user_id: String, ) -> Result<(), Error<DisableUserError>>
Disable a user. Can only be used with an application key belonging to an administrator user.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.disable_user(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn disable_user_with_http_info(
&self,
user_id: String,
) -> Result<ResponseContent<()>, Error<DisableUserError>>
pub async fn disable_user_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<()>, Error<DisableUserError>>
Disable a user. Can only be used with an application key belonging to an administrator user.
sourcepub async fn get_invitation(
&self,
user_invitation_uuid: String,
) -> Result<UserInvitationResponse, Error<GetInvitationError>>
pub async fn get_invitation( &self, user_invitation_uuid: String, ) -> Result<UserInvitationResponse, Error<GetInvitationError>>
Returns a single user invitation by its UUID.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// the "user" has a "user_invitation"
let user_invitation_id = std::env::var("USER_INVITATION_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.get_invitation(user_invitation_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_invitation_with_http_info(
&self,
user_invitation_uuid: String,
) -> Result<ResponseContent<UserInvitationResponse>, Error<GetInvitationError>>
pub async fn get_invitation_with_http_info( &self, user_invitation_uuid: String, ) -> Result<ResponseContent<UserInvitationResponse>, Error<GetInvitationError>>
Returns a single user invitation by its UUID.
sourcepub async fn get_user(
&self,
user_id: String,
) -> Result<UserResponse, Error<GetUserError>>
pub async fn get_user( &self, user_id: String, ) -> Result<UserResponse, Error<GetUserError>>
Get a user in the organization specified by the user’s user_id.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.get_user(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_user_with_http_info(
&self,
user_id: String,
) -> Result<ResponseContent<UserResponse>, Error<GetUserError>>
pub async fn get_user_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<UserResponse>, Error<GetUserError>>
Get a user in the organization specified by the user’s user_id.
sourcepub async fn list_user_organizations(
&self,
user_id: String,
) -> Result<UserResponse, Error<ListUserOrganizationsError>>
pub async fn list_user_organizations( &self, user_id: String, ) -> Result<UserResponse, Error<ListUserOrganizationsError>>
Get a user organization. Returns the user information and all organizations joined by this user.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api
.list_user_organizations("00000000-0000-9999-0000-000000000000".to_string())
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_user_organizations_with_http_info(
&self,
user_id: String,
) -> Result<ResponseContent<UserResponse>, Error<ListUserOrganizationsError>>
pub async fn list_user_organizations_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<UserResponse>, Error<ListUserOrganizationsError>>
Get a user organization. Returns the user information and all organizations joined by this user.
sourcepub async fn list_user_permissions(
&self,
user_id: String,
) -> Result<PermissionsResponse, Error<ListUserPermissionsError>>
pub async fn list_user_permissions( &self, user_id: String, ) -> Result<PermissionsResponse, Error<ListUserPermissionsError>>
Get a user permission set. Returns a list of the user’s permissions granted by the associated user’s roles.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.list_user_permissions(user_data_id.clone()).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_user_permissions_with_http_info(
&self,
user_id: String,
) -> Result<ResponseContent<PermissionsResponse>, Error<ListUserPermissionsError>>
pub async fn list_user_permissions_with_http_info( &self, user_id: String, ) -> Result<ResponseContent<PermissionsResponse>, Error<ListUserPermissionsError>>
Get a user permission set. Returns a list of the user’s permissions granted by the associated user’s roles.
sourcepub async fn list_users(
&self,
params: ListUsersOptionalParams,
) -> Result<UsersResponse, Error<ListUsersError>>
pub async fn list_users( &self, params: ListUsersOptionalParams, ) -> Result<UsersResponse, Error<ListUsersError>>
Get the list of all users in the organization. This list includes all users even if they are deactivated or unverified.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
// there is a valid "user" in the system
let user_data_attributes_email = std::env::var("USER_DATA_ATTRIBUTES_EMAIL").unwrap();
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api
.list_users(ListUsersOptionalParams::default().filter(user_data_attributes_email.clone()))
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn list_users_with_pagination(
&self,
params: ListUsersOptionalParams,
) -> impl Stream<Item = Result<User, Error<ListUsersError>>> + '_
pub fn list_users_with_pagination( &self, params: ListUsersOptionalParams, ) -> impl Stream<Item = Result<User, Error<ListUsersError>>> + '_
Examples found in repository?
9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let response = api.list_users_with_pagination(ListUsersOptionalParams::default().page_size(2));
pin_mut!(response);
while let Some(resp) = response.next().await {
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}
}sourcepub async fn list_users_with_http_info(
&self,
params: ListUsersOptionalParams,
) -> Result<ResponseContent<UsersResponse>, Error<ListUsersError>>
pub async fn list_users_with_http_info( &self, params: ListUsersOptionalParams, ) -> Result<ResponseContent<UsersResponse>, Error<ListUsersError>>
Get the list of all users in the organization. This list includes all users even if they are deactivated or unverified.
sourcepub async fn send_invitations(
&self,
body: UserInvitationsRequest,
) -> Result<UserInvitationsResponse, Error<SendInvitationsError>>
pub async fn send_invitations( &self, body: UserInvitationsRequest, ) -> Result<UserInvitationsResponse, Error<SendInvitationsError>>
Sends emails to one or more users inviting them to join the organization.
Examples found in repository?
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let body = UserInvitationsRequest::new(vec![UserInvitationData::new(
UserInvitationRelationships::new(RelationshipToUser::new(RelationshipToUserData::new(
user_data_id.clone(),
UsersType::USERS,
))),
UserInvitationsType::USER_INVITATIONS,
)]);
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.send_invitations(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn send_invitations_with_http_info(
&self,
body: UserInvitationsRequest,
) -> Result<ResponseContent<UserInvitationsResponse>, Error<SendInvitationsError>>
pub async fn send_invitations_with_http_info( &self, body: UserInvitationsRequest, ) -> Result<ResponseContent<UserInvitationsResponse>, Error<SendInvitationsError>>
Sends emails to one or more users inviting them to join the organization.
sourcepub async fn update_user(
&self,
user_id: String,
body: UserUpdateRequest,
) -> Result<UserResponse, Error<UpdateUserError>>
pub async fn update_user( &self, user_id: String, body: UserUpdateRequest, ) -> Result<UserResponse, Error<UpdateUserError>>
Edit a user. Can only be used with an application key belonging to an administrator user.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28
async fn main() {
// there is a valid "user" in the system
let user_data_id = std::env::var("USER_DATA_ID").unwrap();
let body = UserUpdateRequest::new(UserUpdateData::new(
UserUpdateAttributes::new()
.disabled(true)
.name("updated".to_string()),
user_data_id.clone(),
UsersType::USERS,
));
let configuration = datadog::Configuration::new();
let api = UsersAPI::with_config(configuration);
let resp = api.update_user(user_data_id.clone(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn update_user_with_http_info(
&self,
user_id: String,
body: UserUpdateRequest,
) -> Result<ResponseContent<UserResponse>, Error<UpdateUserError>>
pub async fn update_user_with_http_info( &self, user_id: String, body: UserUpdateRequest, ) -> Result<ResponseContent<UserResponse>, Error<UpdateUserError>>
Edit a user. Can only be used with an application key belonging to an administrator user.