pub struct WorkflowAutomationAPI { /* private fields */ }Expand description
Automate your teams operational processes with Datadog Workflow Automation.
Implementations
sourceimpl WorkflowAutomationAPI
impl WorkflowAutomationAPI
pub fn new() -> Self
sourcepub fn with_config(config: Configuration) -> Self
pub fn with_config(config: Configuration) -> Self
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.list_workflow_instances(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
ListWorkflowInstancesOptionalParams::default(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.get_workflow_instance(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
"305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.cancel_workflow_instance(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
"305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25
async fn main() {
let body =
WorkflowInstanceCreateRequest::new().meta(WorkflowInstanceCreateMeta::new().payload(
BTreeMap::from([("input".to_string(), Value::from("value"))]),
));
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.create_workflow_instance("ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn with_client_and_config( config: Configuration, client: ClientWithMiddleware, ) -> Self
sourcepub async fn cancel_workflow_instance(
&self,
workflow_id: String,
instance_id: String,
) -> Result<WorklflowCancelInstanceResponse, Error<CancelWorkflowInstanceError>>
pub async fn cancel_workflow_instance( &self, workflow_id: String, instance_id: String, ) -> Result<WorklflowCancelInstanceResponse, Error<CancelWorkflowInstanceError>>
Cancels a specific execution of a given workflow. This API requires an application key scoped with the workflows_run permission.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.cancel_workflow_instance(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
"305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn cancel_workflow_instance_with_http_info(
&self,
workflow_id: String,
instance_id: String,
) -> Result<ResponseContent<WorklflowCancelInstanceResponse>, Error<CancelWorkflowInstanceError>>
pub async fn cancel_workflow_instance_with_http_info( &self, workflow_id: String, instance_id: String, ) -> Result<ResponseContent<WorklflowCancelInstanceResponse>, Error<CancelWorkflowInstanceError>>
Cancels a specific execution of a given workflow. This API requires an application key scoped with the workflows_run permission.
sourcepub async fn create_workflow_instance(
&self,
workflow_id: String,
body: WorkflowInstanceCreateRequest,
) -> Result<WorkflowInstanceCreateResponse, Error<CreateWorkflowInstanceError>>
pub async fn create_workflow_instance( &self, workflow_id: String, body: WorkflowInstanceCreateRequest, ) -> Result<WorkflowInstanceCreateResponse, Error<CreateWorkflowInstanceError>>
Execute the given workflow. This API requires an application key scoped with the workflows_run permission.
Examples found in repository?
10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25
async fn main() {
let body =
WorkflowInstanceCreateRequest::new().meta(WorkflowInstanceCreateMeta::new().payload(
BTreeMap::from([("input".to_string(), Value::from("value"))]),
));
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.create_workflow_instance("ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(), body)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn create_workflow_instance_with_http_info(
&self,
workflow_id: String,
body: WorkflowInstanceCreateRequest,
) -> Result<ResponseContent<WorkflowInstanceCreateResponse>, Error<CreateWorkflowInstanceError>>
pub async fn create_workflow_instance_with_http_info( &self, workflow_id: String, body: WorkflowInstanceCreateRequest, ) -> Result<ResponseContent<WorkflowInstanceCreateResponse>, Error<CreateWorkflowInstanceError>>
Execute the given workflow. This API requires an application key scoped with the workflows_run permission.
sourcepub async fn get_workflow_instance(
&self,
workflow_id: String,
instance_id: String,
) -> Result<WorklflowGetInstanceResponse, Error<GetWorkflowInstanceError>>
pub async fn get_workflow_instance( &self, workflow_id: String, instance_id: String, ) -> Result<WorklflowGetInstanceResponse, Error<GetWorkflowInstanceError>>
Get a specific execution of a given workflow. This API requires an application key scoped with the workflows_read permission.
Examples found in repository?
6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.get_workflow_instance(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
"305a472b-71ab-4ce8-8f8d-75db635627b5".to_string(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn get_workflow_instance_with_http_info(
&self,
workflow_id: String,
instance_id: String,
) -> Result<ResponseContent<WorklflowGetInstanceResponse>, Error<GetWorkflowInstanceError>>
pub async fn get_workflow_instance_with_http_info( &self, workflow_id: String, instance_id: String, ) -> Result<ResponseContent<WorklflowGetInstanceResponse>, Error<GetWorkflowInstanceError>>
Get a specific execution of a given workflow. This API requires an application key scoped with the workflows_read permission.
sourcepub async fn list_workflow_instances(
&self,
workflow_id: String,
params: ListWorkflowInstancesOptionalParams,
) -> Result<WorkflowListInstancesResponse, Error<ListWorkflowInstancesError>>
pub async fn list_workflow_instances( &self, workflow_id: String, params: ListWorkflowInstancesOptionalParams, ) -> Result<WorkflowListInstancesResponse, Error<ListWorkflowInstancesError>>
List all instances of a given workflow. This API requires an application key scoped with the workflows_read permission.
Examples found in repository?
7 8 9 10 11 12 13 14 15 16 17 18 19 20 21
async fn main() {
let configuration = datadog::Configuration::new();
let api = WorkflowAutomationAPI::with_config(configuration);
let resp = api
.list_workflow_instances(
"ccf73164-1998-4785-a7a3-8d06c7e5f558".to_string(),
ListWorkflowInstancesOptionalParams::default(),
)
.await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub async fn list_workflow_instances_with_http_info(
&self,
workflow_id: String,
params: ListWorkflowInstancesOptionalParams,
) -> Result<ResponseContent<WorkflowListInstancesResponse>, Error<ListWorkflowInstancesError>>
pub async fn list_workflow_instances_with_http_info( &self, workflow_id: String, params: ListWorkflowInstancesOptionalParams, ) -> Result<ResponseContent<WorkflowListInstancesResponse>, Error<ListWorkflowInstancesError>>
List all instances of a given workflow. This API requires an application key scoped with the workflows_read permission.