#[non_exhaustive]pub struct EntityV3Metadata {
pub additional_owners: Option<Vec<EntityV3MetadataAdditionalOwnersItems>>,
pub contacts: Option<Vec<EntityV3MetadataContactsItems>>,
pub description: Option<String>,
pub display_name: Option<String>,
pub id: Option<String>,
pub inherit_from: Option<String>,
pub links: Option<Vec<EntityV3MetadataLinksItems>>,
pub managed: Option<BTreeMap<String, Value>>,
pub name: String,
pub namespace: Option<String>,
pub owner: Option<EntityV3MetadataOwner>,
pub tags: Option<Vec<String>>,
/* private fields */
}Expand description
The definition of Entity V3 Metadata object.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.additional_owners: Option<Vec<EntityV3MetadataAdditionalOwnersItems>>The additional owners of the entity, usually a team
contacts: Option<Vec<EntityV3MetadataContactsItems>>A list of contacts for the entity
description: Option<String>Short description of the entity. The UI can leverage the description for display
display_name: Option<String>User friendly name of the entity. The UI can leverage the display name for display
id: Option<String>A read-only globally unique identifier for the entity generated by Datadog. User supplied values are ignored.
inherit_from: Option<String>The entity reference from which to inherit metadata
links: Option<Vec<EntityV3MetadataLinksItems>>A list of links for the entity
managed: Option<BTreeMap<String, Value>>A read-only set of Datadog managed attributes generated by Datadog. User supplied values are ignored.
name: StringUnique name given to an entity under the kind/namespace
namespace: Option<String>Namespace is a part of unique identifier. It has a default value of ‘default’
owner: Option<EntityV3MetadataOwner>The owner of the entity, usually a team
A set of custom tags
Implementations
sourceimpl EntityV3Metadata
impl EntityV3Metadata
sourcepub fn new(name: String) -> EntityV3Metadata
pub fn new(name: String) -> EntityV3Metadata
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn additional_owners(
self,
value: Vec<EntityV3MetadataAdditionalOwnersItems>,
) -> Self
pub fn additional_owners( self, value: Vec<EntityV3MetadataAdditionalOwnersItems>, ) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn contacts(self, value: Vec<EntityV3MetadataContactsItems>) -> Self
pub fn contacts(self, value: Vec<EntityV3MetadataContactsItems>) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn description(self, value: String) -> Self
pub fn display_name(self, value: String) -> Self
sourcepub fn id(self, value: String) -> Self
pub fn id(self, value: String) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn inherit_from(self, value: String) -> Self
pub fn inherit_from(self, value: String) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}sourcepub fn links(self, value: Vec<EntityV3MetadataLinksItems>) -> Self
pub fn links(self, value: Vec<EntityV3MetadataLinksItems>) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn managed(self, value: BTreeMap<String, Value>) -> Self
sourcepub fn namespace(self, value: String) -> Self
pub fn namespace(self, value: String) -> Self
Examples found in repository?
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn owner(self, value: EntityV3MetadataOwner) -> Self
Examples found in repository?
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("service-examplesoftwarecatalog".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76
async fn main() {
let body = UpsertCatalogEntityRequest::EntityV3(Box::new(EntityV3::EntityV3Service(Box::new(
EntityV3Service::new(
EntityV3APIVersion::V3,
EntityV3ServiceKind::SERVICE,
EntityV3Metadata::new("myService".to_string())
.additional_owners(vec![])
.contacts(vec![EntityV3MetadataContactsItems::new(
"https://slack/".to_string(),
"slack".to_string(),
)])
.id("4b163705-23c0-4573-b2fb-f6cea2163fcb".to_string())
.inherit_from("application:default/myapp".to_string())
.links(vec![EntityV3MetadataLinksItems::new(
"mylink".to_string(),
"link".to_string(),
"https://mylink".to_string(),
)])
.namespace("default".to_string())
.tags(vec!["this:tag".to_string(), "that:tag".to_string()]),
)
.datadog(
EntityV3ServiceDatadog::new()
.code_locations(vec![EntityV3DatadogCodeLocationItem::new().paths(vec![])])
.events(vec![EntityV3DatadogEventItem::new()])
.logs(vec![EntityV3DatadogLogItem::new()])
.performance_data(EntityV3DatadogPerformance::new().tags(vec![]))
.pipelines(EntityV3DatadogPipelines::new().fingerprints(vec![])),
)
.integrations(
EntityV3Integrations::new()
.opsgenie(EntityV3DatadogIntegrationOpsgenie::new(
"https://www.opsgenie.com/service/shopping-cart".to_string(),
))
.pagerduty(EntityV3DatadogIntegrationPagerduty::new(
"https://www.pagerduty.com/service-directory/Pshopping-cart".to_string(),
)),
)
.spec(
EntityV3ServiceSpec::new()
.depends_on(vec![])
.languages(vec![]),
),
))));
let configuration = datadog::Configuration::new();
let api = SoftwareCatalogAPI::with_config(configuration);
let resp = api.upsert_catalog_entity(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}Trait Implementations
sourceimpl Clone for EntityV3Metadata
impl Clone for EntityV3Metadata
sourcefn clone(&self) -> EntityV3Metadata
fn clone(&self) -> EntityV3Metadata
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for EntityV3Metadata
impl Debug for EntityV3Metadata
sourceimpl<'de> Deserialize<'de> for EntityV3Metadata
impl<'de> Deserialize<'de> for EntityV3Metadata
sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
sourceimpl PartialEq for EntityV3Metadata
impl PartialEq for EntityV3Metadata
sourceimpl Serialize for EntityV3Metadata
impl Serialize for EntityV3Metadata
impl StructuralPartialEq for EntityV3Metadata