Struct datadog_api_client::datadogV2::model::model_sensitive_data_scanner_text_replacement::SensitiveDataScannerTextReplacement
source · #[non_exhaustive]pub struct SensitiveDataScannerTextReplacement {
pub number_of_chars: Option<i64>,
pub replacement_string: Option<String>,
pub type_: Option<SensitiveDataScannerTextReplacementType>,
pub additional_properties: BTreeMap<String, Value>,
/* private fields */
}Expand description
Object describing how the scanned event will be replaced.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.number_of_chars: Option<i64>Required if type == ‘partial_replacement_from_beginning’ or ‘partial_replacement_from_end’. It must be > 0.
replacement_string: Option<String>Required if type == ‘replacement_string’.
type_: Option<SensitiveDataScannerTextReplacementType>Type of the replacement text. None means no replacement. hash means the data will be stubbed. replacement_string means that one can chose a text to replace the data. partial_replacement_from_beginning allows a user to partially replace the data from the beginning, and partial_replacement_from_end on the other hand, allows to replace data from the end.
additional_properties: BTreeMap<String, Value>Implementations
sourceimpl SensitiveDataScannerTextReplacement
impl SensitiveDataScannerTextReplacement
sourcepub fn new() -> SensitiveDataScannerTextReplacement
pub fn new() -> SensitiveDataScannerTextReplacement
Examples found in repository?
examples/v2_sensitive-data-scanner_UpdateScanningRule.rs (line 33)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49
async fn main() {
// the "scanning_group" has a "scanning_rule"
let rule_data_id = std::env::var("RULE_DATA_ID").unwrap();
let body = SensitiveDataScannerRuleUpdateRequest::new(
SensitiveDataScannerRuleUpdate::new()
.attributes(
SensitiveDataScannerRuleAttributes::new()
.included_keyword_configuration(
SensitiveDataScannerIncludedKeywordConfiguration::new(
35,
vec!["credit card".to_string(), "cc".to_string()],
),
)
.is_enabled(true)
.name("Example-Sensitive-Data-Scanner".to_string())
.pattern("pattern".to_string())
.priority(5)
.tags(vec!["sensitive_data:true".to_string()])
.text_replacement(
SensitiveDataScannerTextReplacement::new()
.type_(SensitiveDataScannerTextReplacementType::NONE),
),
)
.id(rule_data_id.clone())
.type_(SensitiveDataScannerRuleType::SENSITIVE_DATA_SCANNER_RULE),
SensitiveDataScannerMetaVersionOnly::new(),
);
let configuration = datadog::Configuration::new();
let api = SensitiveDataScannerAPI::with_config(configuration);
let resp = api.update_scanning_rule(rule_data_id.clone(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_sensitive-data-scanner_CreateScanningRule.rs (line 38)
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60
async fn main() {
// there is a valid "scanning_group" in the system
let group_data_id = std::env::var("GROUP_DATA_ID").unwrap();
let body = SensitiveDataScannerRuleCreateRequest::new(
SensitiveDataScannerRuleCreate::new(
SensitiveDataScannerRuleAttributes::new()
.excluded_namespaces(vec!["admin.name".to_string()])
.included_keyword_configuration(
SensitiveDataScannerIncludedKeywordConfiguration::new(
35,
vec!["credit card".to_string()],
),
)
.is_enabled(true)
.name("Example-Sensitive-Data-Scanner".to_string())
.namespaces(vec!["admin".to_string()])
.pattern("pattern".to_string())
.priority(1)
.tags(vec!["sensitive_data:true".to_string()])
.text_replacement(
SensitiveDataScannerTextReplacement::new()
.type_(SensitiveDataScannerTextReplacementType::NONE),
),
SensitiveDataScannerRuleRelationships::new().group(
SensitiveDataScannerGroupData::new().data(
SensitiveDataScannerGroup::new()
.id(group_data_id.clone())
.type_(SensitiveDataScannerGroupType::SENSITIVE_DATA_SCANNER_GROUP),
),
),
SensitiveDataScannerRuleType::SENSITIVE_DATA_SCANNER_RULE,
),
SensitiveDataScannerMetaVersionOnly::new(),
);
let configuration = datadog::Configuration::new();
let api = SensitiveDataScannerAPI::with_config(configuration);
let resp = api.create_scanning_rule(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn number_of_chars(self, value: i64) -> Self
pub fn replacement_string(self, value: String) -> Self
sourcepub fn type_(self, value: SensitiveDataScannerTextReplacementType) -> Self
pub fn type_(self, value: SensitiveDataScannerTextReplacementType) -> Self
Examples found in repository?
examples/v2_sensitive-data-scanner_UpdateScanningRule.rs (line 34)
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49
async fn main() {
// the "scanning_group" has a "scanning_rule"
let rule_data_id = std::env::var("RULE_DATA_ID").unwrap();
let body = SensitiveDataScannerRuleUpdateRequest::new(
SensitiveDataScannerRuleUpdate::new()
.attributes(
SensitiveDataScannerRuleAttributes::new()
.included_keyword_configuration(
SensitiveDataScannerIncludedKeywordConfiguration::new(
35,
vec!["credit card".to_string(), "cc".to_string()],
),
)
.is_enabled(true)
.name("Example-Sensitive-Data-Scanner".to_string())
.pattern("pattern".to_string())
.priority(5)
.tags(vec!["sensitive_data:true".to_string()])
.text_replacement(
SensitiveDataScannerTextReplacement::new()
.type_(SensitiveDataScannerTextReplacementType::NONE),
),
)
.id(rule_data_id.clone())
.type_(SensitiveDataScannerRuleType::SENSITIVE_DATA_SCANNER_RULE),
SensitiveDataScannerMetaVersionOnly::new(),
);
let configuration = datadog::Configuration::new();
let api = SensitiveDataScannerAPI::with_config(configuration);
let resp = api.update_scanning_rule(rule_data_id.clone(), body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}More examples
examples/v2_sensitive-data-scanner_CreateScanningRule.rs (line 39)
18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60
async fn main() {
// there is a valid "scanning_group" in the system
let group_data_id = std::env::var("GROUP_DATA_ID").unwrap();
let body = SensitiveDataScannerRuleCreateRequest::new(
SensitiveDataScannerRuleCreate::new(
SensitiveDataScannerRuleAttributes::new()
.excluded_namespaces(vec!["admin.name".to_string()])
.included_keyword_configuration(
SensitiveDataScannerIncludedKeywordConfiguration::new(
35,
vec!["credit card".to_string()],
),
)
.is_enabled(true)
.name("Example-Sensitive-Data-Scanner".to_string())
.namespaces(vec!["admin".to_string()])
.pattern("pattern".to_string())
.priority(1)
.tags(vec!["sensitive_data:true".to_string()])
.text_replacement(
SensitiveDataScannerTextReplacement::new()
.type_(SensitiveDataScannerTextReplacementType::NONE),
),
SensitiveDataScannerRuleRelationships::new().group(
SensitiveDataScannerGroupData::new().data(
SensitiveDataScannerGroup::new()
.id(group_data_id.clone())
.type_(SensitiveDataScannerGroupType::SENSITIVE_DATA_SCANNER_GROUP),
),
),
SensitiveDataScannerRuleType::SENSITIVE_DATA_SCANNER_RULE,
),
SensitiveDataScannerMetaVersionOnly::new(),
);
let configuration = datadog::Configuration::new();
let api = SensitiveDataScannerAPI::with_config(configuration);
let resp = api.create_scanning_rule(body).await;
if let Ok(value) = resp {
println!("{:#?}", value);
} else {
println!("{:#?}", resp.unwrap_err());
}
}pub fn additional_properties(self, value: BTreeMap<String, Value>) -> Self